@@ -1,14 +1,13 @@
 import getopt
+import logging
 import os
 import sys
-import logging
 
 from pcs import (
     settings,
     usage,
     utils,
 )
-
 from pcs.cli.common import (
     capabilities,
     completion,
@@ -16,7 +15,12 @@ from pcs.cli.common import (
     parse_args,
     routing,
 )
-from pcs.cli.reports import process_library_reports, output
+from pcs.cli.reports import process_library_reports
+from pcs.cli.reports.output import (
+    deprecation_warning,
+    error,
+    print_to_stderr,
+)
 from pcs.cli.routing import (
     acl,
     alert,
@@ -46,14 +50,12 @@ def _non_root_run(argv_cmd):
     are not root. If it required to run such command as root it will do that by
     sending it to the local pcsd and then it will exit.
     """
-    # matching the commands both in here and in pcsd expects -o and --options
-    # to be at the end of a command
-    argv_and_options = argv_cmd[:]
+    options = []
     for option, value in utils.pcs_options.items():
         if parse_args.is_option_expecting_value(option):
-            argv_and_options.extend([option, value])
+            options.extend([option, value])
         else:
-            argv_and_options.append(option)
+            options.append(option)
 
     # specific commands need to be run under root account, pass them to pcsd
     # don't forget to allow each command in pcsd.rb in "post /run_pcs do"
@@ -84,22 +86,22 @@ def _non_root_run(argv_cmd):
     ]
 
     for root_cmd in root_command_list:
-        if (argv_and_options == root_cmd) or (
+        if (argv_cmd == root_cmd) or (
             root_cmd[-1] == "..."
-            and argv_and_options[: len(root_cmd) - 1] == root_cmd[:-1]
+            and argv_cmd[: len(root_cmd) - 1] == root_cmd[:-1]
         ):
             # handle interactivity of 'pcs cluster auth'
-            if argv_and_options[0:2] in [["cluster", "auth"], ["host", "auth"]]:
+            if argv_cmd[0:2] in [["cluster", "auth"], ["host", "auth"]]:
                 if "-u" not in utils.pcs_options:
                     username = utils.get_terminal_input("Username: ")
-                    argv_and_options.extend(["-u", username])
+                    options.extend(["-u", username])
                 if "-p" not in utils.pcs_options:
                     password = utils.get_terminal_password()
-                    argv_and_options.extend(["-p", password])
+                    options.extend(["-p", password])
 
             # call the local pcsd
             err_msgs, exitcode, std_out, std_err = utils.call_local_pcsd(
-                argv_and_options
+                argv_cmd, options
             )
             if err_msgs:
                 for msg in err_msgs:
@@ -162,7 +164,7 @@ def main(argv=None):
             ) = parse_args.filter_out_non_option_negative_numbers(argv)
             if args_filtered_out:
                 options_str = "', '".join(args_filtered_out)
-                output.warn(
+                deprecation_warning(
                     f"Using '{options_str}' without '--' is deprecated, those "
                     "parameters will be considered position independent "
                     "options in future pcs versions"
@@ -174,14 +176,8 @@ def main(argv=None):
             )
             argv = parse_args.filter_out_options(argv)
     except getopt.GetoptError as err:
-        usage.main()
-        print(err)
-        if err.opt in {"V", "clone", "device", "watchdog"}:
-            # Print error messages which point users to the changes section in
-            # pcs manpage.
-            # TODO remove
-            # To be removed in the next significant version.
-            print(f"Hint: {errors.HINT_SYNTAX_CHANGE}")
+        error(str(err))
+        print_to_stderr(usage.main())
         sys.exit(1)
 
     full = False
@@ -200,7 +196,7 @@ def main(argv=None):
 
         if opt in ("-h", "--help"):
             if not argv:
-                usage.main()
+                print(usage.main())
                 sys.exit()
             else:
                 argv = [argv[0], "help"] + argv[1:]
@@ -271,17 +267,20 @@ def main(argv=None):
         "client": client.client_cmd,
         "dr": dr.dr_cmd,
         "tag": tag.tag_cmd,
-        "help": lambda lib, argv, modifiers: usage.main(),
+        "help": lambda lib, argv, modifiers: print(usage.main()),
     }
     try:
         routing.create_router(cmd_map, [])(
             utils.get_library_wrapper(), argv, utils.get_input_modifiers()
         )
     except LibraryError as e:
+        if e.output:
+            sys.stderr.write(e.output)
+            sys.exit(1)
         process_library_reports(e.args)
     except errors.CmdLineInputError:
         if argv and argv[0] in cmd_map:
             usage.show(argv[0], [])
         else:
-            usage.main()
+            print_to_stderr(usage.main())
         sys.exit(1)
