@@ -1,5 +1,8 @@
 from pcs.cli.common.errors import CmdLineInputError
-from pcs.cli.common.parse_args import group_by_keywords, prepare_options
+from pcs.cli.common.parse_args import (
+    group_by_keywords,
+    prepare_options,
+)
 
 
 def config_setup(lib, arg_list, modifiers):
@@ -54,7 +57,7 @@ def config_show(lib, arg_list, modifiers):
     print booth config
 
     Options:
-      * --name - name of a booth instace
+      * --name - name of a booth instance
       * --request-timeout - HTTP timeout for getting config from remote host
     """
     modifiers.ensure_only_supported("--name", "--request-timeout")
@@ -79,7 +82,7 @@ def config_ticket_add(lib, arg_list, modifiers):
       * --force
       * --booth-conf - booth config file
       * --booth-key - booth auth key file
-      * --name - name of a booth instace
+      * --name - name of a booth instance
     """
     modifiers.ensure_only_supported(
         "--force", "--booth-conf", "--name", "--booth-key"
@@ -101,7 +104,7 @@ def config_ticket_remove(lib, arg_list, modifiers):
     Options:
       * --booth-conf - booth config file
       * --booth-key - booth auth key file
-      * --name - name of a booth instace
+      * --name - name of a booth instance
     """
     modifiers.ensure_only_supported("--booth-conf", "--name", "--booth-key")
     if len(arg_list) != 1:
@@ -112,6 +115,34 @@ def config_ticket_remove(lib, arg_list, modifiers):
     )
 
 
+def enable_authfile(lib, arg_list, modifiers) -> None:
+    """
+    Options:
+      * --booth-conf - booth config file
+      * --booth-key - booth auth key file
+      * --name - name of a booth instance
+    """
+    modifiers.ensure_only_supported("--booth-conf", "--name", "--booth-key")
+    if len(arg_list):
+        raise CmdLineInputError()
+    lib.booth.config_set_enable_authfile(instance_name=modifiers.get("--name"))
+
+
+def enable_authfile_clean(lib, arg_list, modifiers) -> None:
+    """
+    Options:
+      * --booth-conf - booth config file
+      * --booth-key - booth auth key file
+      * --name - name of a booth instance
+    """
+    modifiers.ensure_only_supported("--booth-conf", "--name", "--booth-key")
+    if len(arg_list):
+        raise CmdLineInputError()
+    lib.booth.config_unset_enable_authfile(
+        instance_name=modifiers.get("--name")
+    )
+
+
 def _ticket_operation(lib_call, arg_list, booth_name):
     """
     Commandline options:
@@ -219,7 +250,7 @@ def sync(lib, arg_list, modifiers):
       * --name - name of a booth instance
       * --booth-conf - booth config file
       * --booth-key - booth authkey file
-      * --request-timeout - HTTP timeout for file ditribution
+      * --request-timeout - HTTP timeout for file distribution
     """
     modifiers.ensure_only_supported(
         "--skip-offline",
@@ -284,7 +315,7 @@ def pull(lib, arg_list, modifiers):
     """
     Options:
       * --name - name of a booth instance
-      * --request-timeout - HTTP timeout for file ditribution
+      * --request-timeout - HTTP timeout for file distribution
     """
     modifiers.ensure_only_supported("--name", "--request-timeout")
     if len(arg_list) != 1:
