@@ -1,7 +1,7 @@
 from collections import Counter
 from collections.abc import Set
+from functools import partial
 from typing import (
-    Iterable,
     Mapping,
     Union,
     cast,
@@ -16,7 +16,10 @@ from pcs.common.str_tools import (
     format_plural,
 )
 from pcs.common.tools import timeout_to_seconds
-from pcs.common.types import StringSequence
+from pcs.common.types import (
+    StringIterable,
+    StringSequence,
+)
 
 ModifierValueType = Union[None, bool, str]
 
@@ -93,6 +96,8 @@ PCS_LONG_OPTIONS = [
     f"{_OUTPUT_FORMAT_OPTION_STR}=",
     # auth token
     "token=",
+    # enable agent self validation
+    "agent-validation",
 ]
 
 
@@ -484,6 +489,7 @@ class InputModifiers:
             {
                 # boolean values
                 "--all": "--all" in options,
+                "--agent-validation": "--agent-validation" in options,
                 "--autodelete": "--autodelete" in options,
                 "--brief": "--brief" in options,
                 "--config": "--config" in options,
@@ -560,7 +566,7 @@ class InputModifiers:
             supported_options_set.add(_OUTPUT_FORMAT_OPTION)
         unsupported_options = self._defined_options - supported_options_set
         if unsupported_options:
-            pluralize = lambda word: format_plural(unsupported_options, word)
+            pluralize = partial(format_plural, unsupported_options)
             raise CmdLineInputError(
                 "Specified {option} {option_list} {_is} not supported in this "
                 "command".format(
@@ -596,9 +602,7 @@ class InputModifiers:
             )
 
     def ensure_dependency_satisfied(
-        self,
-        main_option: str,
-        dependent_options: Iterable[str],
+        self, main_option: str, dependent_options: StringIterable
     ) -> None:
         """
         Raise a `CmdLineInputError` exception if any of `dependent_options` is
@@ -621,7 +625,7 @@ class InputModifiers:
     def is_specified(self, option: str) -> bool:
         return option in self._defined_options
 
-    def is_specified_any(self, option_list: Iterable[str]) -> bool:
+    def is_specified_any(self, option_list: StringIterable) -> bool:
         for option in option_list:
             if self.is_specified(option):
                 return True
