@@ -1,5 +1,6 @@
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.constraint import command
+from pcs.cli.reports.output import deprecation_warning
 from pcs.common.reports import constraints
 
 
@@ -18,13 +19,21 @@ def create_with_set(lib, argv, modifiers):
     """
     modifiers.ensure_only_supported("-f", "--force")
     command.create_with_set(
-        lib.constraint_colocation.set,
+        lib.constraint_colocation.create_with_set,
         argv,
         modifiers,
     )
 
 
 def show(lib, argv, modifiers):
+    deprecation_warning(
+        "This command is deprecated and will be removed. "
+        "Please use 'pcs constraint colocation config' instead."
+    )
+    return config_cmd(lib, argv, modifiers)
+
+
+def config_cmd(lib, argv, modifiers):
     """
     show all colocation constraints
     object lib exposes library
@@ -40,9 +49,9 @@ def show(lib, argv, modifiers):
         raise CmdLineInputError()
     print(
         "\n".join(
-            command.show(
+            command.config_cmd(
                 "Colocation Constraints:",
-                lib.constraint_colocation.show,
+                lib.constraint_colocation.config,
                 constraints.colocation_plain,
                 modifiers,
             )
