@@ -1,24 +1,28 @@
+from functools import partial
 from typing import (
-    get_type_hints,
     Any,
     Dict,
     Mapping,
+    Optional,
+    get_type_hints,
 )
 
 from pcs.common import file_type_codes
-from pcs.common.str_tools import (
-    format_list,
-    format_optional,
-    format_plural,
-    transform,
-)
 from pcs.common.reports import (
+    codes,
     const,
     dto,
     item,
     messages,
     types,
 )
+from pcs.common.str_tools import (
+    format_list,
+    format_optional,
+    format_plural,
+    indent,
+    transform,
+)
 from pcs.common.tools import get_all_subclasses
 
 
@@ -38,6 +42,20 @@ class CliReportMessage:
     def payload(self) -> Mapping[str, Any]:
         return self._dto_obj.payload
 
+    def get_message_with_force_text(
+        self, force_code: Optional[types.ForceCode]
+    ) -> str:
+        force_text_map = {
+            codes.SKIP_OFFLINE_NODES: ", use --skip-offline to override",
+        }
+        force_text = (
+            force_text_map.get(force_code, ", use --force to override")
+            if force_code
+            else ""
+        )
+
+        return f"{self.message}{force_text}"
+
 
 class CliReportMessageCustom(CliReportMessage):
     # pylint: disable=no-member
@@ -142,6 +160,17 @@ class CannotMoveResourceMasterResourceNotPromotable(CliReportMessageCustom):
         )
 
 
+class CannotMoveResourceNotRunning(CliReportMessageCustom):
+    _obj: messages.CannotMoveResourceNotRunning
+
+    @property
+    def message(self) -> str:
+        return (
+            f"{self._obj.message}, use 'pcs resource move-with-constraint' or "
+            "'pcs constraint location' commands instead"
+        )
+
+
 class SbdWatchdogTestMultipleDevices(CliReportMessageCustom):
     _obj: messages.SbdWatchdogTestMultipleDevices
 
@@ -160,8 +189,7 @@ class NodeUsedAsTieBreaker(CliReportMessageCustom):
     @property
     def message(self) -> str:
         return (
-            f"Node '{self._obj.node}' with id '{self._obj.node_id}' is used as "
-            "a tie breaker for a qdevice, run 'pcs quorum device update model "
+            self._obj.message + ", run 'pcs quorum device update model "
             "tie_breaker=<node id>' to change it"
         )
 
@@ -186,7 +214,7 @@ class UnableToConnectToAllRemainingNodes(CliReportMessageCustom):
 
     @property
     def message(self) -> str:
-        pluralize = lambda word: format_plural(self._obj.node_list, word)
+        pluralize = partial(format_plural, self._obj.node_list)
         return (
             "Remaining cluster {node} {nodes} could not be reached, run "
             "'pcs cluster sync' on any currently online node once the "
@@ -222,7 +250,7 @@ class HostNotFound(CliReportMessageCustom):
 
     @property
     def message(self) -> str:
-        pluralize = lambda word: format_plural(self._obj.host_list, word)
+        pluralize = partial(format_plural, self._obj.host_list)
         return (
             (
                 "{host} {hosts_comma} {_is} not known to pcs, try to "
@@ -482,6 +510,88 @@ class StonithRestartlessUpdateUnableToPerform(CliReportMessageCustom):
         return msg
 
 
+class InvalidResourceAgentName(CliReportMessageCustom):
+    _obj: messages.InvalidResourceAgentName
+
+    @property
+    def message(self) -> str:
+        return (
+            f"{self._obj.message} List of standards and providers can be "
+            "obtained by using commands 'pcs resource standards' and "
+            "'pcs resource providers'."
+        )
+
+
+class InvalidStonithAgentName(CliReportMessageCustom):
+    _obj: messages.InvalidStonithAgentName
+
+    @property
+    def message(self) -> str:
+        return (
+            f"{self._obj.message} List of agents can be obtained by using "
+            "command 'pcs stonith list'."
+        )
+
+
+class ResourceStonithCommandsMismatch(CliReportMessageCustom):
+    _obj: messages.ResourceStonithCommandsMismatch
+
+    @property
+    def message(self) -> str:
+        cmd = (
+            {const.PCS_COMMAND_STONITH_CREATE: "pcs stonith create"}.get(
+                self._obj.command_to_use_instead
+            )
+            if self._obj.command_to_use_instead
+            else None
+        )
+        additional_msg = format_optional(cmd, " Use '{}' command instead.")
+        return f"{self._obj.message}{additional_msg}"
+
+
+class AgentSelfValidationResult(CliReportMessageCustom):
+    _obj: messages.AgentSelfValidationResult
+    _base_msg = "Validation result from agent"
+
+    @property
+    def _formatted_result(self) -> str:
+        return "\n".join(indent(self._obj.result.splitlines()))
+
+    @property
+    def message(self) -> str:
+        return f"{self._base_msg}:\n{self._formatted_result}"
+
+    def get_message_with_force_text(
+        self, force_code: Optional[types.ForceCode]
+    ) -> str:
+        force_text = (
+            " (use --force to override)" if force_code == codes.FORCE else ""
+        )
+        return f"{self._base_msg}{force_text}:\n{self._formatted_result}"
+
+
+class BoothAuthfileNotUsed(CliReportMessageCustom):
+    _obj: messages.BoothAuthfileNotUsed
+
+    @property
+    def message(self) -> str:
+        return (
+            f"{self._obj.message}. Run 'pcs booth enable-authfile --name "
+            f"{self._obj.instance}' to enable usage of authfile."
+        )
+
+
+class BoothUnsupportedOptionEnableAuthfile(CliReportMessageCustom):
+    _obj: messages.BoothUnsupportedOptionEnableAuthfile
+
+    @property
+    def message(self) -> str:
+        return (
+            f"{self._obj.message}. Run 'pcs booth clean-enable-authfile --name "
+            f"{self._obj.instance}' to remove the option."
+        )
+
+
 def _create_report_msg_map() -> Dict[str, type]:
     result: Dict[str, type] = {}
     for report_msg_cls in get_all_subclasses(CliReportMessageCustom):
@@ -517,7 +627,7 @@ def _resource_move_ban_clear_master_resource_not_promotable(
     promotable_id: str,
 ) -> str:
     return (
-        "when specifying --master you must use the promotable clone id{_id}"
+        "when specifying --promoted you must use the promotable clone id{_id}"
     ).format(
         _id=format_optional(promotable_id, " ({})"),
     )
