@@ -1,5 +1,11 @@
-from pcs.cli.common.parse_args import group_by_keywords, prepare_options
-from pcs.cli.common.errors import CmdLineInputError, SEE_MAN_CHANGES
+from pcs.cli.common.errors import (
+    SEE_MAN_CHANGES,
+    CmdLineInputError,
+)
+from pcs.cli.common.parse_args import (
+    group_by_keywords,
+    prepare_options,
+)
 
 
 def parse_create_simple(arg_list):
@@ -96,7 +102,7 @@ def parse_create(arg_list):
                 hint=(
                     "Master/Slave resources have been renamed to promotable "
                     "clones, please use the 'promotable' keyword instead of "
-                    "'master'. " + SEE_MAN_CHANGES
+                    "'master'. " + SEE_MAN_CHANGES.format("0.10")
                 ),
             ) from e
         raise
