@@ -1,7 +1,4 @@
-from typing import (
-    Any,
-    Sequence,
-)
+from typing import Any
 
 import pcs.cli.cluster.command as cluster_command
 from pcs import (
@@ -15,10 +12,11 @@ from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.parse_args import InputModifiers
 from pcs.cli.common.routing import create_router
 from pcs.cli.reports.output import deprecation_warning
+from pcs.common.types import StringSequence
 from pcs.utils import exit_on_cmdline_input_error
 
 
-def certkey(lib: Any, argv: Sequence[str], modifiers: InputModifiers) -> None:
+def certkey(lib: Any, argv: StringSequence, modifiers: InputModifiers) -> None:
     deprecation_warning(
         "This command is deprecated and will be removed. "
         "Please use 'pcs pcsd certkey' instead."
@@ -30,7 +28,7 @@ def certkey(lib: Any, argv: Sequence[str], modifiers: InputModifiers) -> None:
 
 
 def pcsd_status(
-    lib: Any, argv: Sequence[str], modifiers: InputModifiers
+    lib: Any, argv: StringSequence, modifiers: InputModifiers
 ) -> None:
     deprecation_warning(
         "This command is deprecated and will be removed. "
