@@ -2,14 +2,14 @@ from pcs import (
     prop,
     usage,
 )
+from pcs.cli import cluster_property
 from pcs.cli.common.routing import create_router
 
-
 property_cmd = create_router(
     {
-        "help": lambda _lib, _argv, _modifiers: usage.property(_argv),
-        "set": prop.set_property,
-        "unset": prop.unset_property,
+        "help": lambda _lib, _argv, _modifiers: print(usage.property(_argv)),
+        "set": cluster_property.set_property,
+        "unset": cluster_property.unset_property,
         # TODO remove, deprecated command
         # replaced with 'config'
         "list": prop.list_property_deprecated,
