@@ -4,10 +4,9 @@ from pcs import (
 )
 from pcs.cli.common.routing import create_router
 
-
 qdevice_cmd = create_router(
     {
-        "help": lambda lib, argv, modifiers: usage.qdevice(argv),
+        "help": lambda lib, argv, modifiers: print(usage.qdevice(argv)),
         "status": qdevice.qdevice_status_cmd,
         "setup": qdevice.qdevice_setup_cmd,
         "destroy": qdevice.qdevice_destroy_cmd,
