@@ -7,7 +7,7 @@ tag_cmd = create_router(
         "config": tag.tag_config,
         "create": tag.tag_create,
         "delete": tag.tag_remove,
-        "help": lambda lib, argv, modifiers: usage.tag(argv),
+        "help": lambda lib, argv, modifiers: print(usage.tag(argv)),
         # TODO remove, deprecated command
         # replaced with 'config'
         "list": tag.tag_list_cmd,
