@@ -3,44 +3,45 @@ import datetime
 import json
 import math
 import os
-import re
 import subprocess
 import sys
 import tempfile
 import time
 import xml.dom.minidom
 from typing import (
-    cast,
     Any,
+    Callable,
     Iterable,
     List,
     Mapping,
     Optional,
+    cast,
 )
 
+import pcs.lib.pacemaker.live as lib_pacemaker
 from pcs import (
     settings,
     utils,
 )
-from pcs.utils import parallel_for_nodes
 from pcs.cli.common import parse_args
 from pcs.cli.common.errors import (
-    CmdLineInputError,
     ERR_NODE_LIST_AND_ALL_MUTUALLY_EXCLUSIVE,
-    HINT_SYNTAX_CHANGE,
-    msg_command_replaced,
+    CmdLineInputError,
+    raise_command_replaced,
 )
+from pcs.cli.common.tools import print_to_stderr
 from pcs.cli.file import metadata as file_metadata
 from pcs.cli.reports import process_library_reports
 from pcs.cli.reports.messages import report_item_msg_from_dto
+from pcs.cli.reports.output import warn
+from pcs.common import file as pcs_file
 from pcs.common import (
-    file as pcs_file,
     file_type_codes,
     reports,
 )
 from pcs.common.corosync_conf import (
-    CorosyncNodeDto,
     CorosyncConfDto,
+    CorosyncNodeDto,
 )
 from pcs.common.interface import dto
 from pcs.common.node_communicator import (
@@ -52,33 +53,62 @@ from pcs.common.str_tools import (
     format_list,
     indent,
 )
-from pcs.common.tools import (
-    Version,
-    format_os_error,
-)
+from pcs.common.tools import format_os_error
 from pcs.lib import sbd as lib_sbd
-from pcs.lib.cib.tools import VERSION_FORMAT
 from pcs.lib.commands.remote_node import _destroy_pcmk_remote_env
 from pcs.lib.communication.nodes import CheckAuth
-from pcs.lib.communication.tools import (
-    run_and_raise,
-    run as run_com_cmd,
-    RunRemotelyBase,
+from pcs.lib.communication.tools import RunRemotelyBase
+from pcs.lib.communication.tools import run as run_com_cmd
+from pcs.lib.communication.tools import run_and_raise
+from pcs.lib.corosync import qdevice_net
+from pcs.lib.corosync.live import (
+    QuorumStatusException,
+    QuorumStatusFacade,
 )
-from pcs.lib.corosync import (
-    live as corosync_live,
-    qdevice_net,
-)
-from pcs.cli.reports.output import error, warn
 from pcs.lib.errors import LibraryError
-from pcs.lib.external import disable_service
-from pcs.lib.env import MIN_FEATURE_SET_VERSION_FOR_DIFF
 from pcs.lib.node import get_existing_nodes_names
-import pcs.lib.pacemaker.live as lib_pacemaker
+from pcs.utils import parallel_for_nodes
 
 # pylint: disable=too-many-branches, too-many-statements
 
 
+def _corosync_conf_local_cmd_call(
+    corosync_conf_path: parse_args.ModifierValueType,
+    lib_cmd: Callable[[bytes], bytes],
+) -> None:
+    """
+    Call a library command that requires modifications of a corosync.conf file
+    supplied as an argument
+
+    The lib command needs to take the corosync.conf file content as its first
+    argument
+
+        lib_cmd -- the lib command to be called
+    """
+    corosync_conf_file = pcs_file.RawFile(
+        file_metadata.for_file_type(
+            file_type_codes.COROSYNC_CONF, corosync_conf_path
+        )
+    )
+
+    try:
+        corosync_conf_file.write(
+            lib_cmd(
+                corosync_conf_file.read(),
+            ),
+            can_overwrite=True,
+        )
+    except pcs_file.RawFileError as e:
+        raise CmdLineInputError(
+            reports.messages.FileIoError(
+                e.metadata.file_type_code,
+                e.action,
+                e.reason,
+                file_path=e.metadata.path,
+            ).message
+        ) from e
+
+
 def cluster_cib_upgrade_cmd(lib, argv, modifiers):
     """
     Options:
@@ -234,6 +264,11 @@ def sync_nodes(lib, argv, modifiers):
     for node in nodes:
         utils.setCorosyncConfig(node, config)
 
+    warn(
+        "Corosync configuration has been synchronized, please reload corosync "
+        "daemon using 'pcs cluster reload corosync' command."
+    )
+
 
 def start_cluster(argv):
     """
@@ -258,16 +293,13 @@ def start_cluster(argv):
     if not utils.hasCorosyncConf():
         utils.err("cluster is not currently configured on this node")
 
-    print("Starting Cluster...")
+    print_to_stderr("Starting Cluster...")
     service_list = ["corosync"]
     if utils.need_to_handle_qdevice_service():
         service_list.append("corosync-qdevice")
     service_list.append("pacemaker")
     for service in service_list:
-        output, retval = utils.start_service(service)
-        if retval != 0:
-            print(output)
-            utils.err("unable to start {0}".format(service))
+        utils.start_service(service)
     if wait:
         wait_for_nodes_started([], wait_timeout)
 
@@ -401,13 +433,13 @@ def wait_for_nodes_started(node_list, timeout=None):
     timeout = 60 * 15 if timeout is None else timeout
     interval = 2
     stop_at = datetime.datetime.now() + datetime.timedelta(seconds=timeout)
-    print("Waiting for node(s) to start...")
+    print_to_stderr("Waiting for node(s) to start...")
     if not node_list:
         code, output = wait_for_local_node_started(stop_at, interval)
         if code != 0:
             utils.err(output)
         else:
-            print(output)
+            print_to_stderr(output)
     else:
         utils.read_known_hosts_file()  # cache known hosts
         node_errors = parallel_for_nodes(
@@ -466,14 +498,14 @@ def stop_cluster_nodes(nodes):
                 error_list.append(node + ": " + data)
                 continue
             try:
-                quorum_status = corosync_live.QuorumStatus.from_string(data)
-                if not quorum_status.is_quorate:
+                quorum_status_facade = QuorumStatusFacade.from_string(data)
+                if not quorum_status_facade.is_quorate:
                     # Get quorum status from a quorate node, non-quorate nodes
                     # may provide inaccurate info. If no node is quorate, there
                     # is no quorum to be lost and therefore no error to be
                     # reported.
                     continue
-                if quorum_status.stopping_nodes_cause_quorum_loss(nodes):
+                if quorum_status_facade.stopping_nodes_cause_quorum_loss(nodes):
                     utils.err(
                         "Stopping the node(s) will cause a loss of the quorum"
                         + ", use --force to override"
@@ -482,7 +514,7 @@ def stop_cluster_nodes(nodes):
                     # We have the info, no need to print errors
                     error_list = []
                     break
-            except corosync_live.QuorumStatusException:
+            except QuorumStatusException:
                 if not utils.is_node_offline_by_quorumtool_output(data):
                     error_list.append(node + ": Unable to get quorum status")
                 # else the node seems to be stopped already
@@ -497,9 +529,7 @@ def stop_cluster_nodes(nodes):
     node_errors = parallel_for_nodes(
         utils.repeat_if_timeout(utils.stopPacemaker), nodes, quiet=True
     )
-    accessible_nodes = [
-        node for node in nodes if node not in node_errors.keys()
-    ]
+    accessible_nodes = [node for node in nodes if node not in node_errors]
     if node_errors:
         utils.err(
             "unable to stop all nodes\n" + "\n".join(node_errors.values()),
@@ -508,7 +538,9 @@ def stop_cluster_nodes(nodes):
         was_error = True
 
     for node in node_errors:
-        print("{0}: Not stopping cluster - node is unreachable".format(node))
+        print_to_stderr(
+            "{0}: Not stopping cluster - node is unreachable".format(node)
+        )
 
     node_errors = parallel_for_nodes(
         utils.stopCorosync, accessible_nodes, quiet=True
@@ -659,14 +691,14 @@ def stop_cluster(argv):
         # - retval is 2 on success if a node is not in a partition with quorum
         output, dummy_retval = utils.run(["corosync-quorumtool", "-p", "-s"])
         try:
-            if corosync_live.QuorumStatus.from_string(
+            if QuorumStatusFacade.from_string(
                 output
             ).stopping_local_node_cause_quorum_loss():
                 utils.err(
                     "Stopping the node will cause a loss of the quorum"
                     + ", use --force to override"
                 )
-        except corosync_live.QuorumStatusException:
+        except QuorumStatusException:
             if not utils.is_node_offline_by_quorumtool_output(output):
                 utils.err(
                     "Unable to determine whether stopping the node will cause "
@@ -688,27 +720,21 @@ def stop_cluster_pacemaker():
     """
     Commandline options: no options
     """
-    print("Stopping Cluster (pacemaker)...")
-    output, retval = utils.stop_service("pacemaker")
-    if retval != 0:
-        print(output)
-        utils.err("unable to stop pacemaker")
+    print_to_stderr("Stopping Cluster (pacemaker)...")
+    utils.stop_service("pacemaker")
 
 
 def stop_cluster_corosync():
     """
     Commandline options: no options
     """
-    print("Stopping Cluster (corosync)...")
+    print_to_stderr("Stopping Cluster (corosync)...")
     service_list = []
     if utils.need_to_handle_qdevice_service():
         service_list.append("corosync-qdevice")
     service_list.append("corosync")
     for service in service_list:
-        output, retval = utils.stop_service(service)
-        if retval != 0:
-            print(output)
-            utils.err("unable to stop {0}".format(service))
+        utils.stop_service(service)
 
 
 def kill_cluster(lib, argv, modifiers):
@@ -748,7 +774,7 @@ def kill_local_cluster_services():
         "corosync-qdevice",
         "corosync",
     ]
-    return utils.run(["/usr/bin/killall", "-9"] + all_cluster_daemons)
+    return utils.run([settings.killall_executable, "-9"] + all_cluster_daemons)
 
 
 def cluster_push(lib, argv, modifiers):
@@ -804,55 +830,9 @@ def cluster_push(lib, argv, modifiers):
         utils.err("unable to parse new cib: %s" % e)
 
     if diff_against:
-        try:
-            original_cib = xml.dom.minidom.parse(diff_against)
-        except (EnvironmentError, xml.parsers.expat.ExpatError) as e:
-            utils.err("unable to parse original cib: %s" % e)
-
-        def unable_to_diff(reason):
-            return error(
-                "unable to diff against original cib '{0}': {1}".format(
-                    diff_against, reason
-                )
-            )
-
-        cib_element_list = original_cib.getElementsByTagName("cib")
-
-        if len(cib_element_list) != 1:
-            raise unable_to_diff("there is not exactly one 'cib' element")
-
-        crm_feature_set = cib_element_list[0].getAttribute("crm_feature_set")
-        if not crm_feature_set:
-            raise unable_to_diff(
-                "the 'cib' element is missing 'crm_feature_set' value"
-            )
-
-        match = re.match(VERSION_FORMAT, crm_feature_set)
-        if not match:
-            raise unable_to_diff(
-                "the attribute 'crm_feature_set' of the element 'cib' has an"
-                " invalid value: '{0}'".format(crm_feature_set)
-            )
-        crm_feature_set_version = Version(
-            int(match.group("major")),
-            int(match.group("minor")),
-            int(match.group("rev")) if match.group("rev") else None,
-        )
-
-        if crm_feature_set_version < MIN_FEATURE_SET_VERSION_FOR_DIFF:
-            raise unable_to_diff(
-                (
-                    "the 'crm_feature_set' version is '{0}'"
-                    " but at least version '{1}' is required"
-                ).format(
-                    crm_feature_set_version,
-                    MIN_FEATURE_SET_VERSION_FOR_DIFF,
-                )
-            )
-
         runner = utils.cmd_runner()
         command = [
-            os.path.join(settings.pacemaker_binaries, "crm_diff"),
+            settings.crm_diff,
             "--original",
             diff_against,
             "--new",
@@ -867,13 +847,13 @@ def cluster_push(lib, argv, modifiers):
         if retval > 1:
             utils.err("unable to diff the CIBs:\n" + stderr)
         if retval == 0:
-            print(
+            print_to_stderr(
                 "The new CIB is the same as the original CIB, nothing to push."
             )
             sys.exit(0)
 
         command = [
-            os.path.join(settings.pacemaker_binaries, "cibadmin"),
+            settings.cibadmin,
             "--patch",
             "--xml-pipe",
         ]
@@ -899,7 +879,7 @@ def cluster_push(lib, argv, modifiers):
         elif retval != 0:
             utils.err("unable to push cib\n" + output)
 
-    print("CIB updated")
+    print_to_stderr("CIB updated")
 
     if not modifiers.is_specified("--wait"):
         return
@@ -949,25 +929,25 @@ def cluster_edit(lib, argv, modifiers):
             scope_arg = ""
 
         editor = os.environ["EDITOR"]
-        tempcib = tempfile.NamedTemporaryFile(mode="w+", suffix=".pcs")
         cib = utils.get_cib(scope)
-        tempcib.write(cib)
-        tempcib.flush()
-        try:
-            subprocess.call([editor, tempcib.name])
-        except OSError:
-            utils.err("unable to open file with $EDITOR: " + editor)
+        with tempfile.NamedTemporaryFile(mode="w+", suffix=".pcs") as tempcib:
+            tempcib.write(cib)
+            tempcib.flush()
+            try:
+                subprocess.call([editor, tempcib.name])
+            except OSError:
+                utils.err("unable to open file with $EDITOR: " + editor)
 
-        tempcib.seek(0)
-        newcib = "".join(tempcib.readlines())
-        if newcib == cib:
-            print("CIB not updated, no changes detected")
-        else:
-            cluster_push(
-                lib,
-                [arg for arg in [tempcib.name, scope_arg] if arg],
-                modifiers.get_subset("--wait", "--config", "-f"),
-            )
+            tempcib.seek(0)
+            newcib = "".join(tempcib.readlines())
+            if newcib == cib:
+                print_to_stderr("CIB not updated, no changes detected")
+            else:
+                cluster_push(
+                    lib,
+                    [arg for arg in [tempcib.name, scope_arg] if arg],
+                    modifiers.get_subset("--wait", "--config", "-f"),
+                )
 
     else:
         utils.err("$EDITOR environment variable is not set")
@@ -1004,14 +984,13 @@ def get_cib(lib, argv, modifiers):
     if not filename:
         print(utils.get_cib(scope).rstrip())
     else:
+        output = utils.get_cib(scope)
+        if not output:
+            utils.err("No data in the CIB")
         try:
-            cib_file = open(filename, "w")
-            output = utils.get_cib(scope)
-            if output != "":
+            with open(filename, "w") as cib_file:
                 cib_file.write(output)
-            else:
-                utils.err("No data in the CIB")
-        except IOError as e:
+        except EnvironmentError as e:
             utils.err(
                 "Unable to write to file '%s', %s" % (filename, e.strerror)
             )
@@ -1061,7 +1040,7 @@ class RemoteAddNodes(RunRemotelyBase):
             if output["status"] == "success":
                 self._success = True
             elif output["status"] != "error":
-                print("Error: {}".format(output["status_msg"]))
+                print_to_stderr("Error: {}".format(output["status_msg"]))
 
         except (KeyError, json.JSONDecodeError):
             self._report(
@@ -1135,9 +1114,9 @@ def node_add_outside_cluster(lib, argv, modifiers):
         raise LibraryError()
 
     com_cmd = RemoteAddNodes(report_processor, target_list[0], cmd_data)
-    was_successfull = run_com_cmd(lib_env.get_node_communicator(), com_cmd)
+    was_successful = run_com_cmd(lib_env.get_node_communicator(), com_cmd)
 
-    if not was_successfull:
+    if not was_successful:
         raise LibraryError()
 
 
@@ -1188,14 +1167,14 @@ def cluster_uidgid(lib, argv, modifiers, silent_list=False):
                 print(line)
                 found = True
         if not found and not silent_list:
-            print("No uidgids configured")
+            print_to_stderr("No uidgids configured")
         return
 
     command = argv.pop(0)
     uid = ""
     gid = ""
 
-    if command in {"add", "delete", "remove", "rm"} and argv:
+    if command in {"add", "delete", "remove"} and argv:
         for arg in argv:
             if arg.find("=") == -1:
                 utils.err(
@@ -1217,33 +1196,23 @@ def cluster_uidgid(lib, argv, modifiers, silent_list=False):
 
         if command == "add":
             utils.write_uid_gid_file(uid, gid)
-        elif command in {"delete", "remove", "rm"}:
-            if command == "rm":
-                sys.stderr.write(
-                    "'pcs cluster uidgid rm' has been deprecated, use 'pcs "
-                    "cluster uidgid delete' or 'pcs cluster uidgid remove' "
-                    "instead\n"
-                )
+        elif command in {"delete", "remove"}:
             file_removed = utils.remove_uid_gid_file(uid, gid)
             if not file_removed:
                 utils.err(
                     "no uidgid files with uid=%s and gid=%s found" % (uid, gid)
                 )
-
-    else:
-        # The hint is defined to print error messages which point users to the
-        # changes section in pcs manpage.
-        # To be removed in the next significant version.
-        raise CmdLineInputError(
-            hint=(
-                msg_command_replaced(
-                    "pcs cluster uidgid delete",
-                    "pcs cluster uidgid remove",
-                )
-                if command == "rm"
-                else None
-            )
+    elif command == "rm":
+        # To be removed in the next significant version
+        raise_command_replaced(
+            [
+                "pcs cluster uidgid delete",
+                "pcs cluster uidgid remove",
+            ],
+            pcs_version="0.11",
         )
+    else:
+        raise CmdLineInputError()
 
 
 def cluster_get_corosync_conf(lib, argv, modifiers):
@@ -1281,7 +1250,7 @@ def cluster_reload(lib, argv, modifiers):
     output, retval = utils.reloadCorosync()
     if retval != 0 or "invalid option" in output:
         utils.err(output.rstrip())
-    print("Corosync reloaded")
+    print_to_stderr("Corosync reloaded")
 
 
 # Completely tear down the cluster & remove config files
@@ -1294,16 +1263,27 @@ def cluster_destroy(lib, argv, modifiers):
     """
     # pylint: disable=bare-except
     del lib
-    modifiers.ensure_only_supported("--all", "--request-timeout")
+    modifiers.ensure_only_supported("--all", "--request-timeout", "--force")
     if argv:
         raise CmdLineInputError()
+    if utils.is_run_interactive():
+        warn(
+            "It is recommended to run 'pcs cluster stop' before "
+            "destroying the cluster."
+        )
+        if not utils.get_continue_confirmation_or_force(
+            "This would kill all cluster processes and then PERMANENTLY remove "
+            "cluster state and configuration",
+            modifiers.get("--force"),
+        ):
+            return
     if modifiers.get("--all"):
         # load data
         cib = None
         lib_env = utils.get_lib_env()
         try:
             cib = lib_env.get_cib()
-        except LibraryError as e:
+        except LibraryError:
             warn(
                 "Unable to load CIB to get guest and remote nodes from it, "
                 "those nodes will not be deconfigured."
@@ -1341,12 +1321,15 @@ def cluster_destroy(lib, argv, modifiers):
         # destroy full-stack nodes
         destroy_cluster(corosync_nodes)
     else:
-        print("Shutting down pacemaker/corosync services...")
+        print_to_stderr("Shutting down pacemaker/corosync services...")
         for service in ["pacemaker", "corosync-qdevice", "corosync"]:
-            # Returns an error if a service is not running. It is safe to
-            # ignore it since we want it not to be running anyways.
-            utils.stop_service(service)
-        print("Killing any remaining services...")
+            try:
+                utils.stop_service(service)
+            except LibraryError:
+                # It is safe to ignore error since we want it not to be running
+                # anyways.
+                pass
+        print_to_stderr("Killing any remaining services...")
         kill_local_cluster_services()
         try:
             utils.disableServices()
@@ -1355,15 +1338,18 @@ def cluster_destroy(lib, argv, modifiers):
             # for now
             pass
         try:
-            disable_service(utils.cmd_runner(), lib_sbd.get_sbd_service_name())
+            service_manager = utils.get_service_manager()
+            service_manager.disable(
+                lib_sbd.get_sbd_service_name(service_manager)
+            )
         except:
             # it's not a big deal if sbd disable fails
             pass
 
-        print("Removing all cluster configuration files...")
+        print_to_stderr("Removing all cluster configuration files...")
         dummy_output, dummy_retval = utils.run(
             [
-                "/bin/rm",
+                settings.rm_executable,
                 "-f",
                 settings.corosync_conf_file,
                 settings.corosync_authkey_file,
@@ -1383,12 +1369,12 @@ def cluster_destroy(lib, argv, modifiers):
         for name in state_files:
             dummy_output, dummy_retval = utils.run(
                 [
-                    "/usr/bin/find",
-                    "/var/lib/pacemaker",
+                    settings.find_executable,
+                    settings.pacemaker_local_state_dir,
                     "-name",
                     name,
                     "-exec",
-                    "/bin/rm",
+                    settings.rm_executable,
                     "-f",
                     "{}",
                     ";",
@@ -1481,7 +1467,7 @@ def cluster_report(lib, argv, modifiers):
         newoutput = newoutput + line + "\n"
     if retval != 0:
         utils.err(newoutput)
-    print(newoutput)
+    print_to_stderr(newoutput)
 
 
 def send_local_configs(
@@ -1535,10 +1521,7 @@ def cluster_auth_cmd(lib, argv, modifiers):
         "--corosync_conf", "--request-timeout", "-u", "-p"
     )
     if argv:
-        # The hint is defined to print error messages which point users to the
-        # changes section in pcs manpage.
-        # To be removed in the next significant version.
-        raise CmdLineInputError(hint=HINT_SYNTAX_CHANGE)
+        raise CmdLineInputError()
     lib_env = utils.get_lib_env()
     target_factory = lib_env.get_node_target_factory()
     cluster_node_list = lib_env.get_corosync_conf().get_nodes()
@@ -1550,8 +1533,8 @@ def cluster_auth_cmd(lib, argv, modifiers):
         else:
             missing_name = True
     if missing_name:
-        print(
-            "Warning: Skipping nodes which do not have their name defined in "
+        warn(
+            "Skipping nodes which do not have their name defined in "
             "corosync.conf, use the 'pcs host auth' command to authenticate "
             "them"
         )
@@ -1561,7 +1544,7 @@ def cluster_auth_cmd(lib, argv, modifiers):
         try:
             target_list.append(target_factory.get_target(node_name))
         except HostNotFound:
-            print("{}: Not authorized".format(node_name))
+            print_to_stderr("{}: Not authorized".format(node_name))
             not_authorized_node_name_list.append(node_name)
     com_cmd = CheckAuth(lib_env.report_processor)
     com_cmd.set_targets(target_list)
@@ -1582,7 +1565,7 @@ def cluster_auth_cmd(lib, argv, modifiers):
                     if node.addrs_plain():
                         not_auth_node_list.append(node)
                     else:
-                        print(
+                        print_to_stderr(
                             f"{node.name}: No addresses defined in "
                             "corosync.conf, use the 'pcs host auth' command to "
                             "authenticate the node"
@@ -1602,10 +1585,10 @@ def cluster_auth_cmd(lib, argv, modifiers):
         }
         utils.auth_hosts(nodes_to_auth_data)
     else:
-        print("Sending cluster config files to the nodes...")
+        print_to_stderr("Sending cluster config files to the nodes...")
         msgs = send_local_configs(cluster_node_names, force=True)
         for msg in msgs:
-            print("Warning: {0}".format(msg))
+            warn(msg)
 
 
 def _parse_node_options(
@@ -1678,13 +1661,19 @@ def cluster_setup(lib, argv, modifiers):
         as warnings
       * --no-keys-sync - do not create and distribute pcsd ssl cert and key,
         corosync and pacemaker authkeys
+      * --no-cluster-uuid - do not generate a cluster UUID during setup
       * --corosync_conf - corosync.conf file path, do not talk to cluster nodes
     """
     # pylint: disable=too-many-locals
     is_local = modifiers.is_specified("--corosync_conf")
 
-    allowed_options_common = ["--force"]
-    allowed_options_live = ["--wait", "--start", "--enable", "--no-keys-sync"]
+    allowed_options_common = ["--force", "--no-cluster-uuid"]
+    allowed_options_live = [
+        "--wait",
+        "--start",
+        "--enable",
+        "--no-keys-sync",
+    ]
     allowed_options_local = ["--corosync_conf", "--overwrite"]
     modifiers.ensure_only_supported(
         *(
@@ -1692,10 +1681,6 @@ def cluster_setup(lib, argv, modifiers):
             + allowed_options_live
             + allowed_options_local
         ),
-        # The hint is defined to print error messages which point users to the
-        # changes section in pcs manpage.
-        # To be removed in the next significant version.
-        hint_syntax_changed=modifiers.is_specified_any(["--local", "--name"]),
     )
     if is_local and modifiers.is_specified_any(allowed_options_live):
         raise CmdLineInputError(
@@ -1762,6 +1747,7 @@ def cluster_setup(lib, argv, modifiers):
             start=modifiers.get("--start"),
             enable=modifiers.get("--enable"),
             no_keys_sync=modifiers.get("--no-keys-sync"),
+            no_cluster_uuid=modifiers.is_specified("--no-cluster-uuid"),
             force_flags=force_flags,
         )
         return
@@ -1778,6 +1764,7 @@ def cluster_setup(lib, argv, modifiers):
         quorum_options=parse_args.prepare_options(
             parsed_args.get("quorum", [])
         ),
+        no_cluster_uuid=modifiers.is_specified("--no-cluster-uuid"),
         force_flags=force_flags,
     )
 
@@ -1789,28 +1776,23 @@ def cluster_setup(lib, argv, modifiers):
     overwrite = modifiers.is_specified("--overwrite")
     try:
         corosync_conf_file.write(corosync_conf_data, can_overwrite=overwrite)
-    # TODO do not use LibraryError
     except pcs_file.FileAlreadyExists as e:
-        raise LibraryError(
-            reports.ReportItem.error(
-                message=reports.messages.FileAlreadyExists(
-                    e.metadata.file_type_code,
-                    e.metadata.path,
-                ),
-                force_code=reports.codes.FORCE_OVERWRITE,
-            )
-        ) from e
+        utils.err(
+            reports.messages.FileAlreadyExists(
+                e.metadata.file_type_code,
+                e.metadata.path,
+            ).message
+            + ", use --overwrite to overwrite existing file(s)"
+        )
     except pcs_file.RawFileError as e:
-        raise LibraryError(
-            reports.ReportItem.error(
-                reports.messages.FileIoError(
-                    e.metadata.file_type_code,
-                    e.action,
-                    e.reason,
-                    file_path=e.metadata.path,
-                )
-            )
-        ) from e
+        utils.err(
+            reports.messages.FileIoError(
+                e.metadata.file_type_code,
+                e.action,
+                e.reason,
+                file_path=e.metadata.path,
+            ).message
+        )
 
 
 def config_update(
@@ -1833,35 +1815,17 @@ def config_update(
             parse_args.prepare_options(parsed_args["totem"]),
         )
         return
-    corosync_conf_file = pcs_file.RawFile(
-        file_metadata.for_file_type(
-            file_type_codes.COROSYNC_CONF, modifiers.get("--corosync_conf")
-        )
-    )
 
-    try:
-        corosync_conf_file.write(
-            lib.cluster.config_update_local(
-                corosync_conf_file.read(),
-                parse_args.prepare_options(parsed_args["transport"]),
-                parse_args.prepare_options(parsed_args["compression"]),
-                parse_args.prepare_options(parsed_args["crypto"]),
-                parse_args.prepare_options(parsed_args["totem"]),
-            ),
-            can_overwrite=True,
-        )
-    except pcs_file.RawFileError as e:
-        # TODO do not use LibraryError
-        raise LibraryError(
-            reports.ReportItem.error(
-                reports.messages.FileIoError(
-                    e.metadata.file_type_code,
-                    e.action,
-                    e.reason,
-                    file_path=e.metadata.path,
-                )
-            )
-        ) from e
+    _corosync_conf_local_cmd_call(
+        modifiers.get("--corosync_conf"),
+        lambda corosync_conf_content: lib.cluster.config_update_local(
+            corosync_conf_content,
+            parse_args.prepare_options(parsed_args["transport"]),
+            parse_args.prepare_options(parsed_args["compression"]),
+            parse_args.prepare_options(parsed_args["crypto"]),
+            parse_args.prepare_options(parsed_args["totem"]),
+        ),
+    )
 
 
 def _format_options(label: str, options: Mapping[str, str]) -> List[str]:
@@ -1869,7 +1833,7 @@ def _format_options(label: str, options: Mapping[str, str]) -> List[str]:
     if options:
         output.append(f"{label}:")
         output.extend(
-            indent(f"{opt}: {val}" for opt, val in sorted(options.items()))
+            indent([f"{opt}: {val}" for opt, val in sorted(options.items())])
         )
     return output
 
@@ -1893,18 +1857,12 @@ def config_show(
       * --corosync_conf - corosync.conf file path, do not talk to cluster nodes
       * --output-format - supported formats: text, cmd, json
     """
-    modifiers.ensure_only_supported("--corosync_conf", "--output-format")
+    modifiers.ensure_only_supported(
+        "--corosync_conf", output_format_supported=True
+    )
     if argv:
         raise CmdLineInputError()
-    output_format = modifiers.get("--output-format")
-    supported_formats = ["text", "cmd", "json"]
-    if not output_format in supported_formats:
-        raise CmdLineInputError(
-            (
-                "Unknown value '{}' for '--output-format' option. Supported "
-                "values are: {}"
-            ).format(output_format, format_list(supported_formats))
-        )
+    output_format = modifiers.get_output_format()
     corosync_conf_dto = lib.cluster.get_corosync_conf_struct()
     if output_format == "cmd":
         if corosync_conf_dto.quorum_device is not None:
@@ -1921,10 +1879,10 @@ def config_show(
 
 
 def _config_get_text(corosync_conf: CorosyncConfDto) -> List[str]:
-    lines = [
-        f"Cluster Name: {corosync_conf.cluster_name}",
-        "Transport: {}".format(corosync_conf.transport.lower()),
-    ]
+    lines = [f"Cluster Name: {corosync_conf.cluster_name}"]
+    if corosync_conf.cluster_uuid:
+        lines.append(f"Cluster UUID: {corosync_conf.cluster_uuid}")
+    lines.append("Transport: {}".format(corosync_conf.transport.lower()))
     lines.extend(_format_nodes(corosync_conf.nodes))
     if corosync_conf.links_options:
         lines.append("Links:")
@@ -2024,6 +1982,8 @@ def _config_get_cmd(corosync_conf: CorosyncConfDto) -> List[str]:
     lines.extend(indent(transport))
     lines.extend(_section_to_lines(corosync_conf.totem_options, "totem"))
     lines.extend(_section_to_lines(corosync_conf.quorum_options, "quorum"))
+    if not corosync_conf.cluster_uuid:
+        lines.extend(indent(["--no-cluster-uuid"]))
     return lines
 
 
@@ -2182,3 +2142,31 @@ def link_update(lib, argv, modifiers):
         parse_args.prepare_options(parsed["options"]),
         force_flags=force_flags,
     )
+
+
+def generate_uuid(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+):
+    """
+    Options:
+      * --force - allow to rewrite an existing UUID in corosync.conf
+      * --corosync_conf - corosync.conf file path, do not talk to cluster nodes
+    """
+    modifiers.ensure_only_supported("--force", "--corosync_conf")
+    if argv:
+        raise CmdLineInputError()
+
+    force_flags = []
+    if modifiers.get("--force"):
+        force_flags.append(reports.codes.FORCE)
+
+    if not modifiers.is_specified("--corosync_conf"):
+        lib.cluster.generate_cluster_uuid(force_flags=force_flags)
+        return
+
+    _corosync_conf_local_cmd_call(
+        modifiers.get("--corosync_conf"),
+        lambda corosync_conf_content: lib.cluster.generate_cluster_uuid_local(
+            corosync_conf_content, force_flags=force_flags
+        ),
+    )
