@@ -44,6 +44,9 @@ AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE = M("AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE")
 AGENT_NAME_GUESS_FOUND_NONE = M("AGENT_NAME_GUESS_FOUND_NONE")
 AGENT_NAME_GUESSED = M("AGENT_NAME_GUESSED")
 AGENT_SELF_VALIDATION_INVALID_DATA = M("AGENT_SELF_VALIDATION_INVALID_DATA")
+AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED = M(
+    "AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED"
+)
 AGENT_SELF_VALIDATION_RESULT = M("AGENT_SELF_VALIDATION_RESULT")
 BAD_CLUSTER_STATE_FORMAT = M("BAD_CLUSTER_STATE_FORMAT")
 BOOTH_ADDRESS_DUPLICATION = M("BOOTH_ADDRESS_DUPLICATION")
@@ -167,6 +170,7 @@ COROSYNC_CONFIG_DISTRIBUTION_NODE_ERROR = M(
     "COROSYNC_CONFIG_DISTRIBUTION_NODE_ERROR"
 )
 COROSYNC_CONFIG_DISTRIBUTION_STARTED = M("COROSYNC_CONFIG_DISTRIBUTION_STARTED")
+COROSYNC_CONFIG_MISSING_IDS_OF_NODES = M("COROSYNC_CONFIG_MISSING_IDS_OF_NODES")
 COROSYNC_CONFIG_MISSING_NAMES_OF_NODES = M(
     "COROSYNC_CONFIG_MISSING_NAMES_OF_NODES"
 )
@@ -349,14 +353,16 @@ PREREQUISITE_OPTION_IS_MISSING = M("PREREQUISITE_OPTION_IS_MISSING")
 QDEVICE_ALREADY_DEFINED = M("QDEVICE_ALREADY_DEFINED")
 QDEVICE_ALREADY_INITIALIZED = M("QDEVICE_ALREADY_INITIALIZED")
 QDEVICE_CERTIFICATE_ACCEPTED_BY_NODE = M("QDEVICE_CERTIFICATE_ACCEPTED_BY_NODE")
+QDEVICE_CERTIFICATE_BAD_FORMAT = M("QDEVICE_CERTIFICATE_BAD_FORMAT")
 QDEVICE_CERTIFICATE_DISTRIBUTION_STARTED = M(
     "QDEVICE_CERTIFICATE_DISTRIBUTION_STARTED"
 )
+QDEVICE_CERTIFICATE_IMPORT_ERROR = M("QDEVICE_CERTIFICATE_IMPORT_ERROR")
+QDEVICE_CERTIFICATE_READ_ERROR = M("QDEVICE_CERTIFICATE_READ_ERROR")
 QDEVICE_CERTIFICATE_REMOVAL_STARTED = M("QDEVICE_CERTIFICATE_REMOVAL_STARTED")
 QDEVICE_CERTIFICATE_REMOVED_FROM_NODE = M(
     "QDEVICE_CERTIFICATE_REMOVED_FROM_NODE"
 )
-QDEVICE_CERTIFICATE_IMPORT_ERROR = M("QDEVICE_CERTIFICATE_IMPORT_ERROR")
 QDEVICE_CERTIFICATE_SIGN_ERROR = M("QDEVICE_CERTIFICATE_SIGN_ERROR")
 QDEVICE_DESTROY_ERROR = M("QDEVICE_DESTROY_ERROR")
 QDEVICE_DESTROY_SUCCESS = M("QDEVICE_DESTROY_SUCCESS")
