@@ -1,11 +1,24 @@
-from enum import auto
+from collections.abc import Set
+from enum import (
+    Enum,
+    auto,
+)
+from typing import (
+    Generator,
+    MutableSequence,
+    Union,
+)
 
-from pcs.common.tools import AutoNameEnum
+StringSequence = Union[MutableSequence[str], tuple[str, ...]]
+StringCollection = Union[StringSequence, Set[str]]
+StringIterable = Union[StringCollection, Generator[str, None, None]]
 
 
-class CibNvsetType(AutoNameEnum):
-    INSTANCE = auto()
-    META = auto()
+class AutoNameEnum(str, Enum):
+    def _generate_next_value_(name, start, count, last_values):  # type: ignore
+        # pylint: disable=no-self-argument
+        del start, count, last_values
+        return name
 
 
 class CibRuleExpressionType(AutoNameEnum):
@@ -57,3 +70,10 @@ class CorosyncTransportType(AutoNameEnum):
             return cls(transport.upper())
         except ValueError:
             raise UnknownCorosyncTransportTypeException(transport) from None
+
+
+class CorosyncNodeAddressType(Enum):
+    IPV4 = "IPv4"
+    IPV6 = "IPv6"
+    FQDN = "FQDN"
+    UNRESOLVABLE = "unresolvable"
