@@ -1,60 +1,58 @@
 import sys
-from collections import defaultdict
-from os.path import isfile
 import xml.dom.minidom
-from xml.dom.minidom import parseString
+from collections import defaultdict
 from enum import Enum
+from os.path import isfile
+from xml.dom.minidom import parseString
 
+import pcs.cli.constraint_colocation.command as colocation_command
+import pcs.cli.constraint_order.command as order_command
+from pcs import rule as rule_utils
 from pcs import (
-    rule as rule_utils,
     settings,
-    usage,
     utils,
 )
 from pcs.cli.common import parse_args
 from pcs.cli.common.errors import CmdLineInputError
-import pcs.cli.constraint_colocation.command as colocation_command
-import pcs.cli.constraint_order.command as order_command
 from pcs.cli.constraint_ticket import command as ticket_command
 from pcs.cli.reports import process_library_reports
-from pcs.cli.reports.output import warn
+from pcs.cli.reports.output import (
+    deprecation_warning,
+    error,
+    print_to_stderr,
+    warn,
+)
 from pcs.common import (
     const,
     pacemaker,
     reports,
 )
 from pcs.common.reports import ReportItem
-from pcs.common.reports.constraints import (
-    colocation as colocation_format,
-    order as order_format,
-)
+from pcs.common.reports.constraints import colocation as colocation_format
+from pcs.common.reports.constraints import order as order_format
 from pcs.common.str_tools import format_list
-from pcs.lib.cib.constraint import resource_set
 from pcs.lib.cib.constraint.order import ATTRIB as order_attrib
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.pacemaker.values import (
-    sanitize_id,
     SCORE_INFINITY,
+    sanitize_id,
 )
 
 # pylint: disable=too-many-branches, too-many-statements
 # pylint: disable=invalid-name, too-many-nested-blocks
 # pylint: disable=too-many-locals, too-many-lines
 
-OPTIONS_ACTION = resource_set.ATTRIB["action"]
-
-DEFAULT_ACTION = "start"
+DEFAULT_ACTION = const.PCMK_ACTION_START
 DEFAULT_ROLE = const.PCMK_ROLE_STARTED
 
 OPTIONS_SYMMETRICAL = order_attrib["symmetrical"]
-OPTIONS_KIND = order_attrib["kind"]
 
 LOCATION_NODE_VALIDATION_SKIP_MSG = (
     "Validation for node existence in the cluster will be skipped"
 )
 CRM_RULE_MISSING_MSG = (
-    "Warning: crm_rule is not available, therefore expired constraints may be "
-    "shown. Consider upgrading pacemaker.\n"
+    "crm_rule is not available, therefore expired constraints may be "
+    "shown. Consider upgrading pacemaker."
 )
 
 RESOURCE_TYPE_RESOURCE = "resource"
@@ -95,7 +93,7 @@ def constraint_location_cmd(lib, argv, modifiers):
         else:
             raise CmdLineInputError()
     except CmdLineInputError as e:
-        utils.exit_on_cmdline_input_errror(
+        utils.exit_on_cmdline_input_error(
             e, "constraint", ["location", sub_cmd]
         )
 
@@ -118,14 +116,13 @@ def constraint_order_cmd(lib, argv, modifiers):
         else:
             order_start(lib, [sub_cmd] + argv, modifiers)
     except CmdLineInputError as e:
-        utils.exit_on_cmdline_input_errror(e, "constraint", ["order", sub_cmd])
+        utils.exit_on_cmdline_input_error(e, "constraint", ["order", sub_cmd])
 
 
 def constraint_show(lib, argv, modifiers):
-    warn(
+    deprecation_warning(
         "This command is deprecated and will be removed. "
-        "Please use 'pcs constraint config' instead.",
-        stderr=True,
+        "Please use 'pcs constraint config' instead."
     )
     return constraint_config_cmd(lib, argv, modifiers)
 
@@ -178,7 +175,7 @@ def colocation_rm(lib, argv, modifiers):
     if elementFound:
         utils.replace_cib_configuration(dom)
     else:
-        print("No matching resources found in ordering list")
+        raise error("No matching resources found in ordering list")
 
 
 def _validate_constraint_resource(cib_dom, resource_id):
@@ -191,6 +188,15 @@ def _validate_constraint_resource(cib_dom, resource_id):
         utils.err(resource_error)
 
 
+def _validate_resources_not_in_same_group(cib_dom, resource1, resource2):
+    if not utils.validate_resources_not_in_same_group(
+        cib_dom, resource1, resource2
+    ):
+        utils.err(
+            "Cannot create an order constraint for resources in the same group"
+        )
+
+
 # Syntax: colocation add [role] <src> with [role] <tgt> [score] [options]
 # possible commands:
 #        <src> with        <tgt> [score] [options]
@@ -242,6 +248,7 @@ def colocation_add(lib, argv, modifiers):
                     role, format_list(const.PCMK_ROLES)
                 )
             )
+        utils.print_depracation_warning_for_legacy_roles(role)
         return pacemaker.role.get_value_for_cib(
             role_cleaned, new_roles_supported
         )
@@ -432,7 +439,7 @@ def order_start(lib, argv, modifiers):
     first_action = DEFAULT_ACTION
     then_action = DEFAULT_ACTION
     action = argv[0]
-    if action in OPTIONS_ACTION:
+    if action in const.PCMK_ACTIONS:
         first_action = action
         argv.pop(0)
 
@@ -444,7 +451,7 @@ def order_start(lib, argv, modifiers):
         raise CmdLineInputError()
 
     action = argv[0]
-    if action in OPTIONS_ACTION:
+    if action in const.PCMK_ACTIONS:
         then_action = action
         argv.pop(0)
 
@@ -480,6 +487,8 @@ def _order_add(resource1, resource2, options_list, modifiers):
     _validate_constraint_resource(cib_dom, resource1)
     _validate_constraint_resource(cib_dom, resource2)
 
+    _validate_resources_not_in_same_group(cib_dom, resource1, resource2)
+
     order_options = []
     id_specified = False
     sym = None
@@ -565,17 +574,7 @@ def _order_add(resource1, resource2, options_list, modifiers):
                     ]
                 )
             )
-    print(
-        "Adding "
-        + resource1
-        + " "
-        + resource2
-        + " ("
-        + scorekind
-        + ")"
-        + options
-    )
-
+    print_to_stderr(f"Adding {resource1} {resource2} ({scorekind}){options}")
     utils.replace_cib_configuration(dom)
 
 
@@ -604,10 +603,9 @@ def order_find_duplicates(dom, constraint_el):
 
 
 def location_show(lib, argv, modifiers):
-    warn(
+    deprecation_warning(
         "This command is deprecated and will be removed. "
-        "Please use 'pcs constraint location config' instead.",
-        stderr=True,
+        "Please use 'pcs constraint location config' instead."
     )
     return location_config_cmd(lib, argv, modifiers)
 
@@ -680,7 +678,7 @@ def location_lines(
 
     if not isfile(settings.crm_rule):
         if verify_expiration:
-            sys.stderr.write(CRM_RULE_MISSING_MSG)
+            warn(CRM_RULE_MISSING_MSG)
         verify_expiration = False
 
     all_lines.append("Location Constraints:")
@@ -697,7 +695,9 @@ def location_lines(
         lc_id = rsc_loc.getAttribute("id")
         lc_node = rsc_loc.getAttribute("node")
         lc_score = rsc_loc.getAttribute("score")
-        lc_role = rsc_loc.getAttribute("role")
+        lc_role = pacemaker.role.get_value_primary(
+            rsc_loc.getAttribute("role").capitalize()
+        )
         lc_resource_discovery = rsc_loc.getAttribute("resource-discovery")
 
         for child in rsc_loc.childNodes:
@@ -824,7 +824,11 @@ def _hashtable_to_lines(hash_label, hash_type, hash_key, show_detail):
                 ]
                 line_parts.append(f"(score:{options['score']})")
                 if options["role"]:
-                    line_parts.append(f"(role:{options['role']})")
+                    line_parts.append(
+                        "(role:{})".format(
+                            pacemaker.role.get_value_primary(options["role"])
+                        )
+                    )
                 if options["resource-discovery"]:
                     line_parts.append(
                         "(resource-discovery={0})".format(
@@ -1176,8 +1180,7 @@ def location_rule(lib, argv, modifiers):
     del lib
     modifiers.ensure_only_supported("-f", "--force")
     if len(argv) < 3:
-        usage.constraint(["location", "rule"])
-        sys.exit(1)
+        raise CmdLineInputError()
 
     rsc_type, rsc_value = parse_args.parse_typed_arg(
         argv.pop(0),
@@ -1439,7 +1442,7 @@ def remove_constraints_containing(
     )
     for c in constraints:
         if output:
-            print("Removing Constraint - " + c)
+            print_to_stderr(f"Removing Constraint - {c}")
         if constraints_element is not None:
             constraint_rm(
                 lib,
@@ -1462,17 +1465,24 @@ def remove_constraints_containing(
                 pn = c.parentNode
                 pn.removeChild(c)
                 if output:
-                    print(
-                        "Removing %s from set %s"
-                        % (resource_id, pn.getAttribute("id"))
+                    print_to_stderr(
+                        "Removing {} from set {}".format(
+                            resource_id, pn.getAttribute("id")
+                        )
                     )
                 if pn.getElementsByTagName("resource_ref").length == 0:
-                    print("Removing set %s" % pn.getAttribute("id"))
+                    print_to_stderr(
+                        "Removing set {}".format(pn.getAttribute("id"))
+                    )
                     pn2 = pn.parentNode
                     pn2.removeChild(pn)
                     if pn2.getElementsByTagName("resource_set").length == 0:
                         pn2.parentNode.removeChild(pn2)
-                        print("Removing constraint %s" % pn2.getAttribute("id"))
+                        print_to_stderr(
+                            "Removing constraint {}".format(
+                                pn2.getAttribute("id")
+                            )
+                        )
         if passed_dom:
             return dom
         utils.replace_cib_configuration(dom)
@@ -1499,10 +1509,7 @@ def find_constraints_containing(resource_id, passed_dom=None):
             break
 
     if resource_match:
-        if (
-            resource_match.parentNode.tagName == "master"
-            or resource_match.parentNode.tagName == "clone"
-        ):
+        if resource_match.parentNode.tagName in ("master", "clone"):
             constraints_found, set_constraints = find_constraints_containing(
                 resource_match.parentNode.getAttribute("id"), dom
             )
@@ -1539,7 +1546,9 @@ def remove_constraints_containing_node(dom, node, output=False):
     """
     for constraint in find_constraints_containing_node(dom, node):
         if output:
-            print("Removing Constraint - %s" % constraint.getAttribute("id"))
+            print_to_stderr(
+                "Removing Constraint - {}".format(constraint.getAttribute("id"))
+            )
         constraint.parentNode.removeChild(constraint)
     return dom
 
@@ -1642,11 +1651,13 @@ def constraint_rule(lib, argv, modifiers):
             for rule in loc_con:
                 if rule.get("id") == temp_id:
                     if len(loc_con) > 1:
-                        print("Removing Rule: {0}".format(rule.get("id")))
+                        print_to_stderr(
+                            "Removing Rule: {0}".format(rule.get("id"))
+                        )
                         loc_con.remove(rule)
                         found = True
                     else:
-                        print(
+                        print_to_stderr(
                             "Removing Constraint: {0}".format(loc_con.get("id"))
                         )
                         constraints.remove(loc_con)
