@@ -22,11 +22,15 @@ from pcs.daemon import (
 from pcs.daemon.app import (
     api_v1,
     api_v2,
+    auth,
     sinatra_remote,
     sinatra_ui,
     ui,
 )
-from pcs.daemon.app.common import RedirectHandler
+from pcs.daemon.app.common import (
+    Http404Handler,
+    RedirectHandler,
+)
 from pcs.daemon.async_tasks.scheduler import (
     Scheduler,
     SchedulerConfig,
@@ -88,6 +92,7 @@ def configure_app(
 
         routes = api_v2.get_routes(async_scheduler, auth_provider)
         routes.extend(api_v1.get_routes(async_scheduler, auth_provider))
+        routes.extend(auth.get_routes(auth_provider))
         routes.extend(
             sinatra_remote.get_routes(
                 ruby_pcsd_wrapper,
@@ -115,7 +120,9 @@ def configure_app(
                 )
             )
 
-        return Application(routes, debug=debug)
+        return Application(
+            routes, debug=debug, default_handler_class=Http404Handler
+        )
 
     return make_app
 
