@@ -1,14 +1,18 @@
+from typing import Mapping
+
+from lxml.etree import _Element
+
 from pcs.common import reports
 from pcs.common.reports.item import ReportItem
+from pcs.common.types import StringCollection
 from pcs.lib import validate
-from pcs.lib.cib.tools import does_id_exist
 from pcs.lib.cib.node import PacemakerNode
 from pcs.lib.cib.nvpair import (
-    has_meta_attribute,
     arrange_first_meta_attributes,
     get_meta_attribute_value,
+    has_meta_attribute,
 )
-
+from pcs.lib.cib.tools import does_id_exist
 
 # TODO pcs currently does not care about multiple meta_attributes and here
 # we don't care as well
@@ -20,8 +24,12 @@ GUEST_OPTIONS = [
 
 
 def validate_conflicts(
-    tree, existing_nodes_names, existing_nodes_addrs, node_name, options
-):
+    tree: _Element,
+    existing_nodes_names: StringCollection,
+    existing_nodes_addrs: StringCollection,
+    node_name: str,
+    options: Mapping[str, str],
+) -> reports.ReportItemList:
     report_list = []
     if (
         does_id_exist(tree, node_name)
@@ -206,7 +214,7 @@ def find_node_list(tree):
 
 def find_node_resources(resources_section, node_identifier):
     """
-    Return list of etree.Eleent primitives that are guest nodes.
+    Return list of etree.Element primitives that are guest nodes.
 
     etree.Element resources_section is a researched element
     string node_identifier could be id of resource, node name or node address
@@ -215,7 +223,7 @@ def find_node_resources(resources_section, node_identifier):
         """
         .//primitive[
             (
-                @id="{0}"
+                @id=$node_id
                 and
                 meta_attributes[
                     nvpair[
@@ -240,12 +248,11 @@ def find_node_resources(resources_section, node_identifier):
                         @name="remote-node"
                     )
                     and
-                    @value="{0}"
+                    @value=$node_id
                 ]
             ]
         ]
-    """.format(
-            node_identifier
-        )
+    """,
+        node_id=node_identifier,
     )
     return resources
