@@ -1,23 +1,32 @@
 import base64
-from functools import partial
 import os.path
-from typing import Optional
-
-from pcs.common.services.errors import ManageServiceError
+from functools import partial
+from typing import (
+    Optional,
+    cast,
+)
 
 from pcs import settings
-from pcs.common import file_type_codes
-from pcs.common import reports
-from pcs.common.file import FileAlreadyExists, RawFileError
+from pcs.common import (
+    file_type_codes,
+    reports,
+)
+from pcs.common.file import (
+    FileAlreadyExists,
+    RawFileError,
+)
 from pcs.common.reports import ReportProcessor
 from pcs.common.reports import codes as report_codes
 from pcs.common.reports.item import (
-    get_severity,
     ReportItem,
+    get_severity,
 )
+from pcs.common.services.errors import ManageServiceError
 from pcs.common.str_tools import join_multilines
-from pcs.lib import tools
-from pcs.lib.cib.resource import primitive, group
+from pcs.lib import (
+    tools,
+    validate,
+)
 from pcs.lib.booth import (
     config_files,
     config_validators,
@@ -25,7 +34,15 @@ from pcs.lib.booth import (
     resource,
     status,
 )
-from pcs.lib.cib.tools import get_resources, IdProvider
+from pcs.lib.cib.resource import (
+    group,
+    hierarchy,
+    primitive,
+)
+from pcs.lib.cib.tools import (
+    IdProvider,
+    get_resources,
+)
 from pcs.lib.communication.booth import (
     BoothGetConfig,
     BoothSendConfig,
@@ -34,10 +51,21 @@ from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
 from pcs.lib.file.instance import FileInstance
-from pcs.lib.file.raw_file import GhostFile, raw_file_error_report
+from pcs.lib.file.raw_file import (
+    GhostFile,
+    RealFile,
+    raw_file_error_report,
+)
 from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.node import get_existing_nodes_names
-from pcs.lib.resource_agent import find_valid_resource_agent_by_name
+from pcs.lib.resource_agent import (
+    ResourceAgentError,
+    ResourceAgentFacade,
+    ResourceAgentFacadeFactory,
+    ResourceAgentName,
+    UnableToGetAgentMetadata,
+    resource_agent_error_to_report_item,
+)
 from pcs.lib.services import (
     ensure_is_systemd,
     is_systemd,
@@ -56,8 +84,8 @@ def config_setup(
     create booth configuration
 
     env
-    list site_list -- site adresses of multisite
-    list arbitrator_list -- arbitrator adresses of multisite
+    list site_list -- site addresses of multisite
+    list arbitrator_list -- arbitrator addresses of multisite
     string instance_name -- booth instance name
     bool overwrite_existing -- allow overwriting existing files
     """
@@ -78,6 +106,12 @@ def config_setup(
     booth_conf = booth_env.create_facade(site_list, arbitrator_list)
     booth_conf.set_authfile(booth_env.key_path)
 
+    conf_dir = (
+        None
+        if booth_env.ghost_file_codes
+        else os.path.dirname(booth_env.config_path)
+    )
+
     try:
         booth_env.key.write_raw(
             tools.generate_binary_key(
@@ -102,7 +136,12 @@ def config_setup(
             )
         )
     except RawFileError as e:
-        report_processor.report(raw_file_error_report(e))
+        if conf_dir and not os.path.exists(conf_dir):
+            report_processor.report(
+                ReportItem.error(reports.messages.BoothPathNotExists(conf_dir))
+            )
+        else:
+            report_processor.report(raw_file_error_report(e))
     if report_processor.has_errors:
         raise LibraryError()
 
@@ -165,8 +204,8 @@ def config_destroy(
     if report_processor.has_errors:
         raise LibraryError()
 
+    authfile_path = None
     try:
-        authfile_path = None
         booth_conf = booth_env.config.read_to_facade()
         authfile_path = booth_conf.get_authfile()
     except RawFileError as e:
@@ -192,8 +231,14 @@ def config_destroy(
         authfile_dir, authfile_name = os.path.split(authfile_path)
         if (authfile_dir == settings.booth_config_dir) and authfile_name:
             try:
-                key_file = FileInstance.for_booth_key(authfile_name)
-                key_file.raw_file.remove(fail_if_file_not_found=False)
+                key_file = FileInstance.for_booth_key(
+                    authfile_name, ghost_file=False
+                )
+                # We're sure we have a RealFile instance as for_booth_key was
+                # called with ghost_file=False
+                cast(RealFile, key_file.raw_file).remove(
+                    fail_if_file_not_found=False
+                )
             except RawFileError as e:
                 report_processor.report(
                     raw_file_error_report(
@@ -224,6 +269,44 @@ def config_destroy(
         raise LibraryError()
 
 
+# TODO: remove once settings booth_enable_autfile_(set|unset)_enabled are removed
+def _config_set_enable_authfile(
+    env: LibraryEnvironment, value: bool, instance_name=None
+) -> None:
+    report_processor = env.report_processor
+    booth_env = env.get_booth_env(instance_name)
+    if (value and not settings.booth_enable_authfile_set_enabled) or (
+        not value and not settings.booth_enable_authfile_unset_enabled
+    ):
+        raise AssertionError()
+    try:
+        booth_conf = booth_env.config.read_to_facade()
+        booth_conf.set_option(
+            constants.AUTHFILE_FIX_OPTION, "yes" if value else ""
+        )
+        booth_env.config.write_facade(booth_conf, can_overwrite=True)
+    except RawFileError as e:
+        report_processor.report(raw_file_error_report(e))
+    except ParserErrorException as e:
+        report_processor.report_list(
+            booth_env.config.parser_exception_to_report_list(e)
+        )
+    if report_processor.has_errors:
+        raise LibraryError()
+
+
+def config_set_enable_authfile(
+    env: LibraryEnvironment, instance_name=None
+) -> None:
+    _config_set_enable_authfile(env, True, instance_name=instance_name)
+
+
+def config_unset_enable_authfile(
+    env: LibraryEnvironment, instance_name=None
+) -> None:
+    _config_set_enable_authfile(env, False, instance_name=instance_name)
+
+
 def config_text(env: LibraryEnvironment, instance_name=None, node_name=None):
     """
     get configuration in raw format
@@ -287,17 +370,22 @@ def config_ticket_add(
     booth_env = env.get_booth_env(instance_name)
     try:
         booth_conf = booth_env.config.read_to_facade()
+        options_pairs = validate.values_to_pairs(
+            options, config_validators.ticket_options_normalization()
+        )
         report_processor.report_list(
             config_validators.add_ticket(
                 booth_conf,
                 ticket_name,
-                options,
+                options_pairs,
                 allow_unknown_options=allow_unknown_options,
             )
         )
         if report_processor.has_errors:
             raise LibraryError()
-        booth_conf.add_ticket(ticket_name, options)
+        booth_conf.add_ticket(
+            ticket_name, validate.pairs_to_values(options_pairs)
+        )
         booth_env.config.write_facade(booth_conf, can_overwrite=True)
     except RawFileError as e:
         report_processor.report(raw_file_error_report(e))
@@ -344,17 +432,17 @@ def config_ticket_remove(
 
 def create_in_cluster(
     env: LibraryEnvironment,
-    ip,
-    instance_name=None,
-    allow_absent_resource_agent=False,
+    ip: str,
+    instance_name: Optional[str] = None,
+    allow_absent_resource_agent: bool = False,
 ):
     """
     Create group with ip resource and booth resource
 
     env -- provides all for communication with externals
-    string ip -- float ip address for the operation of the booth
-    string instance_name -- booth instance name
-    bool allow_absent_resource_agent -- allowing creating booth resource even
+    ip -- float ip address for the operation of the booth
+    instance_name -- booth instance name
+    allow_absent_resource_agent -- allowing creating booth resource even
         if its agent is not installed
     """
     report_processor = env.report_processor
@@ -386,33 +474,44 @@ def create_in_cluster(
     create_id = partial(
         resource.create_resource_id, resources_section, instance_name
     )
-    get_agent = partial(
-        find_valid_resource_agent_by_name,
+    create_primitive = partial(
+        primitive.create,
         env.report_processor,
         env.cmd_runner(),
-        allowed_absent=allow_absent_resource_agent,
+        resources_section,
+        id_provider,
+        enable_agent_self_validation=False,
     )
-    create_primitive = partial(
-        primitive.create, env.report_processor, resources_section, id_provider
-    )
-    into_booth_group = partial(
-        group.place_resource,
-        group.provide_group(resources_section, create_id("group")),
+    agent_factory = ResourceAgentFacadeFactory(
+        env.cmd_runner(), report_processor
     )
 
-    into_booth_group(
-        create_primitive(
-            create_id("ip"),
-            get_agent("ocf:heartbeat:IPaddr2"),
-            instance_attributes={"ip": ip},
-        )
-    )
-    into_booth_group(
-        create_primitive(
-            create_id("service"),
-            get_agent("ocf:pacemaker:booth-site"),
-            instance_attributes={"config": booth_env.config_path},
-        )
+    # Group id validation is not needed since create_id creates a new unique
+    # booth group identifier
+    hierarchy.move_resources_to_group(
+        group.append_new(resources_section, create_id("group")),
+        [
+            create_primitive(
+                create_id("ip"),
+                _get_agent_facade(
+                    env.report_processor,
+                    agent_factory,
+                    allow_absent_resource_agent,
+                    ResourceAgentName("ocf", "heartbeat", "IPaddr2"),
+                ),
+                instance_attributes={"ip": ip},
+            ),
+            create_primitive(
+                create_id("service"),
+                _get_agent_facade(
+                    env.report_processor,
+                    agent_factory,
+                    allow_absent_resource_agent,
+                    ResourceAgentName("ocf", "pacemaker", "booth-site"),
+                ),
+                instance_attributes={"config": booth_env.config_path},
+            ),
+        ],
     )
 
     env.push_cib()
@@ -753,6 +852,7 @@ def pull_config(env: LibraryEnvironment, node_name, instance_name=None):
     booth_env = env.get_booth_env(instance_name)
     instance_name = booth_env.instance_name
     _ensure_live_env(env, booth_env)
+    conf_dir = os.path.dirname(booth_env.config_path)
 
     env.report_processor.report(
         ReportItem.info(
@@ -796,7 +896,12 @@ def pull_config(env: LibraryEnvironment, node_name, instance_name=None):
             )
         )
     except RawFileError as e:
-        report_processor.report(raw_file_error_report(e))
+        if not os.path.exists(conf_dir):
+            report_processor.report(
+                ReportItem.error(reports.messages.BoothPathNotExists(conf_dir))
+            )
+        else:
+            report_processor.report(raw_file_error_report(e))
     except KeyError as e:
         raise LibraryError(
             ReportItem.error(reports.messages.InvalidResponseFormat(node_name))
@@ -815,6 +920,11 @@ def get_status(env: LibraryEnvironment, instance_name=None):
     booth_env = env.get_booth_env(instance_name)
     _ensure_live_env(env, booth_env)
     instance_name = booth_env.instance_name
+    report_msg = status.check_authfile_misconfiguration(
+        booth_env, env.report_processor
+    )
+    if report_msg:
+        env.report_processor.report(reports.ReportItem.warning(report_msg))
     return {
         "status": status.get_daemon_status(env.cmd_runner(), instance_name),
         "ticket": status.get_tickets_status(env.cmd_runner(), instance_name),
@@ -880,3 +990,34 @@ def _ensure_live_env(env: LibraryEnvironment, booth_env):
         raise LibraryError(
             ReportItem.error(reports.messages.LiveEnvironmentRequired(not_live))
         )
+
+
+def _get_agent_facade(
+    report_processor: reports.ReportProcessor,
+    factory: ResourceAgentFacadeFactory,
+    allow_absent_agent: bool,
+    name: ResourceAgentName,
+) -> ResourceAgentFacade:
+    try:
+        return factory.facade_from_parsed_name(name)
+    except UnableToGetAgentMetadata as e:
+        if allow_absent_agent:
+            report_processor.report(
+                resource_agent_error_to_report_item(
+                    e, reports.ReportItemSeverity.warning()
+                )
+            )
+            return factory.void_facade_from_parsed_name(name)
+        report_processor.report(
+            resource_agent_error_to_report_item(
+                e, reports.ReportItemSeverity.error(reports.codes.FORCE)
+            )
+        )
+        raise LibraryError() from e
+    except ResourceAgentError as e:
+        report_processor.report(
+            resource_agent_error_to_report_item(
+                e, reports.ReportItemSeverity.error()
+            )
+        )
+        raise LibraryError() from e
