@@ -2,8 +2,6 @@ from typing import (
     Any,
     Collection,
     Container,
-    Iterable,
-    List,
     Mapping,
     Optional,
 )
@@ -15,6 +13,7 @@ from pcs.common.pacemaker.defaults import CibDefaultsDto
 from pcs.common.pacemaker.nvset import CibNvsetDto
 from pcs.common.reports.item import ReportItem
 from pcs.common.tools import Version
+from pcs.common.types import StringCollection
 from pcs.lib.cib import (
     nvpair_multi,
     sections,
@@ -171,12 +170,15 @@ def resource_defaults_config(
     rule_evaluator = _get_rule_evaluator(
         cib, env.cmd_runner(), env.report_processor, evaluate_expired
     )
-    get_config = lambda tag: _defaults_config(
-        cib,
-        tag,
-        sections.RSC_DEFAULTS,
-        rule_evaluator,
-    )
+
+    def get_config(tag: nvpair_multi.NvsetTag) -> list[CibNvsetDto]:
+        return _defaults_config(
+            cib,
+            tag,
+            sections.RSC_DEFAULTS,
+            rule_evaluator,
+        )
+
     return CibDefaultsDto(
         instance_attributes=get_config(nvpair_multi.NVSET_INSTANCE),
         meta_attributes=get_config(nvpair_multi.NVSET_META),
@@ -196,12 +198,15 @@ def operation_defaults_config(
     rule_evaluator = _get_rule_evaluator(
         cib, env.cmd_runner(), env.report_processor, evaluate_expired
     )
-    get_config = lambda tag: _defaults_config(
-        cib,
-        tag,
-        sections.OP_DEFAULTS,
-        rule_evaluator,
-    )
+
+    def get_config(tag: nvpair_multi.NvsetTag) -> list[CibNvsetDto]:
+        return _defaults_config(
+            cib,
+            tag,
+            sections.OP_DEFAULTS,
+            rule_evaluator,
+        )
+
     return CibDefaultsDto(
         instance_attributes=get_config(nvpair_multi.NVSET_INSTANCE),
         meta_attributes=get_config(nvpair_multi.NVSET_META),
@@ -230,7 +235,7 @@ def _defaults_config(
     nvset_tag: nvpair_multi.NvsetTag,
     cib_section_name: str,
     rule_evaluator: RuleInEffectEval,
-) -> List[CibNvsetDto]:
+) -> list[CibNvsetDto]:
     return [
         nvpair_multi.nvset_element_to_dto(nvset_el, rule_evaluator)
         for nvset_el in nvpair_multi.find_nvsets(
@@ -240,7 +245,7 @@ def _defaults_config(
 
 
 def resource_defaults_remove(
-    env: LibraryEnvironment, nvset_id_list: Collection[str]
+    env: LibraryEnvironment, nvset_id_list: StringCollection
 ) -> None:
     """
     Remove specified resource defaults nvsets
@@ -252,7 +257,7 @@ def resource_defaults_remove(
 
 
 def operation_defaults_remove(
-    env: LibraryEnvironment, nvset_id_list: Collection[str]
+    env: LibraryEnvironment, nvset_id_list: StringCollection
 ) -> None:
     """
     Remove specified operation defaults nvsets
@@ -264,7 +269,9 @@ def operation_defaults_remove(
 
 
 def _defaults_remove(
-    env: LibraryEnvironment, cib_section_name: str, nvset_id_list: Iterable[str]
+    env: LibraryEnvironment,
+    cib_section_name: str,
+    nvset_id_list: StringCollection,
 ) -> None:
     if not nvset_id_list:
         return
