@@ -2,13 +2,14 @@
 import math
 import os.path
 import time
-
 from typing import (
     Any,
-    Container,
+    Collection,
     Mapping,
     Optional,
     Sequence,
+    Tuple,
+    cast,
 )
 
 from pcs import settings
@@ -23,22 +24,27 @@ from pcs.common.corosync_conf import (
 )
 from pcs.common.file import RawFileError
 from pcs.common.node_communicator import HostNotFound
-from pcs.common.reports import (
-    codes as report_codes,
-    ReportProcessor,
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports import codes as report_codes
+from pcs.common.reports.item import (
+    ReportItem,
+    ReportItemList,
 )
-from pcs.common.reports.item import ReportItem
+from pcs.common.str_tools import join_multilines
 from pcs.common.tools import format_environment_error
 from pcs.common.types import (
     CorosyncTransportType,
     UnknownCorosyncTransportTypeException,
 )
-from pcs.common.str_tools import join_multilines
-from pcs.lib import node_communication_format, sbd, validate
+from pcs.lib import (
+    node_communication_format,
+    sbd,
+    validate,
+)
 from pcs.lib.booth import sync as booth_sync
 from pcs.lib.cib import fencing_topology
-from pcs.lib.cib.resource.remote_node import find_node_list as get_remote_nodes
 from pcs.lib.cib.resource.guest_node import find_node_list as get_guest_nodes
+from pcs.lib.cib.resource.remote_node import find_node_list as get_remote_nodes
 from pcs.lib.cib.tools import (
     get_fencing_topology,
     get_resources,
@@ -63,39 +69,41 @@ from pcs.lib.communication.nodes import (
 )
 from pcs.lib.communication.sbd import (
     CheckSbd,
-    SetSbdConfig,
-    EnableSbdService,
     DisableSbdService,
+    EnableSbdService,
+    SetSbdConfig,
 )
-from pcs.lib.communication.tools import (
-    run as run_com,
-    run_and_raise,
-    AllSameDataMixin,
-)
+from pcs.lib.communication.tools import AllSameDataMixin
+from pcs.lib.communication.tools import run as run_com
+from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.corosync import (
     config_facade,
     config_parser,
     config_validators,
-    constants as corosync_constants,
-    qdevice_net,
 )
-from pcs.lib.env import LibraryEnvironment
-from pcs.lib.file.instance import FileInstance
-from pcs.lib.node import get_existing_nodes_names
+from pcs.lib.corosync import constants as corosync_constants
+from pcs.lib.corosync import qdevice_net
+from pcs.lib.env import (
+    LibraryEnvironment,
+    WaitType,
+)
 from pcs.lib.errors import LibraryError
+from pcs.lib.file.instance import FileInstance
 from pcs.lib.interface.config import ParserErrorException
+from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.pacemaker.live import (
     get_cib,
     get_cib_xml,
     get_cib_xml_cmd_results,
     remove_node,
-    verify as verify_cmd,
 )
+from pcs.lib.pacemaker.live import verify as verify_cmd
 from pcs.lib.pacemaker.state import ClusterState
 from pcs.lib.pacemaker.values import get_valid_timeout_seconds
 from pcs.lib.tools import (
     environment_file_to_dict,
     generate_binary_key,
+    generate_uuid,
 )
 
 
@@ -181,21 +189,22 @@ def verify(env: LibraryEnvironment, verbose=False):
 
 
 def setup(
-    env,
-    cluster_name,
-    nodes,
-    transport_type=None,
-    transport_options=None,
-    link_list=None,
-    compression_options=None,
-    crypto_options=None,
-    totem_options=None,
-    quorum_options=None,
-    wait=False,
-    start=False,
-    enable=False,
-    no_keys_sync=False,
-    force_flags: Container[reports.types.ForceCode] = (),
+    env: LibraryEnvironment,
+    cluster_name: str,
+    nodes: Sequence[Mapping[str, Any]],
+    transport_type: Optional[str] = None,
+    transport_options: Optional[Mapping[str, str]] = None,
+    link_list: Optional[Sequence[Mapping[str, Any]]] = None,
+    compression_options: Optional[Mapping[str, str]] = None,
+    crypto_options: Optional[Mapping[str, str]] = None,
+    totem_options: Optional[Mapping[str, str]] = None,
+    quorum_options: Optional[Mapping[str, str]] = None,
+    wait: WaitType = False,
+    start: bool = False,
+    enable: bool = False,
+    no_keys_sync: bool = False,
+    no_cluster_uuid: bool = False,
+    force_flags: Collection[reports.types.ForceCode] = (),
 ):
     # pylint: disable=too-many-arguments
     # pylint: disable=too-many-locals
@@ -204,33 +213,35 @@ def setup(
     """
     Set up cluster on specified nodes.
     Validation of the inputs is done here. Possible existing clusters are
-    destroyed (when using force). Authkey files for corosync and pacemaer,
-    known hosts and and newly generated corosync.conf are distributed to all
+    destroyed (when using force). Authkey files for corosync and pacemaker,
+    known hosts and newly generated corosync.conf are distributed to all
     nodes.
     Raise LibraryError on any error.
 
-    env LibraryEnvironment
-    cluster_name string -- name of a cluster to set up
-    nodes list -- list of dicts which represents node.
-        Supported keys are: name (required), addrs. See note bellow.
-    transport_type string -- transport type of a cluster
-    transport_options dict -- transport specific options
-    link_list list of dict -- list of links, depends of transport_type
-    compression_options dict -- only available for knet transport. In
+    env
+    cluster_name -- name of a cluster to set up
+    nodes -- list of dicts which represents node.
+        Supported keys are: name (required), addrs. See note below.
+    transport_type -- transport type of a cluster
+    transport_options -- transport specific options
+    link_list -- list of links, depends of transport_type
+    compression_options -- only available for knet transport. In
         corosync.conf they are prefixed 'knet_compression_'
-    crypto_options dict -- only available for knet transport'. In corosync.conf
+    crypto_options -- only available for knet transport'. In corosync.conf
         they are prefixed 'crypto_'
-    totem_options dict -- options of section 'totem' in corosync.conf
-    quorum_options dict -- options of section 'quorum' in corosync.conf
+    totem_options -- options of section 'totem' in corosync.conf
+    quorum_options -- options of section 'quorum' in corosync.conf
     wait -- specifies if command should try to wait for cluster to start up.
         Has no effect start is False. If set to False command will not wait for
         cluster to start. If None command will wait for some default timeout.
         If int wait set timeout to int value of seconds.
-    start bool -- if True start cluster when it is set up
-    enable bool -- if True enable cluster when it is set up
-    no_keys_sync bool -- if True do not crete and distribute files: pcsd ssl
+    start -- if True start cluster when it is set up
+    enable -- if True enable cluster when it is set up
+    no_keys_sync -- if True do not create and distribute files: pcsd ssl
         cert and key, pacemaker authkey, corosync authkey
-    force_flags list -- list of flags codes
+    no_cluster_uuid -- if True, do not generate a unique cluster UUID into
+        the 'totem' section of corosync.conf
+    force_flags -- list of flags codes
 
     The command is defaulting node addresses if they are not specified. The
     defaulting is done for each node individually if and only if the "addrs" key
@@ -326,7 +337,7 @@ def setup(
     if report_processor.has_errors:
         raise LibraryError()
 
-    # Validation done. If errors occured, an exception has been raised and we
+    # Validation done. If errors occurred, an exception has been raised and we
     # don't get below this line.
 
     # Destroy cluster on all nodes.
@@ -413,6 +424,7 @@ def setup(
                 crypto_options,
                 totem_options,
                 quorum_options,
+                no_cluster_uuid,
             ).config.export()
         ),
     )
@@ -449,7 +461,8 @@ def setup_local(
     crypto_options: Mapping[str, str],
     totem_options: Mapping[str, str],
     quorum_options: Mapping[str, str],
-    force_flags: Container[reports.types.ForceCode] = (),
+    no_cluster_uuid: bool = False,
+    force_flags: Collection[reports.types.ForceCode] = (),
 ) -> bytes:
     """
     Return corosync.conf text based on specified parameters.
@@ -468,6 +481,8 @@ def setup_local(
         they are prefixed 'crypto_'
     totem_options -- options of section 'totem' in corosync.conf
     quorum_options -- options of section 'quorum' in corosync.conf
+    no_cluster_uuid -- if True, do not generate a unique cluster UUID into
+        the totem section of corosync.conf
     force_flags -- list of flags codes
 
     The command is defaulting node addresses if they are not specified. The
@@ -539,7 +554,7 @@ def setup_local(
     ).has_errors:
         raise LibraryError()
 
-    # Validation done. If errors occured, an exception has been raised and we
+    # Validation done. If errors occurred, an exception has been raised and we
     # don't get below this line.
 
     return (
@@ -553,6 +568,7 @@ def setup_local(
             crypto_options,
             totem_options,
             quorum_options,
+            no_cluster_uuid,
         )
         .config.export()
         .encode("utf-8")
@@ -595,7 +611,7 @@ def _validate_create_corosync_conf(
         force_unresolvable=force,
         force_cluster_name=force,
     )
-    max_node_addr_count = max([len(node["addrs"]) for node in nodes], default=0)
+    max_node_addr_count = max((len(node["addrs"]) for node in nodes), default=0)
     if transport_type in corosync_constants.TRANSPORTS_KNET:
         report_list += config_validators.create_transport_knet(
             transport_options, compression_options, crypto_options
@@ -629,6 +645,7 @@ def _create_corosync_conf(
     crypto_options: Mapping[str, str],
     totem_options: Mapping[str, str],
     quorum_options: Mapping[str, str],
+    no_cluster_uuid: bool,
 ) -> config_facade.ConfigFacade:
     # pylint: disable=too-many-arguments
     corosync_conf = config_facade.ConfigFacade.create(
@@ -642,6 +659,8 @@ def _create_corosync_conf(
         compression_options,
         crypto_options,
     )
+    if not no_cluster_uuid:
+        corosync_conf.set_cluster_uuid(generate_uuid())
 
     _verify_corosync_conf(corosync_conf)  # raises if corosync not valid
     return corosync_conf
@@ -747,8 +766,9 @@ def config_update_local(
     _ensure_live_env(env)
     corosync_conf_instance = FileInstance.for_corosync_conf()
     try:
-        corosync_conf: config_facade.ConfigFacade = (
-            corosync_conf_instance.raw_to_facade(corosync_conf_content)
+        corosync_conf: config_facade.ConfigFacade = cast(
+            config_facade.ConfigFacade,
+            corosync_conf_instance.raw_to_facade(corosync_conf_content),
         )
     except ParserErrorException as e:
         if env.report_processor.report_list(
@@ -778,9 +798,9 @@ def get_corosync_conf_struct(env: LibraryEnvironment) -> CorosyncConfDto:
     """
     corosync_conf = env.get_corosync_conf()
     quorum_device_dto: Optional[CorosyncQuorumDeviceSettingsDto] = None
-    if corosync_conf.has_quorum_device():
+    qd_model = corosync_conf.get_quorum_device_model()
+    if qd_model is not None:
         (
-            qd_model,
             qd_model_options,
             qd_generic_options,
             qd_heuristics_options,
@@ -794,6 +814,7 @@ def get_corosync_conf_struct(env: LibraryEnvironment) -> CorosyncConfDto:
     try:
         return CorosyncConfDto(
             cluster_name=corosync_conf.get_cluster_name(),
+            cluster_uuid=corosync_conf.get_cluster_uuid(),
             transport=CorosyncTransportType.from_str(
                 corosync_conf.get_transport()
             ),
@@ -823,7 +844,7 @@ def add_nodes(
     start=False,
     enable=False,
     no_watchdog_validation=False,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: Collection[reports.types.ForceCode] = (),
 ):
     # pylint: disable=too-many-locals, too-many-statements, too-many-branches
     """
@@ -890,14 +911,14 @@ def add_nodes(
         skip_non_existing=skip_offline_nodes,
     )
     report_processor.report_list(target_report_list)
+
     # get a target for qnetd if needed
-    (
-        qdevice_model,
-        qdevice_model_options,
-        _,
-        _,
-    ) = corosync_conf.get_quorum_device_settings()
-    if qdevice_model == "net":
+    if corosync_conf.get_quorum_device_model() == "net":
+        (
+            qdevice_model_options,
+            _,
+            _,
+        ) = corosync_conf.get_quorum_device_settings()
         try:
             qnetd_target = target_factory.get_target(
                 qdevice_model_options["host"]
@@ -1114,12 +1135,12 @@ def add_nodes(
     if report_processor.has_errors:
         raise LibraryError()
 
-    # Validation done. If errors occured, an exception has been raised and we
+    # Validation done. If errors occurred, an exception has been raised and we
     # don't get below this line.
 
     # First set up everything else than corosync. Once the new nodes are present
     # in corosync.conf, they're considered part of a cluster and the node add
-    # command cannot be run again. So we need to minimize the amout of actions
+    # command cannot be run again. So we need to minimize the amount of actions
     # (and therefore possible failures) after adding the nodes to corosync.
 
     # distribute auth tokens of all cluster nodes (including the new ones) to
@@ -1135,7 +1156,7 @@ def add_nodes(
     run_and_raise(env.get_node_communicator(), com_cmd)
 
     # qdevice setup
-    if qdevice_model == "net":
+    if corosync_conf.get_quorum_device_model() == "net":
         qdevice_net.set_up_client_certificates(
             env.cmd_runner(),
             env.report_processor,
@@ -1143,7 +1164,7 @@ def add_nodes(
             qnetd_target,
             corosync_conf.get_cluster_name(),
             new_nodes_target_list,
-            # we don't want to allow skiping offline nodes which are being
+            # we don't want to allow skipping offline nodes which are being
             # added, otherwise qdevice will not work properly
             skip_offline_nodes=False,
             allow_skip_offline=False,
@@ -1259,7 +1280,7 @@ def add_nodes(
 
     # pcs_settings.conf was previously synced using pcsdcli send_local_configs.
     # This has been changed temporarily until new system for distribution and
-    # syncronization of configs will be introduced.
+    # synchronization of configs will be introduced.
     if os.path.isfile(settings.pcsd_settings_conf_location):
         try:
             with open(
@@ -1689,7 +1710,7 @@ def _verify_corosync_conf(corosync_conf_facade):
 def remove_nodes(
     env: LibraryEnvironment,
     node_list,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: Collection[reports.types.ForceCode] = (),
 ):
     # pylint: disable=too-many-locals, too-many-branches, too-many-statements
     """
@@ -1723,6 +1744,7 @@ def remove_nodes(
         config_validators.remove_nodes(
             node_list,
             corosync_conf.get_nodes(),
+            corosync_conf.get_quorum_device_model(),
             corosync_conf.get_quorum_device_settings(),
         )
     )
@@ -1818,9 +1840,11 @@ def remove_nodes(
         # required, cluster has to be turned off and therefore it loses quorum.
         com_cmd = cluster.GetQuorumStatus(report_processor)
         com_cmd.set_targets(targets_to_remove)
-        failures, quorum_status = run_com(env.get_node_communicator(), com_cmd)
-        if quorum_status:
-            if quorum_status.stopping_nodes_cause_quorum_loss(node_list):
+        failures, quorum_status_facade = run_com(
+            env.get_node_communicator(), com_cmd
+        )
+        if quorum_status_facade:
+            if quorum_status_facade.stopping_nodes_cause_quorum_loss(node_list):
                 report_processor.report(
                     ReportItem(
                         severity=reports.item.get_severity(
@@ -1935,7 +1959,7 @@ def add_link(
     env: LibraryEnvironment,
     node_addr_map,
     link_options=None,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: Collection[reports.types.ForceCode] = (),
 ):
     """
     Add a corosync link to a cluster
@@ -1947,7 +1971,7 @@ def add_link(
     """
     _ensure_live_env(env)  # raises if env is not live
 
-    link_options = link_options or dict()
+    link_options = link_options or {}
     force = report_codes.FORCE in force_flags
     skip_offline = report_codes.SKIP_OFFLINE_NODES in force_flags
 
@@ -1983,7 +2007,7 @@ def add_link(
             link_options,
             corosync_conf.get_nodes(),
             cib_nodes,
-            corosync_conf.get_used_linknumber_list(),
+            [str(num) for num in corosync_conf.get_used_linknumber_list()],
             corosync_conf.get_transport(),
             corosync_conf.get_ip_version(),
             force_unresolvable=force,
@@ -2002,7 +2026,7 @@ def add_link(
 def remove_links(
     env: LibraryEnvironment,
     linknumber_list,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: Collection[reports.types.ForceCode] = (),
 ):
     """
     Remove corosync links from a cluster
@@ -2025,7 +2049,7 @@ def remove_links(
     report_processor.report_list(
         config_validators.remove_links(
             linknumber_list,
-            corosync_conf.get_used_linknumber_list(),
+            [str(num) for num in corosync_conf.get_used_linknumber_list()],
             corosync_conf.get_transport(),
         )
     )
@@ -2045,7 +2069,7 @@ def update_link(
     linknumber,
     node_addr_map=None,
     link_options=None,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: Collection[reports.types.ForceCode] = (),
 ):
     """
     Change an existing corosync link
@@ -2058,8 +2082,8 @@ def update_link(
     """
     _ensure_live_env(env)  # raises if env is not live
 
-    node_addr_map = node_addr_map or dict()
-    link_options = link_options or dict()
+    node_addr_map = node_addr_map or {}
+    link_options = link_options or {}
     force = report_codes.FORCE in force_flags
     skip_offline = report_codes.SKIP_OFFLINE_NODES in force_flags
 
@@ -2090,7 +2114,7 @@ def update_link(
             # cluster must be stopped for updating a link and then we cannot get
             # nodes from CIB
             [],
-            corosync_conf.get_used_linknumber_list(),
+            [str(num) for num in corosync_conf.get_used_linknumber_list()],
             corosync_conf.get_transport(),
             corosync_conf.get_ip_version(),
             force_unresolvable=force,
@@ -2109,7 +2133,7 @@ def update_link(
 def corosync_authkey_change(
     env: LibraryEnvironment,
     corosync_authkey: Optional[bytes] = None,
-    force_flags: Container[reports.types.ForceCode] = (),
+    force_flags: Collection[reports.types.ForceCode] = (),
 ) -> None:
     """
     Distribute new corosync authkey to all cluster nodes.
@@ -2184,3 +2208,82 @@ def corosync_authkey_change(
     com_cmd = ReloadCorosyncConf(env.report_processor)
     com_cmd.set_targets(online_cluster_target_list)
     run_and_raise(env.get_node_communicator(), com_cmd)
+
+
+def _generate_cluster_uuid(
+    corosync_conf: config_facade.ConfigFacade, is_forced: bool
+) -> Tuple[ReportItemList, config_facade.ConfigFacade]:
+    report_list = []
+    if corosync_conf.get_cluster_uuid():
+        report_list.append(
+            reports.ReportItem(
+                severity=reports.item.get_severity(
+                    report_codes.FORCE, is_forced
+                ),
+                message=reports.messages.ClusterUuidAlreadySet(),
+            )
+        )
+        if not is_forced:
+            return report_list, corosync_conf
+
+    corosync_conf.set_cluster_uuid(generate_uuid())
+    return report_list, corosync_conf
+
+
+def generate_cluster_uuid(
+    env: LibraryEnvironment,
+    force_flags: Collection[reports.types.ForceCode] = (),
+) -> None:
+    """
+    Add or update cluster UUID in live cluster
+
+    env
+    """
+    _ensure_live_env(env)
+    corosync_conf = env.get_corosync_conf()
+    report_list, corosync_conf = _generate_cluster_uuid(
+        corosync_conf, report_codes.FORCE in force_flags
+    )
+    if env.report_processor.report_list(report_list).has_errors:
+        raise LibraryError()
+    env.push_corosync_conf(corosync_conf)
+
+
+def generate_cluster_uuid_local(
+    env: LibraryEnvironment,
+    corosync_conf_content: bytes,
+    force_flags: Collection[reports.types.ForceCode] = (),
+) -> bytes:
+    """
+    Add or update cluster UUID in corosync.conf passed as an argument and return
+    the updated config
+
+    env
+    corosync_conf_content -- corosync.conf to be updated
+    """
+    _ensure_live_env(env)
+    corosync_conf_instance = FileInstance.for_corosync_conf()
+    try:
+        corosync_conf: config_facade.ConfigFacade = cast(
+            config_facade.ConfigFacade,
+            corosync_conf_instance.raw_to_facade(corosync_conf_content),
+        )
+    except ParserErrorException as e:
+        if env.report_processor.report_list(
+            corosync_conf_instance.toolbox.parser.exception_to_report_list(
+                e,
+                corosync_conf_instance.toolbox.file_type_code,
+                None,
+                force_code=None,
+                is_forced_or_warning=False,
+            )
+        ).has_errors:
+            raise LibraryError() from e
+
+    report_list, corosync_conf = _generate_cluster_uuid(
+        corosync_conf, report_codes.FORCE in force_flags
+    )
+    if env.report_processor.report_list(report_list).has_errors:
+        raise LibraryError()
+
+    return corosync_conf_instance.facade_to_raw(corosync_conf)
