@@ -1,43 +1,49 @@
-from pcs.common import reports
-from pcs.common.reports import ReportProcessor
-from pcs.common.reports.item import ReportItem
+import re
+from typing import Optional
+
+from pcs import settings
+from pcs.common import (
+    file_type_codes,
+    reports,
+)
+from pcs.common.services.interfaces import ServiceManagerInterface
+from pcs.common.str_tools import join_multilines
 from pcs.lib import sbd
+from pcs.lib.communication import qdevice as qdevice_com
+from pcs.lib.communication import qdevice_net as qdevice_net_com
+from pcs.lib.communication.tools import run_and_raise
+from pcs.lib.corosync import config_validators as corosync_conf_validators
+from pcs.lib.corosync import live as corosync_live
+from pcs.lib.corosync import (
+    qdevice_client,
+    qdevice_net,
+)
+from pcs.lib.corosync.config_facade import ConfigFacade as CorosyncConfFacade
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
-from pcs.lib.communication import (
-    qdevice as qdevice_com,
-    qdevice_net as qdevice_net_com,
-)
-from pcs.lib.communication.tools import run_and_raise
-from pcs.lib.corosync import (
-    config_validators as corosync_conf_validators,
-    live as corosync_live,
-    qdevice_net,
-    qdevice_client,
-)
 from pcs.lib.node import get_existing_nodes_names
 
 
-def get_config(lib_env):
+def get_config(lib_env: LibraryEnvironment):
     """
     Extract and return quorum configuration from corosync.conf
     lib_env LibraryEnvironment
     """
     cfg = lib_env.get_corosync_conf()
     device = None
-    if cfg.has_quorum_device():
+    qd_model = cfg.get_quorum_device_model()
+    if qd_model is not None:
         (
-            model,
-            model_options,
-            generic_options,
-            heuristics_options,
+            qd_model_options,
+            qd_generic_options,
+            qd_heuristics_options,
         ) = cfg.get_quorum_device_settings()
-        device = {
-            "model": model,
-            "model_options": model_options,
-            "generic_options": generic_options,
-            "heuristics_options": heuristics_options,
-        }
+        device = dict(
+            model=qd_model,
+            model_options=qd_model_options,
+            generic_options=qd_generic_options,
+            heuristics_options=qd_heuristics_options,
+        )
     return {
         "options": cfg.get_quorum_options(),
         "device": device,
@@ -45,17 +51,17 @@ def get_config(lib_env):
 
 
 def _check_if_atb_can_be_disabled(
-    runner,
-    report_processor: ReportProcessor,
-    corosync_conf,
-    was_enabled,
-    force=False,
-):
+    service_manager: ServiceManagerInterface,
+    report_processor: reports.ReportProcessor,
+    corosync_conf: CorosyncConfFacade,
+    was_enabled: bool,
+    force: bool = False,
+) -> None:
     """
     Check whenever auto_tie_breaker can be changed without affecting SBD.
     Raises LibraryError if change of ATB will affect SBD functionality.
 
-    runner -- CommandRunner
+    service_manager --
     report_processor -- report processor
     corosync_conf -- corosync conf facade
     was_enabled -- True if ATB was enabled, False otherwise
@@ -64,12 +70,12 @@ def _check_if_atb_can_be_disabled(
     if (
         was_enabled
         and not corosync_conf.is_enabled_auto_tie_breaker()
-        and sbd.is_auto_tie_breaker_needed(runner, corosync_conf)
+        and sbd.is_auto_tie_breaker_needed(service_manager, corosync_conf)
     ):
         report_processor.report(
-            ReportItem(
+            reports.ReportItem(
                 severity=reports.item.get_severity(
-                    reports.codes.FORCE_OPTIONS,
+                    reports.codes.FORCE,
                     force,
                 ),
                 message=(
@@ -98,14 +104,16 @@ def set_options(
     cfg = lib_env.get_corosync_conf()
     if lib_env.report_processor.report_list(
         corosync_conf_validators.update_quorum_options(
-            options, cfg.has_quorum_device(), cfg.get_quorum_options()
+            options,
+            cfg.get_quorum_device_model() is not None,
+            cfg.get_quorum_options(),
         )
     ).has_errors:
         raise LibraryError()
     cfg.set_quorum_options(options)
     if lib_env.is_corosync_conf_live:
         _check_if_atb_can_be_disabled(
-            lib_env.cmd_runner(),
+            lib_env.service_manager,
             lib_env.report_processor,
             cfg,
             cfg.is_enabled_auto_tie_breaker(),
@@ -122,7 +130,7 @@ def status_text(lib_env):
         return corosync_live.get_quorum_status_text(lib_env.cmd_runner())
     except corosync_live.QuorumStatusReadException as e:
         raise LibraryError(
-            ReportItem.error(
+            reports.ReportItem.error(
                 reports.messages.CorosyncQuorumGetStatusError(e.reason)
             )
         ) from e
@@ -159,9 +167,9 @@ def add_device(
     bool skip_offline_nodes -- continue even if not all nodes are accessible
     """
     cfg = lib_env.get_corosync_conf()
-    if cfg.has_quorum_device():
+    if cfg.get_quorum_device_model():
         raise LibraryError(
-            ReportItem.error(reports.messages.QdeviceAlreadyDefined())
+            reports.ReportItem.error(reports.messages.QdeviceAlreadyDefined())
         )
 
     report_processor = lib_env.report_processor
@@ -171,7 +179,7 @@ def add_device(
             model_options,
             generic_options,
             heuristics_options,
-            [node.nodeid for node in cfg.get_nodes()],
+            [node.nodeid for node in cfg.get_nodes() if node.nodeid],
             force_model=force_model,
             force_options=force_options,
         )
@@ -198,7 +206,7 @@ def add_device(
     )
     if cfg.is_quorum_device_heuristics_enabled_with_no_exec():
         lib_env.report_processor.report(
-            ReportItem.warning(
+            reports.ReportItem.warning(
                 reports.messages.CorosyncQuorumHeuristicsEnabledWithNoExec()
             )
         )
@@ -230,7 +238,7 @@ def add_device(
             )
 
         lib_env.report_processor.report(
-            ReportItem.info(
+            reports.ReportItem.info(
                 reports.messages.ServiceActionStarted(
                     reports.const.SERVICE_ACTION_ENABLE, "corosync-qdevice"
                 )
@@ -248,7 +256,7 @@ def add_device(
     # Now, when corosync.conf has been reloaded, we can start qdevice service.
     if lib_env.is_corosync_conf_live:
         lib_env.report_processor.report(
-            ReportItem.info(
+            reports.ReportItem.info(
                 reports.messages.ServiceActionStarted(
                     reports.const.SERVICE_ACTION_START, "corosync-qdevice"
                 )
@@ -279,17 +287,18 @@ def update_device(
     bool skip_offline_nodes -- continue even if not all nodes are accessible
     """
     cfg = lib_env.get_corosync_conf()
-    if not cfg.has_quorum_device():
+    model = cfg.get_quorum_device_model()
+    if not model:
         raise LibraryError(
-            ReportItem.error(reports.messages.QdeviceNotDefined())
+            reports.ReportItem.error(reports.messages.QdeviceNotDefined())
         )
     if lib_env.report_processor.report_list(
         corosync_conf_validators.update_quorum_device(
-            cfg.get_quorum_device_model(),
+            model,
             model_options,
             generic_options,
             heuristics_options,
-            [node.nodeid for node in cfg.get_nodes()],
+            [node.nodeid for node in cfg.get_nodes() if node.nodeid],
             force_options=force_options,
         )
     ).has_errors:
@@ -297,7 +306,7 @@ def update_device(
     cfg.update_quorum_device(model_options, generic_options, heuristics_options)
     if cfg.is_quorum_device_heuristics_enabled_with_no_exec():
         lib_env.report_processor.report(
-            ReportItem.warning(
+            reports.ReportItem.warning(
                 reports.messages.CorosyncQuorumHeuristicsEnabledWithNoExec()
             )
         )
@@ -311,9 +320,9 @@ def remove_device_heuristics(lib_env, skip_offline_nodes=False):
     bool skip_offline_nodes -- continue even if not all nodes are accessible
     """
     cfg = lib_env.get_corosync_conf()
-    if not cfg.has_quorum_device():
+    if not cfg.get_quorum_device_model():
         raise LibraryError(
-            ReportItem.error(reports.messages.QdeviceNotDefined())
+            reports.ReportItem.error(reports.messages.QdeviceNotDefined())
         )
     cfg.remove_quorum_device_heuristics()
     lib_env.push_corosync_conf(cfg, skip_offline_nodes)
@@ -325,11 +334,11 @@ def remove_device(lib_env: LibraryEnvironment, skip_offline_nodes=False):
     skip_offline_nodes continue even if not all nodes are accessible
     """
     cfg = lib_env.get_corosync_conf()
-    if not cfg.has_quorum_device():
-        raise LibraryError(
-            ReportItem.error(reports.messages.QdeviceNotDefined())
-        )
     model = cfg.get_quorum_device_model()
+    if not model:
+        raise LibraryError(
+            reports.ReportItem.error(reports.messages.QdeviceNotDefined())
+        )
     cfg.remove_quorum_device()
 
     if lib_env.is_corosync_conf_live:
@@ -349,9 +358,9 @@ def remove_device(lib_env: LibraryEnvironment, skip_offline_nodes=False):
             skip_non_existing=skip_offline_nodes,
         )
         # fix quorum options for SBD to work properly
-        if sbd.atb_has_to_be_enabled(lib_env.cmd_runner(), cfg):
+        if sbd.atb_has_to_be_enabled(lib_env.service_manager, cfg):
             lib_env.report_processor.report(
-                ReportItem.warning(
+                reports.ReportItem.warning(
                     reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbd()
                 )
             )
@@ -359,7 +368,7 @@ def remove_device(lib_env: LibraryEnvironment, skip_offline_nodes=False):
 
         # disable qdevice
         lib_env.report_processor.report(
-            ReportItem.info(
+            reports.ReportItem.info(
                 reports.messages.ServiceActionStarted(
                     reports.const.SERVICE_ACTION_DISABLE, "corosync-qdevice"
                 )
@@ -372,7 +381,7 @@ def remove_device(lib_env: LibraryEnvironment, skip_offline_nodes=False):
         run_and_raise(lib_env.get_node_communicator(), com_cmd_disable)
         # stop qdevice
         lib_env.report_processor.report(
-            ReportItem.info(
+            reports.ReportItem.info(
                 reports.messages.ServiceActionStarted(
                     reports.const.SERVICE_ACTION_STOP, "corosync-qdevice"
                 )
@@ -386,7 +395,7 @@ def remove_device(lib_env: LibraryEnvironment, skip_offline_nodes=False):
         # handle model specific configuration
         if model == "net":
             lib_env.report_processor.report(
-                ReportItem.info(
+                reports.ReportItem.info(
                     reports.messages.QdeviceCertificateRemovalStarted()
                 )
             )
@@ -401,6 +410,164 @@ def remove_device(lib_env: LibraryEnvironment, skip_offline_nodes=False):
     lib_env.push_corosync_conf(cfg, skip_offline_nodes)
 
 
+def _ensure_live(lib_env: LibraryEnvironment) -> None:
+    if not lib_env.is_corosync_conf_live:
+        lib_env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.LiveEnvironmentRequired(
+                    [file_type_codes.COROSYNC_CONF]
+                )
+            )
+        )
+        raise LibraryError()
+
+
+def device_net_certificate_setup_local(
+    lib_env: LibraryEnvironment,
+    qnetd_host: str,
+    cluster_name: str,
+) -> None:
+    """
+    Set up qdevice model net certificates on the local node
+
+    qnetd_host -- address of a qnetd host
+    cluster_name -- local node cluster name
+    """
+    _ensure_live(lib_env)
+    runner = lib_env.cmd_runner()
+    qnetd_target = lib_env.get_node_target_factory().get_target_from_hostname(
+        qnetd_host
+    )
+
+    # get qnetd CA certificate
+    com_cmd_1 = qdevice_net_com.GetCaCert(lib_env.report_processor)
+    com_cmd_1.set_targets([qnetd_target])
+    qnetd_ca_cert = run_and_raise(
+        lib_env.communicator_factory.get_communicator(), com_cmd_1
+    )[0][1]
+    # init certificate storage on local node
+    qdevice_net.client_setup(runner, qnetd_ca_cert)
+    # create client certificate request
+    cert_request = qdevice_net.client_generate_certificate_request(
+        runner, cluster_name
+    )
+    # sign the request on qnetd host
+    com_cmd_2 = qdevice_net_com.SignCertificate(lib_env.report_processor)
+    com_cmd_2.add_request(qnetd_target, cert_request, cluster_name)
+    signed_certificate = run_and_raise(
+        lib_env.communicator_factory.get_communicator(), com_cmd_2
+    )[0][1]
+    # transform the signed certificate to pk12 format which can sent to nodes
+    pk12 = qdevice_net.client_cert_request_to_pk12(runner, signed_certificate)
+    # store final certificate
+    qdevice_net.client_import_certificate_and_key(runner, pk12)
+
+
+def device_net_certificate_check_local(
+    lib_env: LibraryEnvironment,
+    qnetd_host: str,
+    cluster_name: str,
+) -> bool:
+    """
+    Check if the local node already has qdevice model net certificates
+
+    qnetd_host -- address of a qnetd host
+    cluster_name -- local node cluster name
+    """
+
+    def get_certificate_data(text: str) -> Optional[str]:
+        match = re.search(
+            r"-----BEGIN CERTIFICATE-----([a-zA-Z0-9/+=]+)-----END CERTIFICATE-----",
+            "".join(text.splitlines()),
+        )
+        return match.group(1) if match else None
+
+    _ensure_live(lib_env)
+    runner = lib_env.cmd_runner()
+    qnetd_target = lib_env.get_node_target_factory().get_target_from_hostname(
+        qnetd_host
+    )
+
+    if not qdevice_net.client_initialized():
+        return False
+
+    # check if certificates are present
+    list_certs_cmd = [
+        settings.certutil_executable,
+        "-d",
+        settings.corosync_qdevice_net_client_certs_dir,
+        "-L",
+    ]
+    stdout, stderr, retval = runner.run(list_certs_cmd)
+    if retval != 0:
+        lib_env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.QdeviceCertificateReadError(
+                    join_multilines([stderr, stdout])
+                )
+            )
+        )
+        raise LibraryError()
+    for certname in ["QNet CA", "Cluster Cert"]:
+        if not re.search(rf"^{certname}\s*\S*,.*,.*$", stdout, re.MULTILINE):
+            return False
+
+    # check cluster name
+    stdout, stderr, retval = runner.run(list_certs_cmd + ["-n", "Cluster Cert"])
+    if retval != 0:
+        lib_env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.QdeviceCertificateReadError(
+                    join_multilines([stderr, stdout])
+                )
+            )
+        )
+        raise LibraryError()
+    if not re.search(
+        rf'^\s*Subject: "CN={cluster_name}"$', stdout, re.MULTILINE
+    ):
+        return False
+
+    # get qnetd CA certificate from qnetd host
+    com_cmd = qdevice_net_com.GetCaCert(lib_env.report_processor)
+    com_cmd.set_targets([qnetd_target])
+    qnetd_ca_cert_text = run_and_raise(
+        lib_env.communicator_factory.get_communicator(), com_cmd
+    )[0][1]
+    qnetd_ca_cert = get_certificate_data(qnetd_ca_cert_text.decode())
+    if qnetd_ca_cert is None:
+        lib_env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.QdeviceCertificateBadFormat()
+            )
+        )
+        raise LibraryError()
+
+    # get qnetd CA certificate from local node
+    stdout, stderr, retval = runner.run(
+        list_certs_cmd + ["-n", "QNet CA", "-a"]
+    )
+    if retval != 0:
+        lib_env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.QdeviceCertificateReadError(
+                    join_multilines([stderr, stdout])
+                )
+            )
+        )
+        raise LibraryError()
+    local_ca_cert = get_certificate_data(stdout)
+    if local_ca_cert is None:
+        lib_env.report_processor.report(
+            reports.ReportItem.error(
+                reports.messages.QdeviceCertificateBadFormat()
+            )
+        )
+        raise LibraryError()
+
+    return qnetd_ca_cert == local_ca_cert
+
+
 def set_expected_votes_live(lib_env, expected_votes):
     """
     set expected votes in live cluster to specified value
@@ -412,7 +579,7 @@ def set_expected_votes_live(lib_env, expected_votes):
             raise ValueError()
     except ValueError:
         raise LibraryError(
-            ReportItem.error(
+            reports.ReportItem.error(
                 reports.messages.InvalidOptionValue(
                     "expected votes", expected_votes, "positive integer"
                 )
