@@ -31,6 +31,7 @@ from pcs.common.tools import (
     Version,
     timeout_to_seconds,
 )
+from pcs.common.types import StringCollection
 from pcs.lib.cib import const as cib_const
 from pcs.lib.cib import resource
 from pcs.lib.cib import status as cib_status
@@ -74,7 +75,10 @@ from pcs.lib.pacemaker.state import (
     info_resource_state,
     is_resource_managed,
 )
-from pcs.lib.pacemaker.values import validate_id
+from pcs.lib.pacemaker.values import (
+    is_true,
+    validate_id,
+)
 from pcs.lib.resource_agent import (
     ResourceAgentError,
     ResourceAgentFacade,
@@ -112,7 +116,7 @@ def resource_environment(
 def _get_resource_state_wait(
     env: LibraryEnvironment,
     wait_timeout: int = -1,
-    wait_for_resource_ids: Optional[Iterable[str]] = None,
+    wait_for_resource_ids: Optional[StringCollection] = None,
     resource_state_reporter: Callable[
         [_Element, str], ReportItem
     ] = info_resource_state,
@@ -131,7 +135,7 @@ def _get_resource_state_wait(
 def _push_cib_wait(
     env: LibraryEnvironment,
     wait_timeout: int = -1,
-    wait_for_resource_ids: Optional[Iterable[str]] = None,
+    wait_for_resource_ids: Optional[StringCollection] = None,
     resource_state_reporter: Callable[
         [_Element, str], ReportItem
     ] = info_resource_state,
@@ -198,7 +202,7 @@ def _get_agent_facade(
 
 def _validate_remote_connection(
     resource_agent_name: ResourceAgentName,
-    existing_nodes_addrs: Iterable[str],
+    existing_nodes_addrs: StringCollection,
     resource_id: str,
     instance_attributes: Mapping[str, str],
     allow_not_suitable_command: bool,
@@ -227,8 +231,8 @@ def _validate_remote_connection(
 
 def _validate_guest_change(
     tree: _Element,
-    existing_nodes_names: Iterable[str],
-    existing_nodes_addrs: Iterable[str],
+    existing_nodes_names: StringCollection,
+    existing_nodes_addrs: StringCollection,
     meta_attributes: Mapping[str, str],
     allow_not_suitable_command: bool,
     detect_remove: bool = False,
@@ -347,7 +351,7 @@ def create(
     env: LibraryEnvironment,
     resource_id: str,
     resource_agent_name: str,
-    operation_list: Iterable[Mapping[str, str]],
+    operation_list: List[Mapping[str, str]],
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
     allow_absent_agent: bool = False,
@@ -357,6 +361,7 @@ def create(
     ensure_disabled: bool = False,
     wait: WaitType = False,
     allow_not_suitable_command: bool = False,
+    enable_agent_self_validation: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
@@ -390,6 +395,8 @@ def create(
         pcs.lib.commands.remote_node);
         in the case of remote/guest node forcible error is produced when this
         flag is set to False and warning is produced otherwise
+    enable_agent_self_validation -- if True, use agent self-validation feature
+        to validate instance attributes
     """
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
@@ -425,6 +432,7 @@ def create(
 
         primitive_element = resource.primitive.create(
             env.report_processor,
+            runner,
             resources_section,
             id_provider,
             resource_id,
@@ -435,6 +443,7 @@ def create(
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
+            enable_agent_self_validation=enable_agent_self_validation,
         )
         if env.report_processor.has_errors:
             raise LibraryError()
@@ -447,7 +456,7 @@ def create_as_clone(
     env: LibraryEnvironment,
     resource_id: str,
     resource_agent_name: str,
-    operation_list: Iterable[Mapping[str, str]],
+    operation_list: List[Mapping[str, str]],
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
     clone_meta_options: Mapping[str, str],
@@ -459,6 +468,8 @@ def create_as_clone(
     ensure_disabled: bool = False,
     wait: WaitType = False,
     allow_not_suitable_command: bool = False,
+    allow_incompatible_clone_meta_attributes: bool = False,
+    enable_agent_self_validation: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
@@ -486,6 +497,11 @@ def create_as_clone(
     ensure_disabled -- is flag that keeps resource in target-role "Stopped"
     wait -- is flag for controlling waiting for pacemaker idle mechanism
     allow_not_suitable_command -- turn forceable errors into warnings
+    allow_incompatible_clone_meta_attributes -- if True some incompatible clone
+        meta attributes are treated as a warning, or as a forceable error if
+        False
+    enable_agent_self_validation -- if True, use agent self-validation feature
+        to validate instance attributes
     """
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
@@ -496,6 +512,37 @@ def create_as_clone(
         resource_agent_name,
         allow_absent_agent,
     )
+    if resource_agent.metadata.name.standard != "ocf":
+        for incompatible_attr in ("globally-unique", "promotable"):
+            if is_true(clone_meta_options.get(incompatible_attr, "0")):
+                env.report_processor.report(
+                    reports.ReportItem.error(
+                        reports.messages.ResourceCloneIncompatibleMetaAttributes(
+                            incompatible_attr,
+                            resource_agent.metadata.name.to_dto(),
+                        )
+                    )
+                )
+    elif resource_agent.metadata.ocf_version == "1.1":
+        if (
+            is_true(clone_meta_options.get("promotable", "0"))
+            and not resource_agent.metadata.provides_promotability
+        ):
+            env.report_processor.report(
+                reports.ReportItem(
+                    reports.get_severity(
+                        reports.codes.FORCE,
+                        allow_incompatible_clone_meta_attributes,
+                    ),
+                    reports.messages.ResourceCloneIncompatibleMetaAttributes(
+                        "promotable",
+                        resource_agent.metadata.name.to_dto(),
+                    ),
+                )
+            )
+    if env.report_processor.has_errors:
+        raise LibraryError()
+
     with resource_environment(
         env,
         wait,
@@ -528,6 +575,7 @@ def create_as_clone(
 
         primitive_element = resource.primitive.create(
             env.report_processor,
+            runner,
             resources_section,
             id_provider,
             resource_id,
@@ -538,6 +586,7 @@ def create_as_clone(
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
+            enable_agent_self_validation=enable_agent_self_validation,
         )
 
         clone_element = resource.clone.append_new(
@@ -556,7 +605,7 @@ def create_in_group(
     resource_id: str,
     resource_agent_name: str,
     group_id: str,
-    operation_list: Iterable[Mapping[str, str]],
+    operation_list: List[Mapping[str, str]],
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
     allow_absent_agent: bool = False,
@@ -568,6 +617,7 @@ def create_in_group(
     put_after_adjacent: bool = False,
     wait: WaitType = False,
     allow_not_suitable_command: bool = False,
+    enable_agent_self_validation: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
@@ -596,6 +646,8 @@ def create_in_group(
         adjacent resource
     wait -- is flag for controlling waiting for pacemaker idle mechanism
     allow_not_suitable_command -- turn forceable errors into warnings
+    enable_agent_self_validation -- if True, use agent self-validation feature
+        to validate instance attributes
     """
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
@@ -660,6 +712,7 @@ def create_in_group(
 
         primitive_element = resource.primitive.create(
             env.report_processor,
+            runner,
             resources_section,
             id_provider,
             resource_id,
@@ -670,6 +723,7 @@ def create_in_group(
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
+            enable_agent_self_validation=enable_agent_self_validation,
         )
         if ensure_disabled:
             resource.common.disable(primitive_element, id_provider)
@@ -695,7 +749,7 @@ def create_into_bundle(
     env: LibraryEnvironment,
     resource_id: str,
     resource_agent_name: str,
-    operation_list: Iterable[Mapping[str, str]],
+    operation_list: List[Mapping[str, str]],
     meta_attributes: Mapping[str, str],
     instance_attributes: Mapping[str, str],
     bundle_id: str,
@@ -707,6 +761,7 @@ def create_into_bundle(
     wait: WaitType = False,
     allow_not_suitable_command: bool = False,
     allow_not_accessible_resource: bool = False,
+    enable_agent_self_validation: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
@@ -734,6 +789,8 @@ def create_into_bundle(
     wait -- is flag for controlling waiting for pacemaker idle mechanism
     allow_not_suitable_command -- turn forceable errors into warnings
     allow_not_accessible_resource -- turn forceable errors into warnings
+    enable_agent_self_validation -- if True, use agent self-validation feature
+        to validate instance attributes
     """
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
@@ -770,6 +827,7 @@ def create_into_bundle(
 
         primitive_element = resource.primitive.create(
             env.report_processor,
+            runner,
             resources_section,
             id_provider,
             resource_id,
@@ -780,6 +838,7 @@ def create_into_bundle(
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
+            enable_agent_self_validation=enable_agent_self_validation,
         )
         if ensure_disabled:
             resource.common.disable(primitive_element, id_provider)
@@ -1043,7 +1102,7 @@ def bundle_update(
 def _disable_validate_and_edit_cib(
     env: LibraryEnvironment,
     cib: _Element,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: StringCollection,
 ) -> List[_Element]:
     resource_el_list, report_list = _find_resources_expand_tags(
         cib, resource_or_tag_ids
@@ -1127,7 +1186,7 @@ def _disable_run_simulate(
 
 def disable(
     env: LibraryEnvironment,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: StringCollection,
     wait: WaitType = False,
 ):
     """
@@ -1150,7 +1209,7 @@ def disable(
 
 def disable_safe(
     env: LibraryEnvironment,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: List[str],
     strict: bool,
     wait: WaitType = False,
 ):
@@ -1227,7 +1286,7 @@ def disable_safe(
 
 
 def disable_simulate(
-    env: LibraryEnvironment, resource_or_tag_ids: Iterable[str], strict: bool
+    env: LibraryEnvironment, resource_or_tag_ids: List[str], strict: bool
 ) -> Mapping[str, Union[str, List[str]]]:
     """
     Simulate disallowing specified resources to be started by the cluster
@@ -1266,7 +1325,7 @@ def disable_simulate(
 
 def enable(
     env: LibraryEnvironment,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: List[str],
     wait: WaitType = False,
 ):
     """
@@ -1333,7 +1392,7 @@ def _resource_list_enable_disable(
 
 def unmanage(
     env: LibraryEnvironment,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: List[str],
     with_monitor: bool = False,
 ) -> None:
     """
@@ -1368,7 +1427,7 @@ def unmanage(
 
 def manage(
     env: LibraryEnvironment,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: List[str],
     with_monitor: bool = False,
 ) -> None:
     """
@@ -1382,24 +1441,33 @@ def manage(
     cib = env.get_cib()
 
     resource_el_list, report_list = _find_resources_expand_tags(
-        cib, resource_or_tag_ids, resource.common.find_resources_to_manage
+        cib, resource_or_tag_ids
     )
-
-    primitives_set = set()
-    for resource_el in resource_el_list:
-        resource.common.manage(resource_el, IdProvider(cib))
-        primitives_set.update(resource.common.find_primitives(resource_el))
-
-    for resource_el in sorted(
-        primitives_set, key=lambda element: element.get("id", "")
-    ):
-        op_list = resource.operations.get_resource_operations(
-            resource_el, ["monitor"]
+    resource_el_to_manage_list = set()
+    for el in resource_el_list:
+        resource_el_to_manage_list.update(
+            resource.common.find_resources_to_manage(el)
         )
-        if with_monitor:
-            for op in op_list:
+
+    # manage all resources that need to be managed in order for the user
+    # specified resource to become managed
+    for resource_el in resource_el_to_manage_list:
+        resource.common.manage(resource_el, IdProvider(cib))
+        if with_monitor and resource.primitive.is_primitive(resource_el):
+            for op in resource.operations.get_resource_operations(
+                resource_el, ["monitor"]
+            ):
                 resource.operations.enable(op)
-        else:
+
+    # only report disabled monitor operations for user specified resources and
+    # their primitives
+    for resource_el in sorted(
+        resource_el_list, key=lambda element: element.get("id", "")
+    ):
+        for primitive_el in resource.common.find_primitives(resource_el):
+            op_list = resource.operations.get_resource_operations(
+                primitive_el, ["monitor"]
+            )
             monitor_enabled = False
             for op in op_list:
                 if resource.operations.is_enabled(op):
@@ -1410,7 +1478,7 @@ def manage(
                 report_list.append(
                     ReportItem.warning(
                         reports.messages.ResourceManagedNoMonitorEnabled(
-                            str(resource_el.get("id", ""))
+                            str(primitive_el.get("id", ""))
                         )
                     )
                 )
@@ -1422,7 +1490,7 @@ def manage(
 def group_add(
     env: LibraryEnvironment,
     group_id: str,
-    resource_id_list: Iterable[str],
+    resource_id_list: List[str],
     adjacent_resource_id: Optional[str] = None,
     put_after_adjacent: bool = True,
     wait: WaitType = False,
@@ -1611,7 +1679,7 @@ def move(
     resource_id: str,
     node: Optional[str] = None,
     master: bool = False,
-    lifetime: str = None,
+    lifetime: Optional[str] = None,
     wait: WaitType = False,
 ) -> None:
     """
@@ -1630,7 +1698,7 @@ def move(
 
 
 def _nodes_exist_reports(
-    cib: _Element, node_names: Iterable[str]
+    cib: _Element, node_names: StringCollection
 ) -> ReportItemList:
     existing_node_names = get_pacemaker_node_names(cib)
     return [
@@ -1684,15 +1752,19 @@ def move_autoclean(
     if env.report_processor.report_list(report_list).has_errors:
         raise LibraryError()
 
-    resource_state_before = get_resource_state(
-        env.get_cluster_state(), resource_id
-    )
+    cluster_state = env.get_cluster_state()
+    resource_state_before = get_resource_state(cluster_state, resource_id)
+    if not is_resource_managed(cluster_state, resource_id):
+        raise LibraryError(
+            ReportItem.error(reports.messages.ResourceIsUnmanaged(resource_id))
+        )
     if not _resource_running_on_nodes(resource_state_before):
         raise LibraryError(
             ReportItem.error(
                 reports.messages.CannotMoveResourceNotRunning(resource_id)
             )
         )
+
     with get_tmp_cib(env.report_processor, cib_xml) as rsc_moved_cib_file:
         stdout, stderr, retval = resource_move(
             env.cmd_runner(dict(CIB_file=rsc_moved_cib_file.name)),
@@ -2302,7 +2374,7 @@ def get_resource_relations_tree(
 
 def _find_resources_expand_tags(
     cib: _Element,
-    resource_or_tag_ids: Iterable[str],
+    resource_or_tag_ids: StringCollection,
     additional_search: Optional[Callable[[_Element], List[_Element]]] = None,
 ) -> Tuple[List[_Element], ReportItemList]:
     rsc_or_tag_el_list, report_list = resource.common.find_resources(
