@@ -1,6 +1,11 @@
 from pcs import settings
 from pcs.common import reports
 from pcs.common.reports.item import ReportItem
+from pcs.lib import (
+    sbd,
+    validate,
+)
+from pcs.lib.communication.nodes import GetOnlineTargets
 from pcs.lib.communication.sbd import (
     CheckSbd,
     DisableSbdService,
@@ -11,19 +16,11 @@ from pcs.lib.communication.sbd import (
     SetSbdConfig,
     SetStonithWatchdogTimeoutToZero,
 )
-from pcs.lib.communication.nodes import GetOnlineTargets
-from pcs.lib.communication.tools import (
-    run as run_com,
-    run_and_raise,
-)
-from pcs.lib import (
-    sbd,
-    validate,
-)
-from pcs.lib.tools import environment_file_to_dict
+from pcs.lib.communication.tools import run as run_com
+from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.errors import LibraryError
 from pcs.lib.node import get_existing_nodes_names
-
+from pcs.lib.tools import environment_file_to_dict
 
 UNSUPPORTED_SBD_OPTION_LIST = [
     "SBD_WATCHDOG_DEV",
@@ -41,14 +38,19 @@ _TIMEOUT_ACTION_ALLOWED_VALUES = (
     {"flush", "noflush"},
     {"reboot", "off", "crashdump"},
 )
-_tuple = lambda set1, set2: {f"{v1},{v2}" for v1 in set1 for v2 in set2}
+
+
+def __tuple(set1, set2):
+    return {f"{v1},{v2}" for v1 in set1 for v2 in set2}
+
+
 TIMEOUT_ACTION_ALLOWED_VALUE_LIST = sorted(
     _TIMEOUT_ACTION_ALLOWED_VALUES[0]
     | _TIMEOUT_ACTION_ALLOWED_VALUES[1]
-    | _tuple(
+    | __tuple(
         _TIMEOUT_ACTION_ALLOWED_VALUES[0], _TIMEOUT_ACTION_ALLOWED_VALUES[1]
     )
-    | _tuple(
+    | __tuple(
         _TIMEOUT_ACTION_ALLOWED_VALUES[1], _TIMEOUT_ACTION_ALLOWED_VALUES[0]
     )
 )
@@ -141,7 +143,7 @@ def enable_sbd(
         as value
     allow_unknown_opts -- if True, accept also unknown options.
     ignore_offline_nodes -- if True, omit offline nodes
-    no_watchdog_validation -- it True, do not validate existance of a watchdog
+    no_watchdog_validation -- it True, do not validate existence of a watchdog
         on the nodes
     allow_invalid_option_values -- if True, invalid values of some options will
         be treated as warning instead of errors
@@ -472,10 +474,10 @@ def set_message(lib_env, device, node_name, message):
     """
     Set message on device for node_name.
 
-    lib_env -- LibrayEnvironment
+    lib_env -- LibraryEnvironment
     device -- string, absolute path to device
     node_name -- string
-    message -- string, mesage type, should be one of settings.sbd_message_types
+    message -- string, message type, should be one of settings.sbd_message_types
     """
     report_item_list = []
     missing_options = []
