@@ -1,15 +1,20 @@
-from logging import Logger
-from shlex import quote as shell_quote
 import signal
 import subprocess
-from typing import Dict, Mapping, Optional, Sequence, Tuple
+from logging import Logger
+from shlex import quote as shell_quote
+from typing import (
+    Dict,
+    Mapping,
+    Optional,
+    Tuple,
+)
 
 from pcs import settings
 from pcs.common import reports
 from pcs.common.reports import ReportProcessor
 from pcs.common.reports.item import ReportItem
-
 from pcs.common.str_tools import join_multilines
+from pcs.common.types import StringSequence
 from pcs.lib.errors import LibraryError
 
 
@@ -35,7 +40,7 @@ class CommandRunner:
         # where the library runs.  We also get rid of PATH settings, so all
         # executables must be specified with full path unless the PATH variable
         # is set from outside.
-        self._env_vars = env_vars if env_vars else dict()
+        self._env_vars = env_vars if env_vars else {}
 
     @property
     def env_vars(self) -> Dict[str, str]:
@@ -43,7 +48,7 @@ class CommandRunner:
 
     def run(
         self,
-        args: Sequence[str],
+        args: StringSequence,
         stdin_string: Optional[str] = None,
         env_extend: Optional[Mapping[str, str]] = None,
         binary_output: bool = False,
@@ -53,7 +58,7 @@ class CommandRunner:
         # a pacemaker tool on a CIB in a file but cannot afford the risk of
         # changing the CIB in the file specified by the user.
         env_vars = dict(self._env_vars)
-        env_vars.update(dict(env_extend) if env_extend else dict())
+        env_vars.update(dict(env_extend) if env_extend else {})
 
         log_args = " ".join([shell_quote(x) for x in args])
         self._logger.debug(
@@ -160,7 +165,7 @@ def kill_services(runner, services):
     )
     # If a process isn't running, killall will still return 1 even with --quiet.
     # We don't consider that an error, so we check for output string as well.
-    # If it's empty, no actuall error happened.
+    # If it's empty, no actual error happened.
     if retval != 0:
         message = join_multilines([stderr, stdout])
         if message:
