@@ -1,10 +1,25 @@
-from pcs.common import file_type_codes
+from typing import (
+    Any,
+    Optional,
+)
+
+from pcs.common import (
+    file_type_codes,
+    reports,
+)
+from pcs.common.file import (
+    FileMetadata,
+    RawFileInterface,
+)
 from pcs.lib.file import (
     metadata,
     raw_file,
     toolbox,
 )
-from pcs.lib.interface.config import FacadeInterface
+from pcs.lib.interface.config import (
+    FacadeInterface,
+    ParserErrorException,
+)
 
 
 class FileInstance:
@@ -13,33 +28,49 @@ class FileInstance:
     """
 
     @classmethod
-    def for_booth_config(cls, name, ghost_file=False, ghost_data=None):
+    def for_booth_config(
+        cls,
+        name: str,
+        ghost_file: bool = False,
+        ghost_data: Optional[bytes] = None,
+    ) -> "FileInstance":
         """
         Factory for booth config file
 
-        string name -- booth instance name
-        bool ghost_file -- use GhostFile if True, RealFile otherwise
-        bytes ghost_data -- initial GhostFile data
+        name -- booth instance name
+        ghost_file -- use GhostFile if True, RealFile otherwise
+        ghost_data -- initial GhostFile data
         """
         return cls._for_booth(
             file_type_codes.BOOTH_CONFIG, name, ghost_file, ghost_data
         )
 
     @classmethod
-    def for_booth_key(cls, name, ghost_file=False, ghost_data=None):
+    def for_booth_key(
+        cls,
+        name: str,
+        ghost_file: bool = False,
+        ghost_data: Optional[bytes] = None,
+    ) -> "FileInstance":
         """
         Factory for booth key file
 
-        string name -- booth instance name
-        bool ghost_file -- use GhostFile if True, RealFile otherwise
-        bytes ghost_data -- initial GhostFile data
+        name -- booth instance name
+        ghost_file -- use GhostFile if True, RealFile otherwise
+        ghost_data -- initial GhostFile data
         """
         return cls._for_booth(
             file_type_codes.BOOTH_KEY, name, ghost_file, ghost_data
         )
 
     @classmethod
-    def _for_booth(cls, file_type_code, name, ghost_file, ghost_data):
+    def _for_booth(
+        cls,
+        file_type_code: file_type_codes.FileTypeCode,
+        name: str,
+        ghost_file: bool,
+        ghost_data: Optional[bytes],
+    ) -> "FileInstance":
         return cls(
             _get_raw_file(
                 metadata.for_file_type(file_type_code, name),
@@ -50,14 +81,14 @@ class FileInstance:
         )
 
     @classmethod
-    def for_known_hosts(cls):
+    def for_known_hosts(cls) -> "FileInstance":
         """
         Factory for known-hosts file
         """
         return cls._for_common(file_type_codes.PCS_KNOWN_HOSTS)
 
     @classmethod
-    def for_pacemaker_key(cls):
+    def for_pacemaker_key(cls) -> "FileInstance":
         """
         Factory for pacemaker key file
         """
@@ -77,6 +108,14 @@ class FileInstance:
         """
         return cls._for_common(file_type_codes.COROSYNC_CONF)
 
+    @classmethod
+    def for_pcs_users_config(cls) -> "FileInstance":
+        return cls._for_common(file_type_codes.PCS_USERS_CONF)
+
+    @classmethod
+    def for_pcs_settings_config(cls) -> "FileInstance":
+        return cls._for_common(file_type_codes.PCS_SETTINGS_CONF)
+
     @classmethod
     def _for_common(
         cls,
@@ -89,7 +128,7 @@ class FileInstance:
 
     def __init__(
         self,
-        raw_file_interface: raw_file.RawFileInterface,
+        raw_file_interface: RawFileInterface,
         file_toolbox: toolbox.FileToolbox,
     ):
         """
@@ -102,7 +141,7 @@ class FileInstance:
         self._toolbox = file_toolbox
 
     @property
-    def raw_file(self) -> raw_file.RawFileInterface:
+    def raw_file(self) -> RawFileInterface:
         """
         Get the underlying RawFileInterface instance
         """
@@ -116,14 +155,17 @@ class FileInstance:
         return self._toolbox
 
     def parser_exception_to_report_list(
-        self, exception, force_code=None, is_forced_or_warning=False
-    ):
+        self,
+        exception: ParserErrorException,
+        force_code: Optional[reports.types.ForceCode] = None,
+        is_forced_or_warning: bool = False,
+    ) -> reports.ReportItemList:
         """
         Translate a RawFileError instance to a report
 
-        RawFileError exception -- an exception to be translated
+        exception -- an exception to be translated
         string force_code -- is it a forcible error? by which code?
-        bool is_forced_or_warning -- return a warning if True, error otherwise
+        is_forced_or_warning -- return a warning if True, error otherwise
         """
         return self._toolbox.parser.exception_to_report_list(
             exception,
@@ -137,54 +179,62 @@ class FileInstance:
             is_forced_or_warning,
         )
 
-    def read_to_facade(self):
+    def read_to_facade(self) -> FacadeInterface:
         return self._toolbox.facade(self.read_to_structure())
 
-    def read_to_structure(self):
+    def read_to_structure(self) -> Any:
         return self._toolbox.parser.parse(self.read_raw())
 
-    def read_raw(self):
+    def read_raw(self) -> bytes:
         return self._raw_file.read()
 
-    def raw_to_facade(self, raw_file_data):
+    def raw_to_facade(self, raw_file_data: bytes) -> FacadeInterface:
         """
         Parse raw file data and return a corresponding facade
 
-        bytes raw_file_data -- data to be parsed
+        raw_file_data -- data to be parsed
         """
         return self._toolbox.facade(self.raw_to_structure(raw_file_data))
 
-    def raw_to_structure(self, raw_file_data):
+    def raw_to_structure(self, raw_file_data: bytes) -> Any:
         """
         Parse raw file data and return a corresponding structure
 
-        bytes raw_file_data -- data to be parsed
+        raw_file_data -- data to be parsed
         """
         return self._toolbox.parser.parse(raw_file_data)
 
     def facade_to_raw(self, facade: FacadeInterface) -> bytes:
         return self._toolbox.exporter.export(facade.config)
 
-    def write_facade(self, facade, can_overwrite=False):
+    def write_facade(
+        self, facade: FacadeInterface, can_overwrite: bool = False
+    ) -> None:
         self.write_structure(facade.config, can_overwrite=can_overwrite)
 
-    def write_structure(self, structure, can_overwrite=False):
+    def write_structure(
+        self, structure: Any, can_overwrite: bool = False
+    ) -> None:
         self.write_raw(
             self._toolbox.exporter.export(structure),
             can_overwrite=can_overwrite,
         )
 
-    def write_raw(self, raw_file_data, can_overwrite=False):
+    def write_raw(
+        self, raw_file_data: bytes, can_overwrite: bool = False
+    ) -> None:
         """
         Write raw data to a file
 
-        bytes raw_file_data -- data to be written
-        bool can_overwrite -- raise if False and the file already exists
+        raw_file_data -- data to be written
+        can_overwrite -- raise if False and the file already exists
         """
         self._raw_file.write(raw_file_data, can_overwrite=can_overwrite)
 
 
-def _get_raw_file(file_metadata, is_ghost, ghost_data):
+def _get_raw_file(
+    file_metadata: FileMetadata, is_ghost: bool, ghost_data: Optional[bytes]
+) -> RawFileInterface:
     if is_ghost:
         return raw_file.GhostFile(file_metadata, file_data=ghost_data)
     return raw_file.RealFile(file_metadata)
