@@ -1,12 +1,12 @@
 import os.path
 import re
 from typing import (
-    cast,
     Dict,
-    Iterable,
     List,
+    Mapping,
     Optional,
     Tuple,
+    cast,
 )
 
 from lxml import etree
@@ -18,23 +18,24 @@ from pcs.common.reports import ReportProcessor
 from pcs.common.reports.item import ReportItem
 from pcs.common.str_tools import join_multilines
 from pcs.common.tools import (
+    Version,
     format_os_error,
     xml_fromstring,
-    Version,
 )
-from pcs.common.types import CibRuleInEffectStatus
+from pcs.common.types import (
+    CibRuleInEffectStatus,
+    StringCollection,
+    StringSequence,
+)
+from pcs.lib import tools
 from pcs.lib.cib.tools import get_pacemaker_version_by_which_cib_was_validated
 from pcs.lib.errors import LibraryError
 from pcs.lib.external import CommandRunner
 from pcs.lib.pacemaker import api_result
 from pcs.lib.pacemaker.state import ClusterState
-from pcs.lib.tools import (
-    get_tmp_cib,
-    get_tmp_file,
-)
+from pcs.lib.resource_agent import ResourceAgentName
 from pcs.lib.xml_tools import etree_to_str
 
-
 __EXITCODE_NOT_CONNECTED = 102
 __EXITCODE_CIB_SCOPE_VALID_BUT_NOT_PRESENT = 105
 __EXITCODE_WAIT_TIMEOUT = 124
@@ -52,78 +53,55 @@ class FenceHistoryCommandErrorException(Exception):
 ### status
 
 
+def get_cluster_status_xml_raw(runner: CommandRunner) -> Tuple[str, str, int]:
+    """
+    Run pacemaker tool to get XML status. This function doesn't do any
+    processing. Usually, using get_cluster_status_dom is preferred instead.
+
+    runner -- a class for running external processes
+    """
+    return runner.run(
+        [__exec("crm_mon"), "--one-shot", "--inactive", "--output-as", "xml"]
+    )
+
+
+def _get_cluster_status_xml(runner: CommandRunner) -> str:
+    """
+    Get pacemaker XML status. Using get_cluster_status_dom is preferred instead.
+
+    runner -- a class for running external processes
+    """
+    stdout, stderr, retval = get_cluster_status_xml_raw(runner)
+    if retval == 0:
+        return stdout
+
+    # We parse error messages from XML. If we didn't get an XML, we pass it to
+    # the exception as a plaintext. If we got an XML but it doesn't conform to
+    # the schema, we raise an error.
+    try:
+        status = _get_status_from_api_result(_get_api_result_dom(stdout))
+        message = join_multilines([status.message] + list(status.errors))
+    except etree.XMLSyntaxError:
+        message = join_multilines([stderr, stdout])
+    except etree.DocumentInvalid as e:
+        raise LibraryError(
+            ReportItem.error(reports.messages.BadClusterStateFormat())
+        ) from e
+    klass = (
+        PacemakerNotConnectedException
+        if retval == __EXITCODE_NOT_CONNECTED
+        else LibraryError
+    )
+    raise klass(ReportItem.error(reports.messages.CrmMonError(message)))
+
+
 def get_cluster_status_dom(runner: CommandRunner) -> _Element:
-    def validate_dom(dom, rng):
-        try:
-            if os.path.isfile(rng):
-                etree.RelaxNG(file=rng).assertValid(dom)
-            return dom
-        except etree.DocumentInvalid as e:
-            raise LibraryError(
-                ReportItem.error(reports.messages.BadClusterStateFormat())
-            ) from e
-
-    def get_dom(xml, rng):
-        try:
-            return validate_dom(xml_fromstring(xml), rng)
-        except etree.XMLSyntaxError as e:
-            raise LibraryError(
-                ReportItem.error(reports.messages.BadClusterStateFormat())
-            ) from e
-
-    pcmk_supports_new_format = _is_in_pcmk_tool_help(
-        runner, "crm_mon", "--output-as="
-    )
-    format_option = (
-        ["--output-as", "xml"] if pcmk_supports_new_format else ["--as-xml"]
-    )
-
-    stdout, stderr, retval = runner.run(
-        [__exec("crm_mon"), "--one-shot", "--inactive"] + format_option
-    )
-
-    if retval != 0:
-        klass = (
-            PacemakerNotConnectedException
-            if retval == __EXITCODE_NOT_CONNECTED
-            else LibraryError
-        )
-        if pcmk_supports_new_format:
-            # Try to process the output as an XML. If it cannot be parsed, then
-            # process it as a plaintext. If it is an XML but it doesn't conform
-            # to the schema, raise an error (don't catch etree.DocumentInvalid
-            # exception).
-            try:
-                status = get_status_from_api_result(
-                    validate_dom(
-                        xml_fromstring(stdout),
-                        settings.pacemaker_api_result_schema,
-                    )
-                )
-                message = join_multilines(
-                    [status.message] + list(status.errors)
-                )
-            except etree.XMLSyntaxError:
-                message = join_multilines([stderr, stdout])
-        else:
-            message = join_multilines([stderr, stdout])
-        raise klass(ReportItem.error(reports.messages.CrmMonError(message)))
-
-    if pcmk_supports_new_format:
-        return get_dom(stdout, settings.pacemaker_api_result_schema)
-
-    dom = get_dom(stdout, settings.crm_mon_schema)
-    new_format_dom = etree.Element(
-        "pacemaker-result",
-        {
-            "api-version": "2.3",
-            "request": "crm_mon --as-xml",
-        },
-    )
-    for child in dom.getchildren():
-        new_format_dom.append(child)
-    etree.SubElement(new_format_dom, "status", {"code": "0", "message": "OK"})
-    return validate_dom(new_format_dom, settings.pacemaker_api_result_schema)
+    try:
+        return _get_api_result_dom(_get_cluster_status_xml(runner))
+    except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
+        raise LibraryError(
+            ReportItem.error(reports.messages.BadClusterStateFormat())
+        ) from e
 
 
 def get_cluster_status_text(
@@ -167,7 +145,9 @@ def get_ticket_status_text(runner: CommandRunner) -> Tuple[str, str, int]:
 ### cib
 
 
-def get_cib_xml_cmd_results(runner, scope=None):
+def get_cib_xml_cmd_results(
+    runner: CommandRunner, scope: Optional[str] = None
+) -> tuple[str, str, int]:
     command = [__exec("cibadmin"), "--local", "--query"]
     if scope:
         command.append("--scope={0}".format(scope))
@@ -175,7 +155,7 @@ def get_cib_xml_cmd_results(runner, scope=None):
     return stdout, stderr, returncode
 
 
-def get_cib_xml(runner, scope=None):
+def get_cib_xml(runner: CommandRunner, scope: Optional[str] = None) -> str:
     stdout, stderr, retval = get_cib_xml_cmd_results(runner, scope)
     if retval != 0:
         if retval == __EXITCODE_CIB_SCOPE_VALID_BUT_NOT_PRESENT and scope:
@@ -194,11 +174,11 @@ def get_cib_xml(runner, scope=None):
     return stdout
 
 
-def parse_cib_xml(xml):
+def parse_cib_xml(xml: str) -> _Element:
     return xml_fromstring(xml)
 
 
-def get_cib(xml):
+def get_cib(xml: str) -> _Element:
     try:
         return parse_cib_xml(xml)
     except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
@@ -236,7 +216,7 @@ def verify(runner, verbose=False):
             new_lines.append(line)
         # pcs has only one verbose option and cannot be more verbose like
         # `crm_verify` with more -V options. Decision has been made that pcs is
-        # limited to only two -V opions.
+        # limited to only two -V options.
         if verbose:
             can_be_more_verbose = False
         stderr = "".join(new_lines)
@@ -291,7 +271,9 @@ def diff_cibs_xml(
     cib_old_xml -- original CIB
     cib_new_xml -- modified CIB
     """
-    with get_tmp_cib(reporter, cib_old_xml) as cib_old_tmp_file, get_tmp_cib(
+    with tools.get_tmp_cib(
+        reporter, cib_old_xml
+    ) as cib_old_tmp_file, tools.get_tmp_cib(
         reporter, cib_new_xml
     ) as cib_new_tmp_file:
         stdout, stderr, retval = runner.run(
@@ -402,7 +384,7 @@ def simulate_cib_xml(runner, cib_xml):
     string cib_xml -- CIB XML to simulate
     """
     try:
-        with get_tmp_file() as new_cib_file, get_tmp_file() as transitions_file:
+        with tools.get_tmp_file() as new_cib_file, tools.get_tmp_file() as transitions_file:
             cmd = [
                 __exec("crm_simulate"),
                 "--simulate",
@@ -783,7 +765,16 @@ def get_rule_in_effect_status(
     return translation_map.get(retval, CibRuleInEffectStatus.UNKNOWN)
 
 
-def get_status_from_api_result(dom: _Element) -> api_result.Status:
+def _get_api_result_dom(xml: str) -> _Element:
+    # raises etree.XMLSyntaxError and etree.DocumentInvalid
+    rng = settings.pacemaker_api_result_schema
+    dom = xml_fromstring(xml)
+    if os.path.isfile(rng):
+        etree.RelaxNG(file=rng).assertValid(dom)
+    return dom
+
+
+def _get_status_from_api_result(dom: _Element) -> api_result.Status:
     errors = []
     status_el = cast(_Element, dom.find("./status"))
     errors_el = status_el.find("errors")
@@ -805,7 +796,7 @@ def __exec(name):
 
 
 def _is_in_pcmk_tool_help(
-    runner: CommandRunner, tool: str, text_list: Iterable[str]
+    runner: CommandRunner, tool: str, text_list: StringCollection
 ) -> bool:
     stdout, stderr, dummy_retval = runner.run([__exec(tool), "--help-all"])
     # Help goes to stderr but we check stdout as well if that gets changed. Use
@@ -839,7 +830,7 @@ def get_resource_digests(
     """
     # pylint: disable=too-many-locals
     if crm_meta_attributes is None:
-        crm_meta_attributes = dict()
+        crm_meta_attributes = {}
     command = [
         __exec("crm_resource"),
         "--digests",
@@ -866,16 +857,12 @@ def get_resource_digests(
         )
 
     try:
-        dom = xml_fromstring(stdout)
-        if os.path.isfile(settings.pacemaker_api_result_schema):
-            etree.RelaxNG(
-                file=settings.pacemaker_api_result_schema
-            ).assertValid(dom)
+        dom = _get_api_result_dom(stdout)
     except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
         raise error_exception(join_multilines([stderr, stdout])) from e
 
     if retval != 0:
-        status = get_status_from_api_result(dom)
+        status = _get_status_from_api_result(dom)
         raise error_exception(
             join_multilines([status.message] + list(status.errors))
         )
@@ -884,9 +871,101 @@ def get_resource_digests(
     for digest_type in ["all", "nonprivate", "nonreloadable"]:
         xpath_result = cast(
             List[str],
-            dom.xpath(f'./digests/digest[@type="{digest_type}"]/@hash'),
+            dom.xpath(
+                "./digests/digest[@type=$digest_type]/@hash",
+                digest_type=digest_type,
+            ),
         )
         digests[digest_type] = xpath_result[0] if xpath_result else None
     if not any(digests.values()):
         raise error_exception(join_multilines([stderr, stdout]))
     return digests
+
+
+def _validate_stonith_instance_attributes_via_pcmk(
+    cmd_runner: CommandRunner,
+    agent_name: ResourceAgentName,
+    instance_attributes: Mapping[str, str],
+) -> tuple[Optional[bool], str]:
+    cmd = [
+        settings.stonith_admin,
+        "--validate",
+        "--output-as",
+        "xml",
+        "--agent",
+        agent_name.type,
+    ]
+    return _handle_instance_attributes_validation_via_pcmk(
+        cmd_runner,
+        cmd,
+        "./validate/command/output",
+        instance_attributes,
+    )
+
+
+def _validate_resource_instance_attributes_via_pcmk(
+    cmd_runner: CommandRunner,
+    agent_name: ResourceAgentName,
+    instance_attributes: Mapping[str, str],
+) -> tuple[Optional[bool], str]:
+    cmd = [
+        settings.crm_resource_binary,
+        "--validate",
+        "--output-as",
+        "xml",
+        "--class",
+        agent_name.standard,
+        "--agent",
+        agent_name.type,
+    ]
+    if agent_name.provider:
+        cmd.extend(["--provider", agent_name.provider])
+    return _handle_instance_attributes_validation_via_pcmk(
+        cmd_runner,
+        cmd,
+        "./resource-agent-action/command/output",
+        instance_attributes,
+    )
+
+
+def _handle_instance_attributes_validation_via_pcmk(
+    cmd_runner: CommandRunner,
+    cmd: StringSequence,
+    data_xpath: str,
+    instance_attributes: Mapping[str, str],
+) -> tuple[Optional[bool], str]:
+    full_cmd = list(cmd)
+    for key, value in sorted(instance_attributes.items()):
+        full_cmd.extend(["--option", f"{key}={value}"])
+    stdout, dummy_stderr, return_value = cmd_runner.run(full_cmd)
+    try:
+        # dom = _get_api_result_dom(stdout)
+        dom = xml_fromstring(stdout)
+    except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
+        return None, str(e)
+    result = "\n".join(
+        "\n".join(
+            line.strip() for line in item.text.split("\n") if line.strip()
+        )
+        for item in dom.iterfind(data_xpath)
+        if item.get("source") == "stderr" and item.text
+    ).strip()
+    return return_value == 0, result
+
+
+def validate_resource_instance_attributes_via_pcmk(
+    cmd_runner: CommandRunner,
+    resource_agent_name: ResourceAgentName,
+    instance_attributes: Mapping[str, str],
+) -> tuple[Optional[bool], str]:
+    if resource_agent_name.is_stonith:
+        return _validate_stonith_instance_attributes_via_pcmk(
+            cmd_runner,
+            resource_agent_name,
+            instance_attributes,
+        )
+    return _validate_resource_instance_attributes_via_pcmk(
+        cmd_runner,
+        resource_agent_name,
+        instance_attributes,
+    )
