@@ -29,17 +29,20 @@ entered one is reported as not valid.
 """
 import ipaddress
 import re
+from collections import Counter
 from typing import (
     Any,
     Callable,
     Container,
-    cast,
+    Dict,
     Iterable,
     Mapping,
     NamedTuple,
     Optional,
     Pattern,
+    Set,
     Union,
+    cast,
 )
 
 from pcs.common import reports
@@ -48,24 +51,32 @@ from pcs.common.reports import (
     ReportItemList,
     ReportItemSeverity,
 )
+from pcs.common.str_tools import format_list
+from pcs.common.tools import timeout_to_seconds
+from pcs.common.types import (
+    StringCollection,
+    StringIterable,
+)
 from pcs.common.validate import (
     is_integer,
     is_port_number,
 )
+from pcs.lib.cib.tools import IdProvider
 from pcs.lib.corosync import constants as corosync_constants
 from pcs.lib.pacemaker.values import (
+    BOOLEAN_VALUES,
+    SCORE_INFINITY,
+    is_boolean,
     is_score,
-    timeout_to_seconds,
     validate_id,
 )
-from pcs.lib.cib.tools import IdProvider
 
 _FLOAT_RE = re.compile(r"^[-+]?(\d+|(\d*\.\d+)|(\d+\.\d*))([eE][+-]?\d+)?$")
 _PCMK_DATESPEC_PART_RE = re.compile(r"^(?P<since>[0-9]+)(-(?P<until>[0-9]+))?$")
 
 TypeOptionName = str
 TypeOptionValue = str
-TypeOptionRawMap = Mapping[TypeOptionName, TypeOptionValue]
+TypeOptionRawMap = Dict[TypeOptionName, TypeOptionValue]
 TypeNormalizeFunc = Callable[[TypeOptionName, TypeOptionValue], TypeOptionValue]
 
 ### normalization
@@ -213,13 +224,18 @@ class KeyValidator(ValidatorInterface):
         self,
         option_name_list: Iterable[TypeOptionName],
         option_type: Optional[str] = None,
+        severity: Optional[ReportItemSeverity] = None,
     ):
         """
         option_name_list -- names of the options to check
         option_type -- describes a type of the options for reporting
+        severity -- severity of produced reports, defaults to error
         """
         self._option_name_list = option_name_list
         self._option_type = option_type
+        self._severity = (
+            ReportItemSeverity.error() if severity is None else severity
+        )
 
     def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
         raise NotImplementedError()
@@ -231,8 +247,12 @@ class CorosyncOption(KeyValidator):
     suitable for corosync.conf
     """
 
-    def __init__(self, option_type: Optional[str] = None):
-        super().__init__([], option_type=option_type)
+    def __init__(
+        self,
+        option_type: Optional[str] = None,
+        severity: Optional[ReportItemSeverity] = None,
+    ):
+        super().__init__([], option_type=option_type, severity=severity)
 
     def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
         not_valid_options = [
@@ -245,12 +265,13 @@ class CorosyncOption(KeyValidator):
             # otherwise setting a cratfed option name could be misused for
             # setting arbitrary corosync.conf settings.
             return [
-                ReportItem.error(
+                ReportItem(
+                    self._severity,
                     reports.messages.InvalidUserdefinedOptions(
                         sorted(not_valid_options),
                         "a-z A-Z 0-9 /_-",
                         self._option_type,
-                    )
+                    ),
                 )
             ]
         return []
@@ -268,24 +289,28 @@ class DependsOnOption(KeyValidator):
         prerequisite_name: TypeOptionName,
         option_type: Optional[str] = None,
         prerequisite_type: Optional[str] = None,
+        severity: Optional[ReportItemSeverity] = None,
     ):
         """
         prerequisite_name -- name of the prerequisite options
         prerequisite_type -- describes the prerequisite for reporting
         """
-        super().__init__(option_name_list, option_type=option_type)
+        super().__init__(
+            option_name_list, option_type=option_type, severity=severity
+        )
         self._prerequisite_name = prerequisite_name
         self._prerequisite_type = prerequisite_type
 
     def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
         return [
-            ReportItem.error(
+            ReportItem(
+                self._severity,
                 reports.messages.PrerequisiteOptionIsMissing(
                     option_name,
                     self._prerequisite_name,
                     self._option_type,
                     self._prerequisite_type,
-                )
+                ),
             )
             for option_name in self._option_name_list
             if (
@@ -295,6 +320,48 @@ class DependsOnOption(KeyValidator):
         ]
 
 
+class DeprecatedOption(KeyValidator):
+    """
+    Report DEPRECATED_OPTION when the option_dict contains option_name_list
+    options
+    """
+
+    def __init__(
+        self,
+        option_name_list: Iterable[TypeOptionName],
+        deprecated_by: Iterable[TypeOptionName],
+        option_type: Optional[str] = None,
+        severity: Optional[ReportItemSeverity] = None,
+    ):
+        """
+        deprecated_by -- names of the options which should be used instead
+        """
+        super().__init__(
+            option_name_list,
+            option_type=option_type,
+            severity=(
+                ReportItemSeverity.deprecation()
+                if severity is None
+                else severity
+            ),
+        )
+        self._deprecated_by = sorted(deprecated_by)
+
+    def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
+        return [
+            ReportItem(
+                severity=self._severity,
+                message=reports.messages.DeprecatedOption(
+                    option_name,
+                    self._deprecated_by,
+                    self._option_type,
+                ),
+            )
+            for option_name in self._option_name_list
+            if (option_name in option_dict)
+        ]
+
+
 class IsRequiredAll(KeyValidator):
     """
     Report REQUIRED_OPTIONS_ARE_MISSING with all option_name_list options
@@ -305,11 +372,12 @@ class IsRequiredAll(KeyValidator):
         missing = set(self._option_name_list) - set(option_dict.keys())
         if missing:
             return [
-                ReportItem.error(
-                    reports.messages.RequiredOptionsAreMissing(
+                ReportItem(
+                    severity=self._severity,
+                    message=reports.messages.RequiredOptionsAreMissing(
                         sorted(missing),
                         self._option_type,
-                    )
+                    ),
                 )
             ]
         return []
@@ -321,15 +389,32 @@ class IsRequiredSome(KeyValidator):
     at least one item from the option_name_list
     """
 
+    def __init__(
+        self,
+        option_name_list: Iterable[TypeOptionName],
+        option_type: Optional[str] = None,
+        deprecated_option_name_list: Iterable[TypeOptionName] = frozenset(),
+        severity: Optional[ReportItemSeverity] = None,
+    ):
+        """
+        deprecated_option_name_list -- deprecated options from option_name_list
+        """
+        super().__init__(
+            option_name_list, option_type=option_type, severity=severity
+        )
+        self._deprecated_option_name_list = deprecated_option_name_list
+
     def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
         found = set(self._option_name_list) & set(option_dict.keys())
         if not found:
             return [
-                ReportItem.error(
+                ReportItem(
+                    self._severity,
                     reports.messages.RequiredOptionOfAlternativesIsMissing(
                         sorted(self._option_name_list),
+                        sorted(self._deprecated_option_name_list),
                         self._option_type,
-                    )
+                    ),
                 )
             ]
         return []
@@ -345,11 +430,12 @@ class MutuallyExclusive(KeyValidator):
         found = set(self._option_name_list) & set(option_dict.keys())
         if len(found) > 1:
             return [
-                ReportItem.error(
+                ReportItem(
+                    self._severity,
                     reports.messages.MutuallyExclusiveOptions(
                         sorted(found),
                         self._option_type,
-                    )
+                    ),
                 )
             ]
         return []
@@ -364,21 +450,19 @@ class NamesIn(KeyValidator):
         self,
         option_name_list: Iterable[TypeOptionName],
         option_type: Optional[str] = None,
-        allowed_option_patterns: Optional[Iterable[str]] = None,
+        allowed_option_patterns: Optional[StringIterable] = None,
         banned_name_list: Optional[Iterable[TypeOptionName]] = None,
         severity: Optional[ReportItemSeverity] = None,
     ):
         """
         allowed_option_patterns -- option patterns to be added to a report
         banned_name_list -- list of options which cannot be forced
-        severity -- severity of produced reports, defaults to error
         """
-        super().__init__(option_name_list, option_type=option_type)
+        super().__init__(
+            option_name_list, option_type=option_type, severity=severity
+        )
         self._allowed_option_patterns = allowed_option_patterns or []
         self._banned_name_set = set(banned_name_list or [])
-        self._severity = (
-            ReportItemSeverity.error() if severity is None else severity
-        )
 
     def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
         name_set = set(option_dict.keys())
@@ -476,21 +560,23 @@ class ValuePredicateBase(ValueValidator):
         self._forbidden_characters = None
 
     def _validate_value(self, value: ValuePair) -> ReportItemList:
-        if not self._is_valid(value.normalized):
-            return [
-                ReportItem(
-                    severity=self._severity,
-                    message=reports.messages.InvalidOptionValue(
-                        self._get_option_name_for_report(),
-                        value.original,
-                        self._get_allowed_values(),
-                        cannot_be_empty=self._value_cannot_be_empty,
-                        forbidden_characters=self._forbidden_characters,
-                    ),
-                )
-            ]
+        return (
+            []
+            if self._is_valid(value.normalized)
+            else [self._get_report_item(value)]
+        )
 
-        return []
+    def _get_report_item(self, value: ValuePair) -> ReportItem:
+        return ReportItem(
+            severity=self._severity,
+            message=reports.messages.InvalidOptionValue(
+                self._get_option_name_for_report(),
+                value.original,
+                self._get_allowed_values(),
+                cannot_be_empty=self._value_cannot_be_empty,
+                forbidden_characters=self._forbidden_characters,
+            ),
+        )
 
     def _is_valid(self, value: TypeOptionValue) -> bool:
         raise NotImplementedError()
@@ -579,6 +665,49 @@ class ValueId(ValueValidator):
         return report_list
 
 
+class ValueDeprecated(ValueValidator):
+    """
+    Report DEPRECATED_OPTION_VALUE when a value has been deprecated and
+    replaced by new value
+    """
+
+    def __init__(
+        self,
+        option_name: TypeOptionName,
+        deprecation_map: Mapping[str, Optional[str]],
+        severity: Optional[ReportItemSeverity] = None,
+        option_name_for_report: Optional[str] = None,
+    ):
+        """
+        deprecation_map -- keys are deprecated values and values are new
+            values. If values is None, deprecated value has no direct
+            replacement
+        """
+        super().__init__(
+            option_name,
+            option_name_for_report=option_name_for_report,
+        )
+        self._severity = (
+            ReportItemSeverity.deprecation() if severity is None else severity
+        )
+        self._deprecation_map = deprecation_map
+
+    def _validate_value(self, value: ValuePair) -> ReportItemList:
+        if value.normalized in self._deprecation_map:
+            return [
+                ReportItem(
+                    severity=self._severity,
+                    message=reports.messages.DeprecatedOptionValue(
+                        option_name=self._get_option_name_for_report(),
+                        deprecated_value=value.original,
+                        replaced_by=self._deprecation_map[value.normalized],
+                    ),
+                )
+            ]
+
+        return []
+
+
 class ValueIn(ValuePredicateBase):
     """
     Report INVALID_OPTION_VALUE when a value is not in a set of allowed values
@@ -711,6 +840,19 @@ class ValueNotEmpty(ValuePredicateBase):
         return self._value_desc_or_enum
 
 
+class ValuePcmkBoolean(ValuePredicateBase):
+    """
+    Report INVALID_OPTION_VALUE when the value is not a pacemaker boolean value
+    """
+
+    def _is_valid(self, value: TypeOptionValue) -> bool:
+        return is_boolean(value)
+
+    def _get_allowed_values(self) -> Any:
+        bool_values = format_list(list(BOOLEAN_VALUES))
+        return f"a pacemaker boolean value: {bool_values}"
+
+
 class ValuePcmkDatespecPart(ValuePredicateBase):
     """
     Report INVALID_OPTION_VALUE when the value is not a valid Pacemaker
@@ -753,6 +895,49 @@ class ValuePcmkDatespecPart(ValuePredicateBase):
         )
 
 
+class ValuePcmkPercentage(ValuePredicateBase):
+    """
+    Report INVALID_OPTION_VALUE when the value is not a non-negative integer
+    followed by '%' character.
+    """
+
+    def _is_valid(self, value: TypeOptionValue) -> bool:
+        return bool(value) and value[-1] == "%" and is_integer(value[:-1], 0)
+
+    def _get_allowed_values(self) -> Any:
+        return (
+            "a non-negative integer followed by '%' (e.g. 0%, 50%, 200%, ...)"
+        )
+
+
+class ValuePcmkInteger(ValuePredicateBase):
+    """
+    Report INVALID_OPTION_VALUE when the value is not an integer or
+    INFINITY/-INFINITY
+    """
+
+    def _is_valid(self, value: TypeOptionValue) -> bool:
+        return is_score(value)
+
+    def _get_allowed_values(self) -> Any:
+        return f"an integer or {SCORE_INFINITY} or -{SCORE_INFINITY}"
+
+
+class ValuePcmkPositiveInteger(ValuePredicateBase):
+    """
+    Report INVALID_OPTION_VALUE when the value is not a positive integer or
+    INFINITY
+    """
+
+    def _is_valid(self, value: TypeOptionValue) -> bool:
+        return value in [SCORE_INFINITY, f"+{SCORE_INFINITY}"] or is_integer(
+            value, 1
+        )
+
+    def _get_allowed_values(self) -> Any:
+        return f"a positive integer or {SCORE_INFINITY}"
+
+
 class ValuePortNumber(ValuePredicateBase):
     """
     Report INVALID_OPTION_VALUE when the value is not a TCP or UDP port number
@@ -772,7 +957,7 @@ class ValuePortRange(ValuePredicateBase):
 
     def _is_valid(self, value: TypeOptionValue) -> bool:
         return matches_regexp(value, "^[0-9]+-[0-9]+$") and all(
-            [is_port_number(part) for part in value.split("-", 1)]
+            is_port_number(part) for part in value.split("-", 1)
         )
 
     def _get_allowed_values(self) -> Any:
@@ -930,3 +1115,281 @@ def matches_regexp(value: TypeOptionValue, regexp: Union[str, Pattern]) -> bool:
     if not hasattr(regexp, "match"):
         regexp = re.compile(regexp)
     return cast(Pattern, regexp).match(value) is not None
+
+
+### complex
+
+
+class _ValidateAddRemoveBase:
+    # pylint: disable=too-many-instance-attributes
+    def __init__(
+        self,
+        add_item_list: StringCollection,
+        remove_item_list: StringCollection,
+        current_item_list: StringCollection,
+        container_type: reports.types.AddRemoveContainerType,
+        item_type: reports.types.AddRemoveItemType,
+        container_id: str,
+        adjacent_item_id: Optional[str] = None,
+        container_can_be_empty: bool = False,
+        severity: Optional[ReportItemSeverity] = None,
+    ):
+        """
+        Validate if items can be added or removed to or from a container.
+
+        add_item_list -- items to be added
+        remove_item_list -- items to be removed
+        current_item_list -- items currently in the container
+        container_type -- container type
+        item_type -- item type
+        container_id -- id of the container
+        adjacent_item_id -- an adjacent item in the container
+        container_can_be_empty -- flag to decide if container can be left empty
+        severity -- severity of produced reports, defaults to error
+        """
+        # pylint: disable=too-many-arguments
+        self._add_item_list = add_item_list
+        self._remove_item_list = remove_item_list
+        self._current_item_list = current_item_list
+        self._container_type = container_type
+        self._item_type = item_type
+        self._container_id = container_id
+        self._adjacent_item_id = adjacent_item_id
+        self._container_can_be_empty = container_can_be_empty
+        self._severity = (
+            ReportItemSeverity.error() if severity is None else severity
+        )
+
+    def validate_add_or_remove_specified(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        if not self._add_item_list and not self._remove_item_list:
+            report_list.append(
+                ReportItem(
+                    self._severity,
+                    reports.messages.AddRemoveItemsNotSpecified(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                    ),
+                )
+            )
+        return report_list
+
+    @staticmethod
+    def _get_duplicate_items(item_list: StringIterable) -> Set[str]:
+        return {item for item, count in Counter(item_list).items() if count > 1}
+
+    def validate_no_duplicate_items(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        duplicate_items_list = self._get_duplicate_items(
+            self._add_item_list
+        ) | self._get_duplicate_items(self._remove_item_list)
+        if duplicate_items_list:
+            report_list.append(
+                ReportItem(
+                    self._severity,
+                    reports.messages.AddRemoveItemsDuplication(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        sorted(duplicate_items_list),
+                    ),
+                )
+            )
+        return report_list
+
+    def validate_add_items_not_yet_present(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        already_present = set(self._add_item_list).intersection(
+            self._current_item_list
+        )
+        # report only if an adjacent id is not defined, because we want to allow
+        # to move items when adjacent_item_id is specified
+        if self._adjacent_item_id is None and already_present:
+            report_list.append(
+                ReportItem.error(
+                    reports.messages.AddRemoveCannotAddItemsAlreadyInTheContainer(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        sorted(already_present),
+                    )
+                )
+            )
+        return report_list
+
+    def validate_remove_items_present(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        missing_items = set(self._remove_item_list).difference(
+            self._current_item_list
+        )
+        if missing_items:
+            report_list.append(
+                ReportItem(
+                    self._severity,
+                    reports.messages.AddRemoveCannotRemoveItemsNotInTheContainer(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        sorted(missing_items),
+                    ),
+                )
+            )
+        return report_list
+
+    def validate_item_not_both_added_and_removed(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        common_items = set(self._add_item_list) & set(self._remove_item_list)
+        if common_items:
+            report_list.append(
+                ReportItem.error(
+                    reports.messages.AddRemoveCannotAddAndRemoveItemsAtTheSameTime(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        sorted(common_items),
+                    )
+                )
+            )
+        return report_list
+
+    def validate_container_wont_be_empty(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        if not self._container_can_be_empty and not self._add_item_list:
+            remaining_items = set(self._current_item_list).difference(
+                self._remove_item_list
+            )
+            if not remaining_items:
+                report_list.append(
+                    ReportItem.error(
+                        reports.messages.AddRemoveCannotRemoveAllItemsFromTheContainer(
+                            self._container_type,
+                            self._item_type,
+                            self._container_id,
+                            list(self._current_item_list),
+                        )
+                    )
+                )
+        return report_list
+
+    def validate_adjacent(self) -> ReportItemList:
+        report_list: ReportItemList = []
+        if not self._adjacent_item_id:
+            return report_list
+
+        if self._adjacent_item_id not in self._current_item_list:
+            report_list.append(
+                ReportItem.error(
+                    reports.messages.AddRemoveAdjacentItemNotInTheContainer(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        self._adjacent_item_id,
+                    )
+                )
+            )
+        if self._adjacent_item_id in self._add_item_list:
+            report_list.append(
+                ReportItem.error(
+                    reports.messages.AddRemoveCannotPutItemNextToItself(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        self._adjacent_item_id,
+                    )
+                )
+            )
+        if not self._add_item_list:
+            report_list.append(
+                ReportItem.error(
+                    reports.messages.AddRemoveCannotSpecifyAdjacentItemWithoutItemsToAdd(
+                        self._container_type,
+                        self._item_type,
+                        self._container_id,
+                        self._adjacent_item_id,
+                    )
+                )
+            )
+        return report_list
+
+
+def validate_add_remove_items(
+    add_item_list: StringCollection,
+    remove_item_list: StringCollection,
+    current_item_list: StringCollection,
+    container_type: reports.types.AddRemoveContainerType,
+    item_type: reports.types.AddRemoveItemType,
+    container_id: str,
+    adjacent_item_id: Optional[str] = None,
+    container_can_be_empty: bool = False,
+) -> ReportItemList:
+    """
+    Validate if items can be added or removed to or from a container.
+
+    add_item_list -- items to be added
+    remove_item_list -- items to be removed
+    current_item_list -- items currently in the container
+    container_type -- container type
+    item_type -- item type
+    container_id -- id of the container
+    adjacent_item_id -- an adjacent item in the container
+    container_can_be_empty -- flag to decide if container can be left empty
+    """
+    validator = _ValidateAddRemoveBase(
+        add_item_list,
+        remove_item_list,
+        current_item_list,
+        container_type,
+        item_type,
+        container_id,
+        adjacent_item_id=adjacent_item_id,
+        container_can_be_empty=container_can_be_empty,
+    )
+    return (
+        validator.validate_add_or_remove_specified()
+        + validator.validate_no_duplicate_items()
+        + validator.validate_add_items_not_yet_present()
+        + validator.validate_remove_items_present()
+        + validator.validate_item_not_both_added_and_removed()
+        + validator.validate_container_wont_be_empty()
+        + validator.validate_adjacent()
+    )
+
+
+def validate_set_unset_items(
+    add_item_list: StringCollection,
+    remove_item_list: StringCollection,
+    current_item_list: StringCollection,
+    container_type: reports.types.AddRemoveContainerType,
+    item_type: reports.types.AddRemoveItemType,
+    container_id: str,
+    severity: Optional[ReportItemSeverity] = None,
+) -> ReportItemList:
+    """
+    Validate if items can be set or unset to or from a dict of options.
+
+    add_item_list -- items to be added
+    remove_item_list -- items to be removed
+    current_item_list -- items currently in the container
+    container_type -- container type
+    item_type -- item type
+    container_id -- id of the container
+    severity -- severity of produced reports, defaults to error
+    """
+    validator = _ValidateAddRemoveBase(
+        add_item_list,
+        remove_item_list,
+        current_item_list,
+        container_type,
+        item_type,
+        container_id,
+        adjacent_item_id=None,
+        container_can_be_empty=True,
+        severity=severity,
+    )
+    return (
+        validator.validate_add_or_remove_specified()
+        + validator.validate_no_duplicate_items()
+        + validator.validate_remove_items_present()
+        + validator.validate_item_not_both_added_and_removed()
+    )
