@@ -1,11 +1,19 @@
+from typing import Any
+
 from pcs import (
     stonith,
     utils,
 )
 from pcs.cli.common import parse_args
 from pcs.cli.common.errors import CmdLineInputError
+from pcs.cli.common.parse_args import InputModifiers
+from pcs.cli.common.tools import print_to_stderr
 from pcs.cli.reports import process_library_reports
-from pcs.common.str_tools import indent
+from pcs.common.str_tools import (
+    format_list,
+    indent,
+)
+from pcs.common.types import StringSequence
 from pcs.lib.node import get_existing_nodes_names
 
 
@@ -274,10 +282,12 @@ def quorum_unblock_cmd(lib, argv, modifiers):
     output, retval = utils.run(
         ["corosync-cmapctl", "-g", "runtime.votequorum.wait_for_all_status"]
     )
+    if (retval == 1 and "Error CS_ERR_NOT_EXIST" in output) or (
+        retval == 0 and output.rsplit("=", maxsplit=1)[-1].strip() != "1"
+    ):
+        utils.err("cluster is not waiting for nodes to establish quorum")
     if retval != 0:
         utils.err("unable to check quorum status")
-    if output.rsplit("=", maxsplit=1)[-1].strip() != "1":
-        utils.err("cluster is not waiting for nodes to establish quorum")
 
     all_nodes, report_list = get_existing_nodes_names(
         utils.get_corosync_conf_facade()
@@ -288,18 +298,13 @@ def quorum_unblock_cmd(lib, argv, modifiers):
     unjoined_nodes = set(all_nodes) - set(utils.getCorosyncActiveNodes())
     if not unjoined_nodes:
         utils.err("no unjoined nodes found")
-    if not modifiers.get("--force"):
-        answer = utils.get_terminal_input(
-            (
-                "WARNING: If node(s) {nodes} are not powered off or they do"
-                + " have access to shared resources, data corruption and/or"
-                + " cluster failure may occur. Are you sure you want to"
-                + " continue? [y/N] "
-            ).format(nodes=", ".join(unjoined_nodes))
-        )
-        if answer.lower() not in ["y", "yes"]:
-            print("Canceled")
-            return
+    if not utils.get_continue_confirmation_or_force(
+        f"If node(s) {format_list(unjoined_nodes)} are not powered off or they "
+        "do have access to shared resources, data corruption and/or cluster "
+        "failure may occur",
+        modifiers.get("--force"),
+    ):
+        return
     for node in unjoined_nodes:
         # pass --force so no warning will be displayed
         stonith.stonith_confirm(
@@ -311,7 +316,7 @@ def quorum_unblock_cmd(lib, argv, modifiers):
     )
     if retval != 0:
         utils.err("unable to cancel waiting for nodes")
-    print("Quorum unblocked")
+    print_to_stderr("Quorum unblocked")
 
     startup_fencing = utils.get_set_properties().get("startup-fencing", "")
     utils.set_cib_property(
@@ -319,4 +324,36 @@ def quorum_unblock_cmd(lib, argv, modifiers):
         "false" if startup_fencing.lower() != "false" else "true",
     )
     utils.set_cib_property("startup-fencing", startup_fencing)
-    print("Waiting for nodes canceled")
+    print_to_stderr("Waiting for nodes canceled")
+
+
+def check_local_qnetd_certs_cmd(
+    lib: Any, argv: StringSequence, modifiers: InputModifiers
+):
+    modifiers.ensure_only_supported()
+    if not argv or len(argv) != 2 or not argv[0] or not argv[1]:
+        raise CmdLineInputError(
+            "Expected arguments: <qnetd_host> <cluster_name>"
+        )
+    qnetd_host = argv[0]
+    cluster_name = argv[1]
+    result = lib.quorum.device_net_certificate_check_local(
+        qnetd_host, cluster_name
+    )
+    if result:
+        print("certificate present")
+    else:
+        print("certificate missing")
+
+
+def setup_local_qnetd_certs_cmd(
+    lib: Any, argv: StringSequence, modifiers: InputModifiers
+):
+    modifiers.ensure_only_supported()
+    if not argv or len(argv) != 2 or not argv[0] or not argv[1]:
+        raise CmdLineInputError(
+            "Expected arguments: <qnetd_host> <cluster_name>"
+        )
+    qnetd_host = argv[0]
+    cluster_name = argv[1]
+    lib.quorum.device_net_certificate_setup_local(qnetd_host, cluster_name)
