@@ -1,16 +1,19 @@
-import sys
 import os
+import sys
 
 from pcs import utils
 from pcs.cli.common.errors import CmdLineInputError
-from pcs.cli.common.reports import process_library_reports
-from pcs.lib import reports
-from pcs.lib.node import get_existing_nodes_names
+from pcs.cli.reports import process_library_reports
+from pcs.cli.reports.output import error
 from pcs.lib.errors import LibraryError
+from pcs.lib.node import get_existing_nodes_names
+from pcs.lib.pacemaker.live import get_cluster_status_dom
 from pcs.lib.pacemaker.state import ClusterState
+from pcs.pcsd import pcsd_status_cmd
 
 # pylint: disable=too-many-branches, too-many-locals, too-many-statements
 
+
 def full_status(lib, argv, modifiers):
     """
     Options:
@@ -21,15 +24,21 @@ def full_status(lib, argv, modifiers):
       * --request-timeout - HTTP timeout for node authorization check
     """
     modifiers.ensure_only_supported(
-        "--hide-inactive", "--full", "-f", "--corosync_conf",
+        "--hide-inactive",
+        "--full",
+        "-f",
+        "--corosync_conf",
         "--request-timeout",
     )
     if argv:
         raise CmdLineInputError()
-    print(lib.status.full_cluster_status_plaintext(
-        hide_inactive_resources=modifiers.get("--hide-inactive"),
-        verbose=modifiers.get("--full"),
-    ))
+    print(
+        lib.status.full_cluster_status_plaintext(
+            hide_inactive_resources=modifiers.get("--hide-inactive"),
+            verbose=modifiers.get("--full"),
+        )
+    )
+
 
 # Parse crm_mon for status
 def nodes_status(lib, argv, modifiers):
@@ -52,11 +61,15 @@ def nodes_status(lib, argv, modifiers):
         else:
             corosync_nodes = []
         try:
-            pacemaker_nodes = sorted([
-                node.attrs.name for node
-                in ClusterState(utils.getClusterStateXml()).node_section.nodes
-                if node.attrs.type != 'remote'
-            ])
+            pacemaker_nodes = sorted(
+                [
+                    node.attrs.name
+                    for node in ClusterState(
+                        get_cluster_status_dom(utils.cmd_runner())
+                    ).node_section.nodes
+                    if node.attrs.type != "remote"
+                ]
+            )
         except LibraryError as e:
             process_library_reports(e.args)
         print("Corosync Nodes:")
@@ -124,12 +137,15 @@ def nodes_status(lib, argv, modifiers):
                         standbynodes_with_resources.append(node_name)
                     else:
                         standbynodes.append(node_name)
-            elif node.getAttribute("maintenance") == "true":
+            if node.getAttribute("maintenance") == "true":
                 if node_remote:
                     remote_maintenancenodes.append(node_name)
                 else:
                     maintenancenodes.append(node_name)
-            else:
+            if (
+                node.getAttribute("standby") == "false"
+                and node.getAttribute("maintenance") == "false"
+            ):
                 if node_remote:
                     remote_onlinenodes.append(node_name)
                 else:
@@ -143,23 +159,27 @@ def nodes_status(lib, argv, modifiers):
     print("Pacemaker Nodes:")
     print(" ".join([" Online:"] + onlinenodes))
     print(" ".join([" Standby:"] + standbynodes))
-    print(" ".join(
-        [" Standby with resource(s) running:"] + standbynodes_with_resources
-    ))
+    print(
+        " ".join(
+            [" Standby with resource(s) running:"] + standbynodes_with_resources
+        )
+    )
     print(" ".join([" Maintenance:"] + maintenancenodes))
     print(" ".join([" Offline:"] + offlinenodes))
 
     print("Pacemaker Remote Nodes:")
     print(" ".join([" Online:"] + remote_onlinenodes))
     print(" ".join([" Standby:"] + remote_standbynodes))
-    print(" ".join(
-        [" Standby with resource(s) running:"]
-        +
-        remote_standbynodes_with_resources
-    ))
+    print(
+        " ".join(
+            [" Standby with resource(s) running:"]
+            + remote_standbynodes_with_resources
+        )
+    )
     print(" ".join([" Maintenance:"] + remote_maintenancenodes))
     print(" ".join([" Offline:"] + remote_offlinenodes))
 
+
 def cluster_status(lib, argv, modifiers):
     """
     Options:
@@ -189,6 +209,7 @@ def cluster_status(lib, argv, modifiers):
         print()
         print_pcsd_daemon_status(lib, modifiers)
 
+
 def corosync_status(lib, argv, modifiers):
     """
     Options: no options
@@ -203,23 +224,17 @@ def corosync_status(lib, argv, modifiers):
     else:
         print(output.rstrip())
 
+
 def xml_status(lib, argv, modifiers):
     """
     Options:
       * -f - CIB file
     """
-    del lib
     modifiers.ensure_only_supported("-f")
     if argv:
         raise CmdLineInputError()
-    (output, retval) = utils.run(
-        ["crm_mon", "-1", "-r", "-X"],
-        ignore_stderr=True
-    )
+    print(lib.status.pacemaker_status_xml().strip())
 
-    if retval != 0:
-        utils.err("running crm_mon, is pacemaker running?")
-    print(output.rstrip())
 
 def print_pcsd_daemon_status(lib, modifiers):
     """
@@ -229,12 +244,12 @@ def print_pcsd_daemon_status(lib, modifiers):
     """
     print("PCSD Status:")
     if os.getuid() == 0:
-        cluster_pcsd_status(
+        pcsd_status_cmd(
             lib, [], modifiers.get_subset("--request-timeout"), dont_exit=True
         )
     else:
         err_msgs, exitcode, std_out, dummy_std_err = utils.call_local_pcsd(
-            ['status', 'pcsd']
+            ["status", "pcsd"], []
         )
         if err_msgs:
             for msg in err_msgs:
@@ -242,57 +257,4 @@ def print_pcsd_daemon_status(lib, modifiers):
         if exitcode == 0:
             print(std_out)
         else:
-            print("Unable to get PCSD status")
-
-def check_nodes(node_list, prefix=""):
-    """
-    Print pcsd status on node_list, return if there is any pcsd not online
-
-    Commandline options:
-      * --request-timeout - HTTP timeout for node authorization check
-    """
-    online_code = 0
-    status_desc_map = {
-        online_code: 'Online',
-        3: 'Unable to authenticate'
-    }
-    status_list = []
-    def report(node, returncode, output):
-        del output
-        print("{0}{1}: {2}".format(
-            prefix,
-            node,
-            status_desc_map.get(returncode, 'Offline')
-        ))
-        status_list.append(returncode)
-
-    utils.read_known_hosts_file() # cache known hosts
-    utils.run_parallel(
-        utils.create_task_list(report, utils.checkAuthorization, node_list)
-    )
-
-    return any([status != online_code for status in status_list])
-
-# If no arguments get current cluster node status, otherwise get listed
-# nodes status
-def cluster_pcsd_status(lib, argv, modifiers, dont_exit=False):
-    """
-    Options:
-      * --request-timeout - HTTP timeout for node authorization check
-    """
-    del lib
-    modifiers.ensure_only_supported("--request-timeout")
-    bad_nodes = False
-    if not argv:
-        nodes, report_list = get_existing_nodes_names(
-            utils.get_corosync_conf_facade()
-        )
-        if not nodes and not dont_exit:
-            report_list.append(reports.corosync_config_no_nodes_defined())
-        if report_list:
-            process_library_reports(report_list)
-        bad_nodes = check_nodes(nodes, "  ")
-    else:
-        bad_nodes = check_nodes(argv, "  ")
-    if bad_nodes and not dont_exit:
-        sys.exit(2)
+            raise error("Unable to get PCSD status")
