@@ -1,4 +1,9 @@
 import json
+from typing import (
+    Any,
+    List,
+    Optional,
+)
 
 from pcs import (
     resource,
@@ -6,20 +11,29 @@ from pcs import (
 )
 from pcs.cli.common import parse_args
 from pcs.cli.common.errors import CmdLineInputError
+from pcs.cli.common.output import smart_wrap_text
 from pcs.cli.fencing_topology import target_type_map_cli_to_lib
-from pcs.cli.reports import process_library_reports
-from pcs.cli.reports.output import error, warn
+from pcs.cli.reports.output import (
+    deprecation_warning,
+    error,
+    print_to_stderr,
+    warn,
+)
+from pcs.cli.resource.output import resource_agent_metadata_to_text
 from pcs.cli.resource.parse_args import parse_create_simple as parse_create_args
 from pcs.common import reports
 from pcs.common.fencing_topology import (
+    TARGET_TYPE_ATTRIBUTE,
     TARGET_TYPE_NODE,
     TARGET_TYPE_REGEXP,
-    TARGET_TYPE_ATTRIBUTE,
 )
-from pcs.common.interface.dto import to_dict
-from pcs.common.str_tools import indent
+from pcs.common.resource_agent.dto import ResourceAgentNameDto
+from pcs.common.str_tools import (
+    format_list,
+    format_optional,
+    indent,
+)
 from pcs.lib.errors import LibraryError
-import pcs.lib.resource_agent as lib_ra
 
 # pylint: disable=too-many-branches, too-many-statements, protected-access
 
@@ -28,23 +42,18 @@ def stonith_show_cmd(lib, argv, modifiers):
     # TODO remove, deprecated command
     # replaced with 'stonith status' and 'stonith config'
     resource.resource_show(lib, argv, modifiers, stonith=True)
-    print_stonith_levels(lib)
 
 
 def stonith_status_cmd(lib, argv, modifiers):
     resource.resource_status(lib, argv[:], modifiers, stonith=True)
     if not argv:
-        print_stonith_levels(lib)
+        _print_stonith_levels(lib)
 
 
-def stonith_config_cmd(lib, argv, modifiers):
-    resource.resource_config(lib, argv, modifiers, stonith=True)
-    print_stonith_levels(lib)
-
-
-def print_stonith_levels(lib):
+def _print_stonith_levels(lib):
     levels = stonith_level_config_to_str(lib.fencing_topology.get_config())
     if levels:
+        print("\nFencing Levels:")
         print("\n".join(indent(levels, 1)))
 
 
@@ -72,7 +81,7 @@ def stonith_list_available(lib, argv, modifiers):
         )
 
     for agent_info in agent_list:
-        name = agent_info["name"]
+        name = agent_info["type"]
         shortdesc = agent_info["shortdesc"]
         if shortdesc:
             print(
@@ -87,7 +96,9 @@ def stonith_list_available(lib, argv, modifiers):
             print(name)
 
 
-def stonith_list_options(lib, argv, modifiers):
+def stonith_list_options(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
     """
     Options:
       * --full - show advanced options
@@ -95,17 +106,36 @@ def stonith_list_options(lib, argv, modifiers):
     modifiers.ensure_only_supported("--full")
     if len(argv) != 1:
         raise CmdLineInputError()
-    agent_name = argv[0]
-
+    agent_name = ResourceAgentNameDto("stonith", None, argv[0])
     print(
-        resource._format_agent_description(
-            lib.stonith_agent.describe_agent(agent_name),
-            stonith=True,
-            show_all=modifiers.get("--full"),
+        "\n".join(
+            smart_wrap_text(
+                resource_agent_metadata_to_text(
+                    lib.resource_agent.get_agent_metadata(agent_name),
+                    lib.resource_agent.get_agent_default_operations(
+                        agent_name
+                    ).operations,
+                    verbose=modifiers.is_specified("--full"),
+                )
+            )
         )
     )
 
 
+def _check_is_stonith(
+    lib: Any,
+    resource_id_list: List[str],
+    cmd_to_use: Optional[str] = None,
+) -> None:
+    if lib.resource.is_any_resource_except_stonith(resource_id_list):
+        deprecation_warning(
+            reports.messages.ResourceStonithCommandsMismatch(
+                "resources"
+            ).message
+            + format_optional(cmd_to_use, " Please use '{}' instead.")
+        )
+
+
 def stonith_create(lib, argv, modifiers):
     """
     Options:
@@ -116,8 +146,9 @@ def stonith_create(lib, argv, modifiers):
       * --group - specifies group in which resource will be created
       * --force - allow not existing agent, invalid operations or invalid
         instance attributes
-      * --disabled - created reource will be disabled
+      * --disabled - created resource will be disabled
       * --no-default-ops - do not add default operations
+      * --agent-validation - use agent self validation of instance attributes
       * --wait
       * -f - CIB file
     """
@@ -128,6 +159,7 @@ def stonith_create(lib, argv, modifiers):
         "--force",
         "--disabled",
         "--no-default-ops",
+        "--agent-validation",
         "--wait",
         "-f",
     )
@@ -161,6 +193,7 @@ def stonith_create(lib, argv, modifiers):
         ensure_disabled=modifiers.get("--disabled"),
         use_default_operations=not modifiers.get("--no-default-ops"),
         wait=modifiers.get("--wait"),
+        enable_agent_self_validation=modifiers.get("--agent-validation"),
     )
 
     if not modifiers.get("--group"):
@@ -173,6 +206,10 @@ def stonith_create(lib, argv, modifiers):
             **settings,
         )
     else:
+        deprecation_warning(
+            "Option to group stonith resource is deprecated and will be "
+            "removed in a future release."
+        )
         adjacent_resource_id = None
         put_after_adjacent = False
         if modifiers.get("--after"):
@@ -251,10 +288,9 @@ def _stonith_level_normalize_devices(argv):
     # normalize devices - previously it was possible to delimit devices by both
     # a comma and a space
     if any("," in arg for arg in argv):
-        warn(
+        deprecation_warning(
             "Delimiting stonith devices with ',' is deprecated and will be "
-            "removed. Please use a space to delimit stonith devices.",
-            stderr=True,
+            "removed. Please use a space to delimit stonith devices."
         )
     return ",".join(argv).split(",")
 
@@ -270,11 +306,13 @@ def stonith_level_add_cmd(lib, argv, modifiers):
     if len(argv) < 3:
         raise CmdLineInputError()
     target_type, target_value = _stonith_level_parse_node(argv[1])
+    stonith_devices = _stonith_level_normalize_devices(argv[2:])
+    _check_is_stonith(lib, stonith_devices)
     lib.fencing_topology.add_level(
         argv[0],
         target_type,
         target_value,
-        _stonith_level_normalize_devices(argv[2:]),
+        stonith_devices,
         force_device=modifiers.get("--force"),
         force_node=modifiers.get("--force"),
     )
@@ -312,17 +350,16 @@ def stonith_level_clear_cmd(lib, argv, modifiers):
 
     # TODO remove, deprecated backward compatibility mode for old syntax
     # Command parameters are: node, stonith-list
-    # Both the node and the stonith list are optional. If the node is ommited
+    # Both the node and the stonith list are optional. If the node is omitted
     # and the stonith list is present, there is no way to figure it out, since
     # there is no specification of what the parameter is. Hence the pre-lib
     # code tried both. It deleted all levels having the first parameter as
     # either a node or a device list. Since it was only possible to specify
     # node as a target back then, this is enabled only in that case.
-    warn(
+    deprecation_warning(
         "Syntax 'pcs stonith level clear [<target> | <stonith id(s)>] is "
         "deprecated and will be removed. Please use 'pcs stonith level clear "
-        "[target <target>] | [stonith <stonith id>...]'.",
-        stderr=True,
+        "[target <target>] | [stonith <stonith id>...]'."
     )
     target_type, target_value = _stonith_level_parse_node(argv[0])
     was_error = False
@@ -357,10 +394,10 @@ def stonith_level_config_to_str(config):
     """
     Commandline option: no options
     """
-    config_data = dict()
+    config_data = {}
     for level in config:
         if level["target_type"] not in config_data:
-            config_data[level["target_type"]] = dict()
+            config_data[level["target_type"]] = {}
         if level["target_value"] not in config_data[level["target_type"]]:
             config_data[level["target_type"]][level["target_value"]] = []
         config_data[level["target_type"]][level["target_value"]].append(level)
@@ -433,19 +470,17 @@ def stonith_level_remove_cmd(lib, argv, modifiers):
     else:
         # TODO remove, deprecated backward compatibility layer for old syntax
         if len(argv) > 1:
-            warn(
+            deprecation_warning(
                 "Syntax 'pcs stonith level delete | remove <level> [<target>] "
                 "[<stonith id>...]' is deprecated and will be removed. Please "
                 "use 'pcs stonith level delete | remove <level> "
-                "[target <target>] [stonith <stonith id>...]'.",
-                stderr=True,
+                "[target <target>] [stonith <stonith id>...]'."
             )
             if not parse_args.ARG_TYPE_DELIMITER in argv[1] and "," in argv[1]:
-                warn(
+                deprecation_warning(
                     "Delimiting stonith devices with ',' is deprecated and "
                     "will be removed. Please use a space to delimit stonith "
-                    "devices.",
-                    stderr=True,
+                    "devices."
                 )
             target_type, target_value = _stonith_level_parse_node(argv[1])
         if len(argv) > 2:
@@ -494,7 +529,7 @@ def stonith_fence(lib, argv, modifiers):
     if retval != 0:
         utils.err("unable to fence '%s'\n" % node + output)
     else:
-        print("Node: %s fenced" % node)
+        print_to_stderr(f"Node: {node} fenced")
 
 
 def stonith_confirm(lib, argv, modifiers):
@@ -508,18 +543,12 @@ def stonith_confirm(lib, argv, modifiers):
         utils.err("must specify one (and only one) node to confirm fenced")
 
     node = argv.pop(0)
-    if not modifiers.get("--force"):
-        answer = utils.get_terminal_input(
-            (
-                "WARNING: If node {node} is not powered off or it does"
-                + " have access to shared resources, data corruption and/or"
-                + " cluster failure may occur. Are you sure you want to"
-                + " continue? [y/N] "
-            ).format(node=node)
-        )
-        if answer.lower() not in ["y", "yes"]:
-            print("Canceled")
-            return
+    if not utils.get_continue_confirmation_or_force(
+        f"If node '{node}' is not powered off or it does have access to shared "
+        "resources, data corruption and/or cluster failure may occur",
+        modifiers.get("--force"),
+    ):
+        return
     args = ["stonith_admin", "-C", node]
     output, retval = utils.run(args)
 
@@ -534,26 +563,18 @@ def get_fence_agent_info(lib, argv, modifiers):
     """
     Options: no options
     """
-    del lib
     modifiers.ensure_only_supported()
     if len(argv) != 1:
         utils.err("One parameter expected")
 
-    agent = argv[0]
-    if not agent.startswith("stonith:"):
+    agent_name = argv[0]
+    if not agent_name.startswith("stonith:"):
         utils.err("Invalid fence agent name")
-
-    runner = utils.cmd_runner()
-
-    try:
-        metadata = lib_ra.StonithAgent(runner, agent[len("stonith:") :])
-        info = to_dict(metadata.get_full_info())
-        info["name"] = "stonith:{0}".format(info["name"])
-        print(json.dumps(info))
-    except lib_ra.ResourceAgentError as e:
-        process_library_reports([lib_ra.resource_agent_error_to_report_item(e)])
-    except LibraryError as e:
-        process_library_reports(e.args)
+    print(
+        json.dumps(
+            lib.stonith_agent.describe_agent(agent_name[len("stonith:") :])
+        )
+    )
 
 
 def sbd_watchdog_list(lib, argv, modifiers):
@@ -571,7 +592,7 @@ def sbd_watchdog_list(lib, argv, modifiers):
         for watchdog in sorted(available_watchdogs.keys()):
             print("  {}".format(watchdog))
     else:
-        print("No available watchdog")
+        print_to_stderr("No available watchdog")
 
 
 def sbd_watchdog_list_json(lib, argv, modifiers):
@@ -588,14 +609,14 @@ def sbd_watchdog_test(lib, argv, modifiers):
     """
     Options: no options
     """
-    modifiers.ensure_only_supported()
+    modifiers.ensure_only_supported("--force")
     if len(argv) > 1:
         raise CmdLineInputError()
-    print(
-        "Warning: This operation is expected to force-reboot this system "
-        "without following any shutdown procedures."
-    )
-    if utils.get_terminal_input("Proceed? [no/yes]: ") != "yes":
+    if not utils.get_continue_confirmation_or_force(
+        "This operation is expected to force-reboot this system without "
+        "following any shutdown procedures",
+        modifiers.get("--force"),
+    ):
         return
     watchdog = None
     if len(argv) == 1:
@@ -824,16 +845,12 @@ def sbd_setup_block_device(lib, argv, modifiers):
     if not device_list:
         raise CmdLineInputError("No device defined")
 
-    if not modifiers.get("--force"):
-        answer = utils.get_terminal_input(
-            (
-                "WARNING: All current content on device(s) '{device}' will be"
-                + " overwritten. Are you sure you want to continue? [y/N] "
-            ).format(device="', '".join(device_list))
-        )
-        if answer.lower() not in ["y", "yes"]:
-            print("Canceled")
-            return
+    if not utils.get_continue_confirmation_or_force(
+        f"All current content on device(s) {format_list(device_list)} will be "
+        "overwritten",
+        modifiers.get("--force"),
+    ):
+        return
 
     lib.sbd.initialize_block_devices(
         device_list,
@@ -874,7 +891,7 @@ def stonith_history_cleanup_cmd(lib, argv, modifiers):
         raise CmdLineInputError()
 
     node = argv[0] if argv else None
-    print(lib.stonith.history_cleanup(node))
+    print_to_stderr(lib.stonith.history_cleanup(node))
 
 
 def stonith_history_update_cmd(lib, argv, modifiers):
@@ -885,7 +902,7 @@ def stonith_history_update_cmd(lib, argv, modifiers):
     if argv:
         raise CmdLineInputError()
 
-    print(lib.stonith.history_update())
+    print_to_stderr(lib.stonith.history_update())
 
 
 def stonith_update_scsi_devices(lib, argv, modifiers):
@@ -935,3 +952,137 @@ def stonith_update_scsi_devices(lib, argv, modifiers):
             parsed_args.get("delete", []) + parsed_args.get("remove", []),
             force_flags=force_flags,
         )
+
+
+def delete_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * -f - CIB file
+      * --force - don't stop a resource before its deletion
+    """
+    modifiers.ensure_only_supported("-f", "--force")
+    if len(argv) != 1:
+        raise CmdLineInputError()
+    resource_id = argv[0]
+    _check_is_stonith(lib, [resource_id], "pcs resource delete")
+    resource.resource_remove(resource_id)
+
+
+def enable_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * --wait
+      * -f - CIB file
+    """
+    modifiers.ensure_only_supported("--wait", "-f")
+    if not argv:
+        raise CmdLineInputError(
+            "You must specify stonith resource(s) to enable"
+        )
+    resources = argv
+    _check_is_stonith(lib, resources, "pcs resource enable")
+    lib.resource.enable(resources, modifiers.get("--wait"))
+
+
+def disable_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * -f - CIB file
+      * --brief - show brief output of --simulate
+      * --safe - only disable if no other resource gets stopped or demoted
+      * --simulate - do not push the CIB, print its effects
+      * --no-strict - allow disable if other resource is affected
+      * --wait
+    """
+    if not argv:
+        raise CmdLineInputError(
+            "You must specify stonith resource(s) to disable"
+        )
+    _check_is_stonith(lib, argv, "pcs resource disable")
+    if modifiers.is_specified_any(("--safe", "--no-strict", "--simulate")):
+        deprecation_warning(
+            "Options '--safe', '--no-strict' and '--simualte' are deprecated "
+            "and will be removed in a future release."
+        )
+    resource.resource_disable_common(lib, argv, modifiers)
+
+
+def update_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * -f - CIB file
+      * --wait
+      * --force - allow invalid options, do not fail if not possible to get
+        agent metadata, allow not suitable command
+    """
+    if not argv:
+        raise CmdLineInputError()
+    _check_is_stonith(lib, [argv[0]], "pcs resource update")
+    resource.resource_update(argv, modifiers)
+
+
+def op_add_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * -f - CIB file
+      * --force - allow unknown options
+    """
+    if not argv:
+        raise CmdLineInputError()
+    _check_is_stonith(lib, [argv[0]], "pcs resource op add")
+    resource.resource_op_add(argv, modifiers)
+
+
+def op_delete_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * -f - CIB file
+    """
+    modifiers.ensure_only_supported("-f")
+    if not argv:
+        raise CmdLineInputError()
+    _check_is_stonith(lib, [argv[0]], "pcs resource op delete")
+    resource.resource_operation_remove(argv[0], argv[1:])
+
+
+def meta_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    """
+    Options:
+      * --force - allow not suitable command
+      * --wait
+      * -f - CIB file
+    """
+    if not argv:
+        raise CmdLineInputError()
+    _check_is_stonith(lib, [argv[0]], "pcs resource meta")
+    resource.resource_meta(argv, modifiers)
+
+
+def config_cmd(
+    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+) -> None:
+    is_text_format = (
+        modifiers.get_output_format() == parse_args.OUTPUT_FORMAT_VALUE_TEXT
+    )
+    if not is_text_format:
+        warn(
+            f"Only '{parse_args.OUTPUT_FORMAT_VALUE_TEXT}' output format is "
+            "supported for stonith levels"
+        )
+    resource.config_common(lib, argv, modifiers, stonith=True)
+    if is_text_format:
+        _print_stonith_levels(lib)
