@@ -1,69 +1,68 @@
 # pylint: disable=too-many-lines
-import os
-import sys
-import subprocess
-import xml.dom.minidom
-from xml.dom.minidom import (
-    parseString,
-    Document as DomDocument,
-)
-import xml.etree.ElementTree as ET
-import re
-import json
-import tempfile
-import signal
-import time
-from io import BytesIO
-import tarfile
-import getpass
 import base64
-import threading
+import getpass
+import json
 import logging
+import os
+import re
+import signal
+import subprocess
+import sys
+import tarfile
+import tempfile
+import threading
+import time
+import xml.dom.minidom
+import xml.etree.ElementTree as ET
 from functools import lru_cache
-from urllib.parse import urlencode
-
+from io import BytesIO
 from typing import (
     Any,
     Dict,
-    Sequence,
     Tuple,
 )
+from urllib.parse import urlencode
+from xml.dom.minidom import Document as DomDocument
+from xml.dom.minidom import parseString
 
-from pcs import settings, usage
-
-from pcs.common import (
-    const,
-    file as pcs_file,
-    file_type_codes,
-    pacemaker as common_pacemaker,
-    pcs_pycurl as pycurl,
+import pcs.cli.booth.env
+import pcs.lib.corosync.config_parser as corosync_conf_parser
+from pcs import (
+    settings,
+    usage,
 )
-from pcs.common.host import PcsKnownHost
-from pcs.common.reports import ReportProcessor
-from pcs.common.reports.item import ReportItemList
-from pcs.common.reports.messages import CibUpgradeFailedToMinimalRequiredVersion
-from pcs.common.services.interfaces import ServiceManagerInterface
-from pcs.common.services.errors import ManageServiceError
-from pcs.common.tools import (
-    timeout_to_seconds,
-    Version,
-)
-
 from pcs.cli.common import middleware
 from pcs.cli.common.env_cli import Env
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.lib_wrapper import Library
 from pcs.cli.common.parse_args import InputModifiers
-from pcs.cli.common.tools import timeout_to_seconds_legacy
-from pcs.cli.reports import (
-    output as reports_output,
-    process_library_reports,
-    ReportProcessorToConsole,
+from pcs.cli.common.tools import (
+    print_to_stderr,
+    timeout_to_seconds_legacy,
 )
-import pcs.cli.booth.env
 from pcs.cli.file import metadata as cli_file_metadata
-
-import pcs.lib.corosync.config_parser as corosync_conf_parser
+from pcs.cli.reports import ReportProcessorToConsole
+from pcs.cli.reports import output as reports_output
+from pcs.cli.reports import process_library_reports
+from pcs.common import const
+from pcs.common import file as pcs_file
+from pcs.common import file_type_codes
+from pcs.common import pacemaker as common_pacemaker
+from pcs.common import pcs_pycurl as pycurl
+from pcs.common.host import PcsKnownHost
+from pcs.common.pacemaker.resource.operations import (
+    OCF_CHECK_LEVEL_INSTANCE_ATTRIBUTE_NAME,
+)
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports.item import ReportItemList
+from pcs.common.reports.messages import CibUpgradeFailedToMinimalRequiredVersion
+from pcs.common.services.errors import ManageServiceError
+from pcs.common.services.interfaces import ServiceManagerInterface
+from pcs.common.tools import (
+    Version,
+    timeout_to_seconds,
+)
+from pcs.common.types import StringSequence
 from pcs.lib.corosync.config_facade import ConfigFacade as corosync_conf_facade
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
@@ -75,15 +74,10 @@ from pcs.lib.file.instance import FileInstance as LibFileInstance
 from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.pacemaker.live import get_cluster_status_dom
 from pcs.lib.pacemaker.state import ClusterState
-from pcs.lib.pacemaker.values import (
-    is_boolean,
-    is_score as is_score_value,
-    validate_id,
-)
-from pcs.lib.services import (
-    get_service_manager as _get_service_manager,
-    service_exception_to_report,
-)
+from pcs.lib.pacemaker.values import is_score as is_score_value
+from pcs.lib.pacemaker.values import validate_id
+from pcs.lib.services import get_service_manager as _get_service_manager
+from pcs.lib.services import service_exception_to_report
 
 # pylint: disable=invalid-name
 # pylint: disable=too-many-branches
@@ -99,10 +93,6 @@ filename = ""
 pcs_options: Dict[Any, Any] = {}
 
 
-class UnknownPropertyException(Exception):
-    pass
-
-
 def getValidateWithVersion(dom) -> Version:
     """
     Commandline options: no options
@@ -156,7 +146,7 @@ def cluster_upgrade():
         == "Upgrade unnecessary: Schema is already the latest available"
     ):
         return
-    print("Cluster CIB has been upgraded to latest version")
+    print_to_stderr("Cluster CIB has been upgraded to latest version")
 
 
 def cluster_upgrade_to_version(required_version: Version) -> Any:
@@ -183,7 +173,9 @@ def checkStatus(node):
     Commandline options:
       * --request-timeout - timeout for HTTP requests
     """
-    return sendHTTPRequest(node, "remote/status", None, False, False)
+    return sendHTTPRequest(
+        node, "remote/status", urlencode({"version": "2"}), False, False
+    )
 
 
 # Check and see if we're authorized (faster than a status check)
@@ -302,6 +294,10 @@ def remove_uid_gid_file(uid, gid):
 
 @lru_cache()
 def read_known_hosts_file():
+    return read_known_hosts_file_not_cached()
+
+
+def read_known_hosts_file_not_cached():
     """
     Commandline options: no options
     """
@@ -369,7 +365,7 @@ def repeat_if_timeout(send_http_request_function, repeat_count=15):
                 return retval, output
             repeats_left = repeats_left - 1
             if "--debug" in pcs_options:
-                print("{0}: {1}, trying again...".format(node, output))
+                print_to_stderr(f"{node}: {output}, trying again...")
 
     return repeater
 
@@ -443,7 +439,7 @@ def stopCluster(node, quiet=False, pacemaker=True, corosync=True, force=True):
     Commandline options:
       * --request-timeout - timeout for HTTP requests
     """
-    data = dict()
+    data = {}
     timeout = None
     if pacemaker and not corosync:
         data["component"] = "pacemaker"
@@ -550,8 +546,7 @@ def sendHTTPRequest(
         port=port,
     )
     if "--debug" in pcs_options:
-        print("Sending HTTP Request to: " + url)
-        print("Data: {0}".format(data))
+        print_to_stderr(f"Sending HTTP Request to: {url}\nData: {data}")
 
     def __debug_callback(data_type, debug_data):
         prefixes = {
@@ -595,16 +590,25 @@ def sendHTTPRequest(
         response_data = output.getvalue().decode("utf-8")
         response_code = handler.getinfo(pycurl.RESPONSE_CODE)
         if printResult or printSuccess:
-            print(host + ": " + response_data.strip())
+            print_to_stderr(host + ": " + response_data.strip())
         if "--debug" in pcs_options:
-            print("Response Code: {0}".format(response_code))
-            print("--Debug Response Start--\n{0}".format(response_data))
-            print("--Debug Response End--")
-            print("Communication debug info for calling: {0}".format(url))
-            print("--Debug Communication Output Start--")
-            print(debug_output.getvalue().decode("utf-8", "ignore"))
-            print("--Debug Communication Output End--")
-            print()
+            print_to_stderr(
+                "Response Code: {response_code}\n"
+                "--Debug Response Start--\n"
+                "{response_data}\n"
+                "--Debug Response End--\n"
+                "Communication debug info for calling: {url}\n"
+                "--Debug Communication Output Start--\n"
+                "{debug_comm_output}\n"
+                "--Debug Communication Output End--".format(
+                    response_code=response_code,
+                    response_data=response_data,
+                    url=url,
+                    debug_comm_output=debug_output.getvalue().decode(
+                        "utf-8", "ignore"
+                    ),
+                )
+            )
 
         if response_code == 401:
             output = (
@@ -632,25 +636,24 @@ def sendHTTPRequest(
             output = (0, response_data)
 
         if printResult and output[0] != 0:
-            print(output[1])
+            print_to_stderr(output[1])
 
         return output
     except pycurl.error as e:
         if is_proxy_set(os.environ):
-            print(
-                "Warning: Proxy is set in environment variables, try "
-                "disabling it"
+            reports_output.warn(
+                "Proxy is set in environment variables, try disabling it"
             )
         # pylint: disable=unbalanced-tuple-unpacking
         dummy_errno, reason = e.args
         if "--debug" in pcs_options:
-            print("Response Reason: {0}".format(reason))
+            print_to_stderr(f"Response Reason: {reason}")
         msg = (
             "Unable to connect to {host}, check if pcsd is running there or try "
             "setting higher timeout with --request-timeout option ({reason})"
         ).format(host=host, reason=reason)
         if printResult:
-            print(msg)
+            print_to_stderr(msg)
         return (2, msg)
 
 
@@ -774,7 +777,7 @@ def getCorosyncActiveNodes():
             if nodeid in id_to_status:
                 node_status[node_name] = id_to_status[nodeid]
         else:
-            print("Error mapping %s" % node_name)
+            print_to_stderr(f"Error mapping {node_name}")
 
     nodes_active = []
     for node, status in node_status.items():
@@ -794,9 +797,12 @@ def need_to_handle_qdevice_service():
     """
     try:
         with open(settings.corosync_conf_file, "rb") as corosync_conf_file:
-            return corosync_conf_facade(
-                corosync_conf_parser.Parser.parse(corosync_conf_file.read())
-            ).has_quorum_device()
+            return (
+                corosync_conf_facade(
+                    corosync_conf_parser.Parser.parse(corosync_conf_file.read())
+                ).get_quorum_device_model()
+                is not None
+            )
     except (EnvironmentError, corosync_conf_parser.CorosyncConfParserException):
         # corosync.conf not present or not valid => no qdevice specified
         return False
@@ -834,7 +840,7 @@ def run(
       * --debug
     """
     if not env_extend:
-        env_extend = dict()
+        env_extend = {}
     env_var = env_extend
     env_var.update(dict(os.environ))
     env_var["LC_ALL"] = "C"
@@ -854,10 +860,13 @@ def run(
 
     try:
         if "--debug" in pcs_options:
-            print("Running: " + " ".join(args))
+            print_to_stderr("Running: " + " ".join(args))
             if string_for_stdin:
-                print("--Debug Input Start--\n" + string_for_stdin)
-                print("--Debug Input End--")
+                print_to_stderr(
+                    f"--Debug Input Start--\n"
+                    f"{string_for_stdin}\n"
+                    f"--Debug Input End--"
+                )
 
         # Some commands react differently if you give them anything via stdin
         if string_for_stdin is not None:
@@ -878,17 +887,22 @@ def run(
             universal_newlines=(not binary_output),
         )
         output, dummy_stderror = p.communicate(string_for_stdin)
-        returnVal = p.returncode
+        retval = p.returncode
         if "--debug" in pcs_options:
-            print("Return Value: {0}".format(returnVal))
-            print(("--Debug Output Start--\n{0}".format(output)).rstrip())
-            print("--Debug Output End--")
-            print()
+            print_to_stderr(
+                "Return Value: {retval}\n"
+                "--Debug Output Start--\n"
+                "{debug_output}\n"
+                "--Debug Output End--".format(
+                    retval=retval,
+                    debug_output=output.rstrip(),
+                )
+            )
     except OSError as e:
-        print(e.strerror)
+        print_to_stderr(e.strerror)
         err("unable to locate command: " + args[0])
 
-    return output, returnVal
+    return output, retval
 
 
 @lru_cache()
@@ -897,7 +911,7 @@ def cmd_runner():
     Commandline options:
       * -f - CIB file
     """
-    env_vars = dict()
+    env_vars = {}
     if usefile:
         env_vars["CIB_file"] = filename
     env_vars.update(os.environ)
@@ -917,8 +931,8 @@ def run_pcsdcli(command, data=None):
         * send_local_configs
     """
     if not data:
-        data = dict()
-    env_var = dict()
+        data = {}
+    env_var = {}
     if "--debug" in pcs_options:
         env_var["PCSD_DEBUG"] = "true"
     if "--request-timeout" in pcs_options:
@@ -943,12 +957,12 @@ def run_pcsdcli(command, data=None):
         output = "".join(output_json["log"])
         # check if some requests timed out, if so print message about it
         if "error: operation_timedout" in output:
-            print("Error: Operation timed out")
+            print_to_stderr("Error: Operation timed out")
         # check if there are any connection failures due to proxy in pcsd and
         # print warning if so
         proxy_msg = "Proxy is set in environment variables, try disabling it"
         if proxy_msg in output:
-            print("Warning: {0}".format(proxy_msg))
+            reports_output.warn(proxy_msg)
 
     except ValueError:
         output_json = {
@@ -959,17 +973,6 @@ def run_pcsdcli(command, data=None):
     return output_json, retval
 
 
-def set_token_to_accept(token):
-    output, retval = run_pcsdcli("set_token_to_accept", dict(token=token))
-    if retval == 0:
-        if output["status"] == "access_denied":
-            err("Access denied")
-        if output["status"] != "ok":
-            err("Unable to communicate with pcsd")
-    else:
-        err("Unable to communicate with pcsd")
-
-
 def auth_hosts_token(host_dict):
     output, retval = run_pcsdcli("auth_with_token", dict(nodes=host_dict))
     if retval == 0:
@@ -1000,7 +1003,7 @@ def auth_hosts(host_dict):
                 )
             for node, result in output["data"]["auth_responses"].items():
                 if result["status"] == "ok":
-                    print("{0}: Authorized".format(node))
+                    print_to_stderr(f"{node}: Authorized")
                 elif result["status"] == "bad_password":
                     err(f"{node}: Username and/or password is incorrect", False)
                     failed = True
@@ -1029,7 +1032,7 @@ def auth_hosts(host_dict):
     err("Unable to communicate with pcsd")
 
 
-def call_local_pcsd(argv, std_in=None):
+def call_local_pcsd(argv, options, std_in=None):
     """
     Commandline options:
       * --request-timeout - timeout of call to local pcsd
@@ -1039,6 +1042,7 @@ def call_local_pcsd(argv, std_in=None):
     # returns [list_of_errors, exit_code, stdout, stderr]
     data = {
         "command": json.dumps(argv),
+        "options": json.dumps(options),
     }
     if std_in:
         data["stdin"] = std_in
@@ -1100,18 +1104,18 @@ def run_parallel(worker_list, wait_seconds=1):
     """
     Commandline options: no options
     """
-    thread_list = []
+    thread_list = set()
     for worker in worker_list:
         thread = threading.Thread(target=worker)
         thread.daemon = True
         thread.start()
-        thread_list.append(thread)
+        thread_list.add(thread)
 
     while thread_list:
-        for thread in thread_list:
-            thread.join(wait_seconds)
-            if not thread.is_alive():
-                thread_list.remove(thread)
+        thread = thread_list.pop()
+        thread.join(wait_seconds)
+        if thread.is_alive():
+            thread_list.add(thread)
 
 
 def create_task(report, action, node, *args, **kwargs):
@@ -1140,11 +1144,11 @@ def parallel_for_nodes(action, node_list, *args, **kwargs):
     Commandline options: no options
     NOTE: callback 'action' may use some cmd options
     """
-    node_errors = dict()
+    node_errors = {}
 
     def report(node, returncode, output):
         message = "{0}: {1}".format(node, output.strip())
-        print(message)
+        print_to_stderr(message)
         if returncode != 0:
             node_errors[node] = message
 
@@ -1169,16 +1173,27 @@ def get_group_children(group_id):
     """
     Commandline options: no options
     """
-    child_resources = []
-    dom = get_cib_dom()
+    return dom_get_group_children(get_cib_dom(), group_id)
+
+
+def dom_get_group_children(dom, group_id):
     groups = dom.getElementsByTagName("group")
     for g in groups:
         if g.getAttribute("id") == group_id:
-            for child in g.childNodes:
-                if child.nodeType != xml.dom.minidom.Node.ELEMENT_NODE:
-                    continue
-                if child.tagName == "primitive":
-                    child_resources.append(child.getAttribute("id"))
+            return [
+                child_el.getAttribute("id")
+                for child_el in get_group_children_el_from_el(g)
+            ]
+    return []
+
+
+def get_group_children_el_from_el(group_el):
+    child_resources = []
+    for child in group_el.childNodes:
+        if child.nodeType != xml.dom.minidom.Node.ELEMENT_NODE:
+            continue
+        if child.tagName == "primitive":
+            child_resources.append(child)
     return child_resources
 
 
@@ -1411,6 +1426,21 @@ def validate_constraint_resource(dom, resource_id):
     return True, "", resource_id
 
 
+def validate_resources_not_in_same_group(dom, resource_id1, resource_id2):
+    resource_el1 = dom_get_resource(dom, resource_id1)
+    resource_el2 = dom_get_resource(dom, resource_id2)
+    if not resource_el1 or not resource_el2:
+        # Only primitive resources can be in a group. If at least one of the
+        # resources is not a primitive (resource_el is None), then the
+        # resources are not in the same group.
+        return True
+    group1 = dom_get_parent_by_tag_names(resource_el1, ["group"])
+    group2 = dom_get_parent_by_tag_names(resource_el2, ["group"])
+    if not group1 or not group2:
+        return True
+    return group1 != group2
+
+
 def dom_get_resource_remote_node_name(dom_resource):
     """
     Commandline options: no options
@@ -1488,7 +1518,13 @@ def dom_attrs_to_list(dom_el, with_id=False):
     Commandline options: no options
     """
     attributes = [
-        "%s=%s" % (name, value)
+        "%s=%s"
+        % (
+            name,
+            value
+            if name != "role"
+            else common_pacemaker.role.get_value_primary(value.capitalize()),
+        )
         for name, value in sorted(dom_el.attributes.items())
         if name != "id"
     ]
@@ -1789,16 +1825,19 @@ def operation_exists_by_name(operations_el, op_el):
     """
     Commandline options: no options
     """
+
+    def get_role(_el, new_roles_supported):
+        return common_pacemaker.role.get_value_for_cib(
+            _el.getAttribute("role") or const.PCMK_ROLE_STARTED,
+            new_roles_supported,
+        )
+
     new_roles_supported = isCibVersionSatisfied(
         operations_el, const.PCMK_NEW_ROLES_CIB_VERSION
     )
     existing = []
     op_name = op_el.getAttribute("name")
-    get_role_fn = lambda _el: common_pacemaker.role.get_value_for_cib(
-        _el.getAttribute("role") or const.PCMK_ROLE_STARTED,
-        new_roles_supported,
-    )
-    op_role = get_role_fn(op_el)
+    op_role = get_role(op_el, new_roles_supported)
     ocf_check_level = None
     if op_name == "monitor":
         ocf_check_level = get_operation_ocf_check_level(op_el)
@@ -1807,8 +1846,8 @@ def operation_exists_by_name(operations_el, op_el):
         if op.getAttribute("name") == op_name:
             if op_name != "monitor":
                 existing.append(op)
-            elif get_role_fn(
-                op
+            elif get_role(
+                op, new_roles_supported
             ) == op_role and ocf_check_level == get_operation_ocf_check_level(
                 op
             ):
@@ -1822,7 +1861,10 @@ def get_operation_ocf_check_level(operation_el):
     """
     for attr_el in operation_el.getElementsByTagName("instance_attributes"):
         for nvpair_el in attr_el.getElementsByTagName("nvpair"):
-            if nvpair_el.getAttribute("name") == "OCF_CHECK_LEVEL":
+            if (
+                nvpair_el.getAttribute("name")
+                == OCF_CHECK_LEVEL_INSTANCE_ATTRIBUTE_NAME
+            ):
                 return nvpair_el.getAttribute("value")
     return None
 
@@ -1836,7 +1878,7 @@ def get_node_attributes(filter_node=None, filter_attr=None):
     if node_config == "":
         err("unable to get crm_config, is pacemaker running?")
     dom = parseString(node_config).documentElement
-    nas = dict()
+    nas = {}
     for node in dom.getElementsByTagName("node"):
         nodename = node.getAttribute("uname")
         if filter_node is not None and nodename != filter_node:
@@ -1847,7 +1889,7 @@ def get_node_attributes(filter_node=None, filter_attr=None):
                 if filter_attr is not None and attr_name != filter_attr:
                     continue
                 if nodename not in nas:
-                    nas[nodename] = dict()
+                    nas[nodename] = {}
                 nas[nodename][attr_name] = nvp.getAttribute("value")
             # Use just first element of attributes. We don't support
             # attributes with rules just yet.
@@ -1965,8 +2007,8 @@ def getTerminalSize(fd=1):
     try:
         # pylint: disable=import-outside-toplevel
         import fcntl
-        import termios
         import struct
+        import termios
 
         hw = struct.unpack(
             str("hh"), fcntl.ioctl(fd, termios.TIOCGWINSZ, "1234")
@@ -1995,6 +2037,52 @@ def get_terminal_input(message=None):
         sys.exit(1)
 
 
+def _get_continue_confirmation(warning_text: str) -> bool:
+    """
+    Warns user and asks for permission to continue. Returns True if user wishes
+    to continue, False otherwise.
+
+    This function is mostly intended for prompting user to confirm destructive
+    operations - that's why WARNING is in all caps here and user is asked to
+    explicitly type 'yes' or 'y' to continue.
+
+    warning_text -- describes action that we want the user to confirm
+    """
+    print(f"WARNING: {warning_text}")
+    print("Type 'yes' or 'y' to proceed, anything else to cancel: ", end="")
+    response = get_terminal_input()
+    if response in ["yes", "y"]:
+        return True
+    print("Canceled")
+    return False
+
+
+def is_run_interactive() -> bool:
+    """
+    Return True if pcs is running in an interactive environment, False otherwise
+    """
+    return sys.stdin.isatty() and sys.stdout.isatty()
+
+
+def get_continue_confirmation_or_force(warning_text: str, force: bool) -> bool:
+    """
+    Either asks user to confirm continuation interactively or use --force to
+    override when running from a script. Returns True if user wants to continue.
+    Returns False if user cancels the action. If a non-interactive environment
+    is detected, pcs exits with an error formed from warning_text.
+
+    warning_text -- describes action that we want the user to confirm
+    force -- was force flag provided?
+    """
+    if force:
+        reports_output.warn(warning_text)
+        return True
+    if not is_run_interactive():
+        err(f"{warning_text}, use --force to override")
+        return False
+    return _get_continue_confirmation(warning_text)
+
+
 def get_terminal_password(message="Password: "):
     """
     Commandline options: no options
@@ -2017,12 +2105,8 @@ def getClusterState():
     Commandline options:
       * -f - CIB file
     """
-    output, returncode = run(["crm_mon", "--help-all"])
-    format_option = (
-        "--output-as=xml" if "--output-as=" in output else "--as-xml"
-    )
     xml_string, returncode = run(
-        ["crm_mon", "--one-shot", format_option, "--inactive"],
+        ["crm_mon", "--one-shot", "--output-as=xml", "--inactive"],
         ignore_stderr=True,
     )
     if returncode != 0:
@@ -2067,16 +2151,17 @@ def write_empty_cib(cibfile):
     """
     Commandline options: no options
     """
-    empty_xml = """<?xml version="1.0" encoding="UTF-8"?>
-<cib admin_epoch="0" epoch="1" num_updates="1" validate-with="pacemaker-1.2">
-  <configuration>
-    <crm_config/>
-    <nodes/>
-    <resources/>
-    <constraints/>
-  </configuration>
-  <status/>
-</cib>"""
+    empty_xml = """
+        <cib admin_epoch="0" epoch="1" num_updates="1" validate-with="pacemaker-3.1">
+          <configuration>
+            <crm_config/>
+            <nodes/>
+            <resources/>
+            <constraints/>
+          </configuration>
+          <status/>
+        </cib>
+    """
     with open(cibfile, "w") as f:
         f.write(empty_xml)
 
@@ -2122,9 +2207,9 @@ def is_iso8601_date(var):
 
 
 def err(errorText, exit_after_error=True):
-    sys.stderr.write("Error: %s\n" % errorText)
+    retval = reports_output.error(errorText)
     if exit_after_error:
-        sys.exit(1)
+        raise retval
 
 
 @lru_cache(typed=True)
@@ -2572,156 +2657,6 @@ def get_utilization_str(element, filter_name=None):
     return " ".join(output)
 
 
-def is_valid_cluster_property(prop_def_dict, property_name, value):
-    """
-    Commandline options: no options
-    """
-    if property_name not in prop_def_dict:
-        raise UnknownPropertyException(
-            "unknown cluster property: '{0}'".format(property_name)
-        )
-    return is_valid_cib_value(
-        prop_def_dict[property_name]["type"],
-        value,
-        prop_def_dict[property_name].get("enum", []),
-    )
-
-
-def is_valid_cib_value(value_type, value, enum_options=()):
-    """
-    Commandline options: no options
-    """
-    value_type = value_type.lower()
-    if value_type == "enum":
-        return value in enum_options
-    if value_type == "boolean":
-        return is_boolean(value)
-    if value_type == "integer":
-        return is_score(value)
-    if value_type == "time":
-        return timeout_to_seconds(value) is not None
-    return True
-
-
-def get_cluster_properties_definition():
-    """
-    Commandline options: no options
-    """
-    # we don't want to change these properties
-    banned_props = ["dc-version", "cluster-infrastructure"]
-    basic_props = [
-        "batch-limit",
-        "no-quorum-policy",
-        "symmetric-cluster",
-        "enable-acl",
-        "stonith-enabled",
-        "stonith-action",
-        "pe-input-series-max",
-        "stop-orphan-resources",
-        "stop-orphan-actions",
-        "cluster-delay",
-        "start-failure-is-fatal",
-        "pe-error-series-max",
-        "pe-warn-series-max",
-    ]
-    readable_names = {
-        "batch-limit": "Batch Limit",
-        "no-quorum-policy": "No Quorum Policy",
-        "symmetric-cluster": "Symmetric",
-        "stonith-enabled": "Stonith Enabled",
-        "stonith-action": "Stonith Action",
-        "cluster-delay": "Cluster Delay",
-        "stop-orphan-resources": "Stop Orphan Resources",
-        "stop-orphan-actions": "Stop Orphan Actions",
-        "start-failure-is-fatal": "Start Failure is Fatal",
-        "pe-error-series-max": "PE Error Storage",
-        "pe-warn-series-max": "PE Warning Storage",
-        "pe-input-series-max": "PE Input Storage",
-        "enable-acl": "Enable ACLs",
-    }
-    sources = [
-        {
-            "name": "pacemaker-schedulerd",
-            "path": settings.pacemaker_schedulerd,
-        },
-        {
-            "name": "pacemaker-controld",
-            "path": settings.pacemaker_controld,
-        },
-        {
-            "name": "pacemaker-based",
-            "path": settings.pacemaker_based,
-        },
-    ]
-    definition = {}
-    for source in sources:
-        stdout, stderr, retval = cmd_runner().run([source["path"], "metadata"])
-        if retval != 0:
-            err("unable to run {0}\n{1}".format(source["name"], stderr))
-        try:
-            etree = ET.fromstring(stdout)
-            for e in etree.findall("./parameters/parameter"):
-                prop = get_cluster_property_from_xml(e)
-                if prop["name"] not in banned_props:
-                    prop["source"] = source["name"]
-                    prop["advanced"] = prop["name"] not in basic_props
-                    if prop["name"] in readable_names:
-                        prop["readable_name"] = readable_names[prop["name"]]
-                    else:
-                        prop["readable_name"] = prop["name"]
-                    definition[prop["name"]] = prop
-        except xml.parsers.expat.ExpatError as e:
-            err(
-                "unable to parse {0} metadata definition: {1}".format(
-                    source["name"], e
-                )
-            )
-        except ET.ParseError as e:
-            err(
-                "unable to parse {0} metadata definition: {1}".format(
-                    source["name"], e
-                )
-            )
-    return definition
-
-
-def get_cluster_property_from_xml(etree_el):
-    """
-    Commandline options: no options
-    """
-    prop = {
-        "name": etree_el.get("name", ""),
-        "shortdesc": "",
-        "longdesc": "",
-    }
-    for item in ["shortdesc", "longdesc"]:
-        item_el = etree_el.find(item)
-        if item_el is not None and item_el.text is not None:
-            prop[item] = item_el.text
-
-    content = etree_el.find("content")
-    if content is None:
-        prop["type"] = ""
-        prop["default"] = ""
-    else:
-        prop["type"] = content.get("type", "")
-        prop["default"] = content.get("default", "")
-
-    if prop["type"] == "enum":
-        prop["enum"] = []
-        if prop["longdesc"]:
-            values = prop["longdesc"].split("  Allowed values: ")
-            if len(values) == 2:
-                prop["enum"] = values[1].split(", ")
-                prop["longdesc"] = values[0]
-        if prop["default"] not in prop["enum"]:
-            prop["enum"].append(prop["default"])
-
-    if prop["longdesc"] == prop["shortdesc"]:
-        prop["longdesc"] = ""
-    return prop
-
-
 def get_lib_env() -> LibraryEnvironment:
     """
     Commandline options:
@@ -2832,17 +2767,15 @@ def get_library_wrapper():
     return Library(get_cli_env(), get_middleware_factory())
 
 
-def exit_on_cmdline_input_errror(
-    error: CmdLineInputError,
-    main_name: str,
-    usage_name: Sequence[str],
+def exit_on_cmdline_input_error(
+    error: CmdLineInputError, main_name: str, usage_name: StringSequence
 ) -> None:
+    if error and error.message:
+        reports_output.error(error.message)
+    if error and error.hint:
+        print_to_stderr(f"Hint: {error.hint}")
     if not error or (not error.message or error.show_both_usage_and_message):
         usage.show(main_name, usage_name)
-    if error and error.message:
-        err(error.message, exit_after_error=False)
-    if error and error.hint:
-        sys.stderr.write("Hint: {0}\n".format(error.hint))
     sys.exit(1)
 
 
@@ -2885,7 +2818,13 @@ def get_user_and_pass():
     return username, password
 
 
-def get_input_modifiers():
+def get_input_modifiers() -> InputModifiers:
+    if "--master" in pcs_options:
+        reports_output.deprecation_warning(
+            "Option '--master' is deprecated and has been replaced by option "
+            "'--promoted' "
+        )
+        pcs_options["--promoted"] = pcs_options.pop("--master")
     return InputModifiers(pcs_options)
 
 
@@ -2902,3 +2841,17 @@ def get_token_from_file(file_name: str) -> str:
     except OSError as e:
         err(f"Unable to read file '{file_name}': {e}", exit_after_error=False)
         raise SystemExit(1) from e
+
+
+def print_depracation_warning_for_legacy_roles(role: str) -> None:
+    deprecation_map: Dict[str, str] = {
+        const.PCMK_ROLE_PROMOTED_LEGACY: const.PCMK_ROLE_PROMOTED,
+        const.PCMK_ROLE_UNPROMOTED_LEGACY: const.PCMK_ROLE_UNPROMOTED,
+    }
+    role_normalized = role.capitalize()
+    if role_normalized in deprecation_map:
+        replaced_by = deprecation_map[role_normalized]
+        reports_output.deprecation_warning(
+            f"Role value '{role}' is deprecated and should not be used, use "
+            f"'{replaced_by}' instead"
+        )
