@@ -1,22 +1,23 @@
 from unittest import TestCase
 
+from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.parse_args import (
+    InputModifiers,
+    _is_negative_num,
+    _is_num,
+    ensure_unique_args,
+    filter_out_non_option_negative_numbers,
+    filter_out_options,
     group_by_keywords,
+    is_long_option_expecting_value,
+    is_option_expecting_value,
+    is_short_option_expecting_value,
     parse_typed_arg,
     prepare_options,
     prepare_options_allowed,
     split_list,
     split_option,
-    filter_out_non_option_negative_numbers,
-    filter_out_options,
-    _is_num,
-    _is_negative_num,
-    is_short_option_expecting_value,
-    is_long_option_expecting_value,
-    is_option_expecting_value,
-    InputModifiers,
 )
-from pcs.cli.common.errors import CmdLineInputError
 
 
 class PrepareOptionsTest(TestCase):
@@ -32,7 +33,7 @@ class PrepareOptionsTest(TestCase):
     def test_refuse_option_without_key(self):
         self.assertRaises(CmdLineInputError, lambda: prepare_options(["=a"]))
 
-    def test_refuse_options_with_same_key_and_differend_value(self):
+    def test_refuse_options_with_same_key_and_different_value(self):
         self.assertRaises(
             CmdLineInputError, lambda: prepare_options(["a=a", "a=b"])
         )
@@ -81,7 +82,7 @@ class PrepareOptionsAllowedTest(TestCase):
             CmdLineInputError, lambda: prepare_options_allowed(["=a"], ["a"])
         )
 
-    def test_refuse_options_with_same_key_and_differend_value(self):
+    def test_refuse_options_with_same_key_and_different_value(self):
         self.assertRaises(
             CmdLineInputError,
             lambda: prepare_options_allowed(["a=a", "a=b"], ["a"]),
@@ -160,7 +161,7 @@ class SplitByKeywords(TestCase):
             },
         )
 
-    def test_splict_without_implict_keyword(self):
+    def test_split_without_implicit_keyword(self):
         self.assertEqual(
             group_by_keywords(
                 ["first", 1, 2, "second", 3],
@@ -270,7 +271,7 @@ class SplitByKeywords(TestCase):
             ),
         )
 
-    def test_group_repeating_keyword_occurences(self):
+    def test_group_repeating_keyword_occurrences(self):
         self.assertEqual(
             group_by_keywords(
                 ["first", 1, 2, "second", 3, "first", 4],
@@ -294,7 +295,7 @@ class SplitByKeywords(TestCase):
             ),
         )
 
-    def test_implicit_first_kw_not_applyed_in_the_middle(self):
+    def test_implicit_first_kw_not_applied_in_the_middle(self):
         self.assertEqual(
             group_by_keywords(
                 [1, 2, "first", 3, "zero", 4],
@@ -307,7 +308,7 @@ class SplitByKeywords(TestCase):
             },
         )
 
-    def test_implicit_first_kw_applyed_in_the_middle_when_is_in_kwds(self):
+    def test_implicit_first_kw_applied_in_the_middle_when_is_in_kwds(self):
         self.assertEqual(
             group_by_keywords(
                 [1, 2, "first", 3, "zero", 4],
@@ -603,10 +604,7 @@ class InputModifiersTest(TestCase):
             # used only in deprecated 'pcs resource|stonith show'
             "--groups",
             "--hide-inactive",
-            # TODO remove, deprecated command 'pcs config import-cman'
-            "--interactive",
             "--local",
-            "--master",
             "--monitor",
             "--no-default-ops",
             "--no-expire-check",
@@ -615,6 +613,7 @@ class InputModifiersTest(TestCase):
             "--nodesc",
             "--off",
             "--pacemaker",
+            "--promoted",
             "--safe",
             "--simulate",
             "--skip-offline",
@@ -799,3 +798,44 @@ class InputModifiersTest(TestCase):
                 {"a": 1, "b": 2, "c": 3, "d": 4}
             ).ensure_not_incompatible("a", ["d", "b"])
         self.assertEqual(str(cm.exception), "'a' cannot be used with 'b', 'd'")
+
+    def test_dependencies_main_defined(self):
+        InputModifiers({"a": 1, "b": 2, "c": 3}).ensure_dependency_satisfied(
+            "a", ["x", "y"]
+        )
+
+    def test_dependencies_main_defined_with_deps(self):
+        InputModifiers(
+            {"a": 1, "b": 2, "c": 3, "d": 4}
+        ).ensure_dependency_satisfied("a", ["b", "c"])
+
+    def test_dependencies_missing_one(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            InputModifiers(
+                {"a": 1, "b": 2, "c": 3}
+            ).ensure_dependency_satisfied("x", ["c"])
+        self.assertEqual(str(cm.exception), "'c' cannot be used without 'x'")
+
+    def test_dependencies_missing_multiple(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            InputModifiers(
+                {"a": 1, "b": 2, "c": 3}
+            ).ensure_dependency_satisfied("x", ["c", "b", "d"])
+        self.assertEqual(
+            str(cm.exception), "'b', 'c' cannot be used without 'x'"
+        )
+
+
+class EnsureUniqueArgsTest(TestCase):
+    def test_no_duplicate_args(self):
+        self.assertEqual(None, ensure_unique_args(["a", "b", "c"]))
+
+    def test_one_duplicate(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            ensure_unique_args(["a", "b", "c", "a"])
+        self.assertEqual("duplicate argument: 'a'", cm.exception.message)
+
+    def test_more_duplicates(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            ensure_unique_args(["a", "b", "c", "b", "a", "b"])
+        self.assertEqual("duplicate arguments: 'a', 'b'", cm.exception.message)
