@@ -1,12 +1,9 @@
 # pylint: disable=too-many-lines
 import json
-
 from textwrap import dedent
-from unittest import mock, TestCase
-
-from pcs_test.tools.misc import (
-    dict_to_modifiers,
-    get_tmp_file,
+from unittest import (
+    TestCase,
+    mock,
 )
 
 from pcs import cluster
@@ -21,6 +18,11 @@ from pcs.common.interface import dto
 from pcs.common.reports import codes as report_codes
 from pcs.common.types import CorosyncTransportType
 
+from pcs_test.tools.misc import (
+    dict_to_modifiers,
+    get_tmp_file,
+)
+
 
 def _node(name, **kwargs):
     """node dictionary fixture"""
@@ -49,6 +51,7 @@ class ClusterSetup(TestCase):
             totem_options={},
             quorum_options={},
             force_flags=[],
+            no_cluster_uuid=False,
         )
 
     def assert_setup_called_with(self, node_list, **kwargs):
@@ -412,6 +415,11 @@ class ClusterSetup(TestCase):
         self.call_cmd([node_name], {"start": True, "wait": "10"})
         self.assert_setup_called_with([_node(node_name)], start=True, wait="10")
 
+    def test_no_cluster_uuid(self):
+        node_name = "node"
+        self.call_cmd([node_name], {"no-cluster-uuid": True})
+        self.assert_setup_called_with([_node(node_name)], no_cluster_uuid=True)
+
     def test_force(self):
         node_name = "node"
         self.call_cmd([node_name], {"force": True})
@@ -430,6 +438,7 @@ class ClusterSetup(TestCase):
                 "start": True,
                 "wait": "15",
                 "no-keys-sync": True,
+                "no-cluster-uuid": True,
             },
         )
         self.assert_setup_called_with(
@@ -438,6 +447,7 @@ class ClusterSetup(TestCase):
             start=True,
             wait="15",
             no_keys_sync=True,
+            no_cluster_uuid=True,
             force_flags=[report_codes.FORCE],
         )
 
@@ -1393,6 +1403,7 @@ class ConfigShow(TestCase):
 
         return CorosyncConfDto(
             cluster_name="HACluster",
+            cluster_uuid="uuid",
             transport=CorosyncTransportType.KNET,
             totem_options={"census": "3600", "join": "50", "token": "3000"},
             transport_options={"ip_version": "ipv4-6", "link_mode": "passive"},
@@ -1469,6 +1480,7 @@ class ConfigShow(TestCase):
         self.output_text = dedent(
             """\
             Cluster Name: HACluster
+            Cluster UUID: uuid
             Transport: knet
             Nodes:
               node1:
@@ -1524,7 +1536,7 @@ class ConfigShow(TestCase):
     def call_cmd(self, argv, modifiers=None):
         cluster.config_show(self.lib, argv, dict_to_modifiers(modifiers or {}))
 
-    def test_args_not_allowd(self, mock_print):
+    def test_args_not_allowed(self, mock_print):
         with self.assertRaises(CmdLineInputError) as cm:
             self.call_cmd(["arg"])
         self.assertIsNone(cm.exception.message)
