@@ -1,19 +1,26 @@
 from random import shuffle
 from textwrap import dedent
-from unittest import mock, TestCase
-
-from pcs_test.tools.assertions import (
-    ac,
-    AssertPcsMixin,
+from unittest import (
+    TestCase,
+    mock,
 )
-from pcs_test.tools.misc import dict_to_modifiers
 
 from pcs import resource
 from pcs.cli.common.errors import CmdLineInputError
+from pcs.cli.reports.processor import ReportItemSeverity
+
+from pcs_test.tools.assertions import (
+    AssertPcsMixin,
+    ac,
+)
+from pcs_test.tools.misc import dict_to_modifiers
 
 
 class FailcountShow(TestCase):
     def setUp(self):
+        print_patcher = mock.patch("pcs.resource.print")
+        self.print_mock = print_patcher.start()
+        self.addCleanup(print_patcher.stop)
         self.lib = mock.Mock(spec_set=["resource"])
         self.resource = mock.Mock(spec_set=["get_failcounts"])
         self.get_failcounts = mock.Mock()
@@ -31,10 +38,22 @@ class FailcountShow(TestCase):
         full=False,
     ):
         self.get_failcounts.return_value = lib_failures
+        argv = []
+        if resource_id:
+            argv.append(resource_id)
+        if node:
+            argv.append(f"node={node}")
+        if operation:
+            argv.append(f"operation={operation}")
+        if interval:
+            argv.append(f"interval={interval}")
+
+        resource.resource_failcount_show(
+            self.lib, argv, dict_to_modifiers(dict(full=full))
+        )
+        self.print_mock.assert_called_once()
         ac(
-            resource.resource_failcount_show(
-                self.lib, resource_id, node, operation, interval, full
-            ),
+            self.print_mock.call_args[0][0],
             expected_output,
         )
 
@@ -282,21 +301,20 @@ class FailcountShow(TestCase):
 class GroupAdd(TestCase, AssertPcsMixin):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["group_add"])
+        self.resource = mock.Mock(spec_set=["group_add", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_group_add_cmd(
-                self.lib, [], dict_to_modifiers(dict())
-            )
+            resource.resource_group_add_cmd(self.lib, [], dict_to_modifiers({}))
         self.assertIsNone(cm.exception.message)
         self.resource.group_add.assert_not_called()
 
     def test_no_resources(self):
         with self.assertRaises(CmdLineInputError) as cm:
             resource.resource_group_add_cmd(
-                self.lib, ["G"], dict_to_modifiers(dict())
+                self.lib, ["G"], dict_to_modifiers({})
             )
         self.assertIsNone(cm.exception.message)
         self.resource.group_add.assert_not_called()
@@ -315,7 +333,7 @@ class GroupAdd(TestCase, AssertPcsMixin):
 
     def test_success(self):
         resource.resource_group_add_cmd(
-            self.lib, ["G", "R1", "R2"], dict_to_modifiers(dict())
+            self.lib, ["G", "R1", "R2"], dict_to_modifiers({})
         )
         self.resource.group_add.assert_called_once_with(
             "G",
@@ -365,7 +383,7 @@ class GroupAdd(TestCase, AssertPcsMixin):
 class ResourceMoveBanMixin:
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            self.cli_command(self.lib, [], dict_to_modifiers(dict()))
+            self.cli_command(self.lib, [], dict_to_modifiers({}))
         self.assertEqual(cm.exception.message, self.no_args_error)
         self.lib_command.assert_not_called()
 
@@ -374,7 +392,7 @@ class ResourceMoveBanMixin:
             self.cli_command(
                 self.lib,
                 ["resource", "arg1", "arg2", "arg3"],
-                dict_to_modifiers(dict()),
+                dict_to_modifiers({}),
             )
         self.assertIsNone(cm.exception.message)
         self.lib_command.assert_not_called()
@@ -384,7 +402,7 @@ class ResourceMoveBanMixin:
             self.cli_command(
                 self.lib,
                 ["resource", "node1", "node2"],
-                dict_to_modifiers(dict()),
+                dict_to_modifiers({}),
             )
         self.assertIsNone(cm.exception.message)
         self.lib_command.assert_not_called()
@@ -394,28 +412,26 @@ class ResourceMoveBanMixin:
             self.cli_command(
                 self.lib,
                 ["resource", "lifetime=1h", "lifetime=2h"],
-                dict_to_modifiers(dict()),
+                dict_to_modifiers({}),
             )
         self.assertIsNone(cm.exception.message)
         self.lib_command.assert_not_called()
 
-    def test_succes(self):
-        self.cli_command(self.lib, ["resource"], dict_to_modifiers(dict()))
+    def test_success(self):
+        self.cli_command(self.lib, ["resource"], dict_to_modifiers({}))
         self.lib_command.assert_called_once_with(
             "resource", lifetime=None, master=False, node=None, wait=False
         )
 
     def test_success_node(self):
-        self.cli_command(
-            self.lib, ["resource", "node"], dict_to_modifiers(dict())
-        )
+        self.cli_command(self.lib, ["resource", "node"], dict_to_modifiers({}))
         self.lib_command.assert_called_once_with(
             "resource", lifetime=None, master=False, node="node", wait=False
         )
 
     def test_success_lifetime(self):
         self.cli_command(
-            self.lib, ["resource", "lifetime=1h"], dict_to_modifiers(dict())
+            self.lib, ["resource", "lifetime=1h"], dict_to_modifiers({})
         )
         self.lib_command.assert_called_once_with(
             "resource", lifetime="P1h", master=False, node=None, wait=False
@@ -423,17 +439,17 @@ class ResourceMoveBanMixin:
 
     def test_success_lifetime_unchanged(self):
         self.cli_command(
-            self.lib, ["resource", "lifetime=T1h"], dict_to_modifiers(dict())
+            self.lib, ["resource", "lifetime=T1h"], dict_to_modifiers({})
         )
         self.lib_command.assert_called_once_with(
             "resource", lifetime="T1h", master=False, node=None, wait=False
         )
 
-    def test_succes_node_lifetime(self):
+    def test_success_node_lifetime(self):
         self.cli_command(
             self.lib,
             ["resource", "node", "lifetime=1h"],
-            dict_to_modifiers(dict()),
+            dict_to_modifiers({}),
         )
         self.lib_command.assert_called_once_with(
             "resource", lifetime="P1h", master=False, node="node", wait=False
@@ -443,7 +459,7 @@ class ResourceMoveBanMixin:
         self.cli_command(
             self.lib,
             ["resource", "lifetime=1h", "node"],
-            dict_to_modifiers(dict()),
+            dict_to_modifiers({}),
         )
         self.lib_command.assert_called_once_with(
             "resource", lifetime="P1h", master=False, node="node", wait=False
@@ -453,44 +469,124 @@ class ResourceMoveBanMixin:
         self.cli_command(
             self.lib,
             ["resource", "lifetime=1h", "node"],
-            dict_to_modifiers(dict(master=True, wait="10")),
+            dict_to_modifiers(dict(promoted=True, wait="10")),
         )
         self.lib_command.assert_called_once_with(
             "resource", lifetime="P1h", master=True, node="node", wait="10"
         )
 
 
-class ResourceMove(ResourceMoveBanMixin, TestCase):
+class ResourceMoveLegacy(ResourceMoveBanMixin, TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["move"])
+        self.resource = mock.Mock(spec_set=["move", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
         self.lib_command = self.resource.move
-        self.cli_command = resource.resource_move
+        self.cli_command = resource.resource_move_with_constraint
         self.no_args_error = "must specify a resource to move"
 
 
 class ResourceBan(ResourceMoveBanMixin, TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["ban"])
+        self.resource = mock.Mock(spec_set=["ban", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
         self.lib_command = self.resource.ban
         self.cli_command = resource.resource_ban
         self.no_args_error = "must specify a resource to ban"
 
 
+@mock.patch("pcs.resource.deprecation_warning")
+class ResourceMove(TestCase):
+    def setUp(self):
+        self.lib = mock.Mock(spec_set=["resource"])
+        self.resource = mock.Mock(spec_set=["move_autoclean", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
+        self.lib.resource = self.resource
+
+    def test_no_args(self, mock_deprecation):
+        with self.assertRaises(CmdLineInputError) as cm:
+            resource.resource_move(self.lib, [], dict_to_modifiers({}))
+        self.assertEqual(
+            cm.exception.message, "must specify a resource to move"
+        )
+        self.resource.move_autoclean.assert_not_called()
+        mock_deprecation.assert_not_called()
+
+    def test_too_many_args(self, mock_deprecation):
+        with self.assertRaises(CmdLineInputError) as cm:
+            resource.resource_move(
+                self.lib,
+                ["resource", "arg1", "arg2"],
+                dict_to_modifiers({}),
+            )
+        self.assertIsNone(cm.exception.message)
+        self.resource.move_autoclean.assert_not_called()
+        mock_deprecation.assert_not_called()
+
+    def test_success(self, mock_deprecation):
+        resource.resource_move(self.lib, ["resource"], dict_to_modifiers({}))
+        self.resource.move_autoclean.assert_called_once_with(
+            "resource", node=None, master=False, wait_timeout=-1, strict=False
+        )
+        mock_deprecation.assert_not_called()
+
+    def test_success_node(self, mock_deprecation):
+        resource.resource_move(
+            self.lib, ["resource", "node"], dict_to_modifiers({})
+        )
+        self.resource.move_autoclean.assert_called_once_with(
+            "resource", node="node", master=False, wait_timeout=-1, strict=False
+        )
+        mock_deprecation.assert_not_called()
+
+    def test_success_wait(self, mock_warn):
+        resource.resource_move(
+            self.lib, ["resource", "node"], dict_to_modifiers(dict(wait=None))
+        )
+        self.resource.move_autoclean.assert_called_once_with(
+            "resource", node="node", master=False, wait_timeout=0, strict=False
+        )
+        mock_warn.assert_not_called()
+
+    def test_success_autodelete(self, mock_deprecation):
+        resource.resource_move(
+            self.lib,
+            ["resource", "node"],
+            dict_to_modifiers(dict(autodelete=True)),
+        )
+        self.resource.move_autoclean.assert_called_once_with(
+            "resource", node="node", master=False, wait_timeout=-1, strict=False
+        )
+        mock_deprecation.assert_called_once_with(
+            "Option '--autodelete' is deprecated. There is no need to use it "
+            "as its functionality is default now."
+        )
+
+    def test_success_all_options(self, mock_warn):
+        resource.resource_move(
+            self.lib,
+            ["resource", "node"],
+            dict_to_modifiers(dict(promoted=True, strict=True, wait="10")),
+        )
+        self.resource.move_autoclean.assert_called_once_with(
+            "resource", node="node", master=True, wait_timeout=10, strict=True
+        )
+        mock_warn.assert_not_called()
+
+
 class ResourceClear(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["unmove_unban"])
+        self.resource = mock.Mock(spec_set=["unmove_unban", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_unmove_unban(
-                self.lib, [], dict_to_modifiers(dict())
-            )
+            resource.resource_unmove_unban(self.lib, [], dict_to_modifiers({}))
         self.assertEqual(
             cm.exception.message, "must specify a resource to clear"
         )
@@ -501,14 +597,14 @@ class ResourceClear(TestCase):
             resource.resource_unmove_unban(
                 self.lib,
                 ["resource", "arg1", "arg2"],
-                dict_to_modifiers(dict()),
+                dict_to_modifiers({}),
             )
         self.assertIsNone(cm.exception.message)
         self.resource.unmove_unban.assert_not_called()
 
-    def test_succes(self):
+    def test_success(self):
         resource.resource_unmove_unban(
-            self.lib, ["resource"], dict_to_modifiers(dict())
+            self.lib, ["resource"], dict_to_modifiers({})
         )
         self.resource.unmove_unban.assert_called_once_with(
             "resource", node=None, master=False, expired=False, wait=False
@@ -516,7 +612,7 @@ class ResourceClear(TestCase):
 
     def test_success_node(self):
         resource.resource_unmove_unban(
-            self.lib, ["resource", "node"], dict_to_modifiers(dict())
+            self.lib, ["resource", "node"], dict_to_modifiers({})
         )
         self.resource.unmove_unban.assert_called_once_with(
             "resource", node="node", master=False, expired=False, wait=False
@@ -526,7 +622,7 @@ class ResourceClear(TestCase):
         resource.resource_unmove_unban(
             self.lib,
             ["resource", "node"],
-            dict_to_modifiers(dict(master=True, expired=True, wait="10")),
+            dict_to_modifiers(dict(promoted=True, expired=True, wait="10")),
         )
         self.resource.unmove_unban.assert_called_once_with(
             "resource", node="node", master=True, expired=True, wait="10"
@@ -535,12 +631,25 @@ class ResourceClear(TestCase):
 
 class ResourceDisable(TestCase):
     def setUp(self):
-        self.lib = mock.Mock(spec_set=["resource"])
+        self.lib = mock.Mock(spec_set=["resource", "env"])
         self.resource = mock.Mock(
-            spec_set=["disable", "disable_safe", "disable_simulate"]
+            spec_set=[
+                "disable",
+                "disable_safe",
+                "disable_simulate",
+                "is_any_stonith",
+            ]
         )
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
+        self.report_processor = mock.Mock(
+            spec_set=["suppress_reports_of_severity"]
+        )
+        self.env = mock.Mock(spec_set=["report_processor"])
+        self.lib.env = self.env
+        self.env.report_processor = self.report_processor
+
     @staticmethod
     def _fixture_output(plaintext=None, resources=None):
         plaintext = plaintext if plaintext is not None else "simulate output"
@@ -552,44 +661,77 @@ class ResourceDisable(TestCase):
 
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_disable_cmd(
-                self.lib, [], dict_to_modifiers(dict())
+            resource.resource_disable_common(
+                self.lib, [], dict_to_modifiers({})
             )
         self.assertEqual(
             cm.exception.message, "You must specify resource(s) to disable"
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_one_resource(self):
-        resource.resource_disable_cmd(
-            self.lib, ["R1"], dict_to_modifiers(dict())
+        resource.resource_disable_common(
+            self.lib, ["R1"], dict_to_modifiers({})
         )
         self.resource.disable.assert_called_once_with(["R1"], False)
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_more_resources(self):
-        resource.resource_disable_cmd(
-            self.lib, ["R1", "R2"], dict_to_modifiers(dict())
+        resource.resource_disable_common(
+            self.lib, ["R1", "R2"], dict_to_modifiers({})
         )
         self.resource.disable.assert_called_once_with(["R1", "R2"], False)
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
+        self.resource.disable_safe.assert_not_called()
+        self.resource.disable_simulate.assert_not_called()
+
+    def test_brief(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            resource.resource_disable_common(
+                self.lib, ["R1", "R2"], dict_to_modifiers(dict(brief=True))
+            )
+        self.assertEqual(
+            cm.exception.message,
+            "'--brief' cannot be used without '--simulate' or '--safe'",
+        )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
+        self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_safe(self):
-        resource.resource_disable_cmd(
+        resource.resource_disable_common(
             self.lib, ["R1", "R2"], dict_to_modifiers(dict(safe=True))
         )
         self.resource.disable_safe.assert_called_once_with(
             ["R1", "R2"], True, False
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
+        self.resource.disable.assert_not_called()
+        self.resource.disable_simulate.assert_not_called()
+
+    def test_safe_brief(self):
+        resource.resource_disable_common(
+            self.lib,
+            ["R1", "R2"],
+            dict_to_modifiers(dict(safe=True, brief=True)),
+        )
+        self.resource.disable_safe.assert_called_once_with(
+            ["R1", "R2"], True, False
+        )
+        self.report_processor.suppress_reports_of_severity.assert_called_once_with(
+            [ReportItemSeverity.INFO]
+        )
         self.resource.disable.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_safe_wait(self):
-        resource.resource_disable_cmd(
+        resource.resource_disable_common(
             self.lib,
             ["R1", "R2"],
             dict_to_modifiers(dict(safe=True, wait="10")),
@@ -597,21 +739,23 @@ class ResourceDisable(TestCase):
         self.resource.disable_safe.assert_called_once_with(
             ["R1", "R2"], True, "10"
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_safe_no_strict(self):
-        resource.resource_disable_cmd(
+        resource.resource_disable_common(
             self.lib, ["R1", "R2"], dict_to_modifiers({"no-strict": True})
         )
         self.resource.disable_safe.assert_called_once_with(
             ["R1", "R2"], False, False
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_safe_no_strict_wait(self):
-        resource.resource_disable_cmd(
+        resource.resource_disable_common(
             self.lib,
             ["R1", "R2"],
             dict_to_modifiers({"no-strict": True, "wait": "10"}),
@@ -619,18 +763,20 @@ class ResourceDisable(TestCase):
         self.resource.disable_safe.assert_called_once_with(
             ["R1", "R2"], False, "10"
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     @mock.patch("pcs.resource.print")
     def test_simulate(self, mock_print):
         self.resource.disable_simulate.return_value = self._fixture_output()
-        resource.resource_disable_cmd(
+        resource.resource_disable_common(
             self.lib, ["R1", "R2"], dict_to_modifiers(dict(simulate=True))
         )
         self.resource.disable_simulate.assert_called_once_with(
             ["R1", "R2"], True
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         mock_print.assert_called_once_with("simulate output")
@@ -646,6 +792,7 @@ class ResourceDisable(TestCase):
         self.resource.disable_simulate.assert_called_once_with(
             ["R1", "R2"], True
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         mock_print.assert_called_once_with("Rx\nRy")
@@ -663,6 +810,7 @@ class ResourceDisable(TestCase):
         self.resource.disable_simulate.assert_called_once_with(
             ["R1", "R2"], False
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         mock_print.assert_called_once_with("Rx\nRy")
@@ -680,13 +828,14 @@ class ResourceDisable(TestCase):
         self.resource.disable_simulate.assert_called_once_with(
             ["R1", "R2"], True
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         mock_print.assert_not_called()
 
     def test_simulate_wait(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_disable_cmd(
+            resource.resource_disable_common(
                 self.lib,
                 ["R1"],
                 dict_to_modifiers(dict(simulate=True, wait=True)),
@@ -695,13 +844,14 @@ class ResourceDisable(TestCase):
             cm.exception.message,
             "Only one of '--simulate', '--wait' can be used",
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_simulate_safe(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_disable_cmd(
+            resource.resource_disable_common(
                 self.lib,
                 ["R1"],
                 dict_to_modifiers(
@@ -711,14 +861,16 @@ class ResourceDisable(TestCase):
         self.assertEqual(
             cm.exception.message, "'--simulate' cannot be used with '--safe'"
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_not_called()
         self.resource.disable_safe.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
 
     def test_wait(self):
-        resource.resource_disable_cmd(
+        resource.resource_disable_common(
             self.lib, ["R1", "R2"], dict_to_modifiers(dict(wait="10"))
         )
+        self.report_processor.suppress_reports_of_severity.assert_not_called()
         self.resource.disable.assert_called_once_with(["R1", "R2"], "10")
         self.resource.disable_safe.assert_not_called()
         self.resource.disable_simulate.assert_not_called()
@@ -728,8 +880,14 @@ class ResourceSafeDisable(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
         self.resource = mock.Mock(
-            spec_set=["disable", "disable_safe", "disable_simulate"]
+            spec_set=[
+                "disable",
+                "disable_safe",
+                "disable_simulate",
+                "is_any_stonith",
+            ]
         )
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
         self.force_warning = (
             "option '--force' is specified therefore checks for disabling "
@@ -970,28 +1128,25 @@ class ResourceSafeDisable(TestCase):
 class ResourceEnable(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["enable"])
+        self.resource = mock.Mock(spec_set=["enable", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_enable_cmd(
-                self.lib, [], dict_to_modifiers(dict())
-            )
+            resource.resource_enable_cmd(self.lib, [], dict_to_modifiers({}))
         self.assertEqual(
             cm.exception.message, "You must specify resource(s) to enable"
         )
         self.resource.enable.assert_not_called()
 
     def test_one_resource(self):
-        resource.resource_enable_cmd(
-            self.lib, ["R1"], dict_to_modifiers(dict())
-        )
+        resource.resource_enable_cmd(self.lib, ["R1"], dict_to_modifiers({}))
         self.resource.enable.assert_called_once_with(["R1"], False)
 
     def test_more_resources(self):
         resource.resource_enable_cmd(
-            self.lib, ["R1", "R2"], dict_to_modifiers(dict())
+            self.lib, ["R1", "R2"], dict_to_modifiers({})
         )
         self.resource.enable.assert_called_once_with(["R1", "R2"], False)
 
@@ -1007,28 +1162,25 @@ class ResourceEnable(TestCase):
 class ResourceManage(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["manage"])
+        self.resource = mock.Mock(spec_set=["manage", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_manage_cmd(
-                self.lib, [], dict_to_modifiers(dict())
-            )
+            resource.resource_manage_cmd(self.lib, [], dict_to_modifiers({}))
         self.assertEqual(
             cm.exception.message, "You must specify resource(s) to manage"
         )
         self.resource.manage.assert_not_called()
 
     def test_one_resource(self):
-        resource.resource_manage_cmd(
-            self.lib, ["R1"], dict_to_modifiers(dict())
-        )
+        resource.resource_manage_cmd(self.lib, ["R1"], dict_to_modifiers({}))
         self.resource.manage.assert_called_once_with(["R1"], with_monitor=False)
 
     def test_more_resources(self):
         resource.resource_manage_cmd(
-            self.lib, ["R1", "R2"], dict_to_modifiers(dict())
+            self.lib, ["R1", "R2"], dict_to_modifiers({})
         )
         self.resource.manage.assert_called_once_with(
             ["R1", "R2"], with_monitor=False
@@ -1048,30 +1200,27 @@ class ResourceManage(TestCase):
 class ResourceUnmanage(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["unmanage"])
+        self.resource = mock.Mock(spec_set=["unmanage", "is_any_stonith"])
+        self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
     def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
-            resource.resource_unmanage_cmd(
-                self.lib, [], dict_to_modifiers(dict())
-            )
+            resource.resource_unmanage_cmd(self.lib, [], dict_to_modifiers({}))
         self.assertEqual(
             cm.exception.message, "You must specify resource(s) to unmanage"
         )
         self.resource.unmanage.assert_not_called()
 
     def test_one_resource(self):
-        resource.resource_unmanage_cmd(
-            self.lib, ["R1"], dict_to_modifiers(dict())
-        )
+        resource.resource_unmanage_cmd(self.lib, ["R1"], dict_to_modifiers({}))
         self.resource.unmanage.assert_called_once_with(
             ["R1"], with_monitor=False
         )
 
     def test_more_resources(self):
         resource.resource_unmanage_cmd(
-            self.lib, ["R1", "R2"], dict_to_modifiers(dict())
+            self.lib, ["R1", "R2"], dict_to_modifiers({})
         )
         self.resource.unmanage.assert_called_once_with(
             ["R1", "R2"], with_monitor=False
