@@ -1,13 +1,9 @@
-from unittest import mock, TestCase
-from lxml import etree
-
-from pcs_test.tools.assertions import (
-    assert_raise_library_error,
-    assert_xml_equal,
-    ExtendedAssertionsMixin,
+from unittest import (
+    TestCase,
+    mock,
 )
-from pcs_test.tools.misc import get_test_resource as rc
-from pcs_test.tools.xml import get_xml_manipulation_creator_from_file
+
+from lxml import etree
 
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
@@ -15,6 +11,14 @@ from pcs.lib.cib import acl as lib
 from pcs.lib.cib.tools import get_acls
 from pcs.lib.errors import LibraryError
 
+from pcs_test.tools.assertions import (
+    ExtendedAssertionsMixin,
+    assert_raise_library_error,
+    assert_xml_equal,
+)
+from pcs_test.tools.misc import get_test_resource as rc
+from pcs_test.tools.xml import get_xml_manipulation_creator_from_file
+
 
 class LibraryAclTest(TestCase):
     def setUp(self):
@@ -313,7 +317,7 @@ class AssignRoleTest(LibraryAclTest):
             )
         )
 
-    def test_sucess_group(self):
+    def test_success_group(self):
         group = self.cib.tree.find(".//acl_group[@id='group1']")
         lib.assign_role(self.cib.tree, "role1", group)
         self.assert_cib_equal(
@@ -706,7 +710,7 @@ class RemoveGroupTest(LibraryAclTest, ExtendedAssertionsMixin):
 
 
 class RemovePermissionForReferenceTest(LibraryAclTest):
-    def test_has_no_efect_when_id_not_referenced(self):
+    def test_has_no_effect_when_id_not_referenced(self):
         lib.remove_permissions_referencing(self.cib.tree, "dummy")
         self.assert_cib_equal(self.create_cib())
 
