@@ -1,18 +1,22 @@
 from functools import partial
-from unittest import mock, TestCase
-from lxml import etree
-
-from pcs_test.tools.assertions import (
-    assert_raise_library_error,
-    assert_xml_equal,
+from unittest import (
+    TestCase,
+    mock,
 )
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-from pcs_test.tools.assertions import assert_report_item_list_equal
+
+from lxml import etree
 
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.constraint import constraint
 
+from pcs_test.tools.assertions import (
+    assert_raise_library_error,
+    assert_report_item_list_equal,
+    assert_xml_equal,
+)
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
+
 # pylint: disable=no-self-use, redundant-keyword-arg
 
 
@@ -188,7 +192,7 @@ class PrepareOptionsTest(TestCase):
             ),
         )
 
-    def test_has_no_side_efect_on_input_options(self):
+    def test_has_no_side_effect_on_input_options(self):
         mock_create_id = mock.MagicMock()
         mock_create_id.return_value = "new-id"
         options = {"a": "b"}
@@ -229,8 +233,8 @@ class CreateIdTest(TestCase):
 
 def fixture_constraint_section(return_value):
     constraint_section = mock.MagicMock()
-    constraint_section.findall = mock.MagicMock()
-    constraint_section.findall.return_value = return_value
+    constraint_section.xpath = mock.MagicMock()
+    constraint_section.xpath.return_value = return_value
     return constraint_section
 
 
@@ -306,7 +310,7 @@ class CheckIsWithoutDuplicationTest(TestCase):
             element,
             are_duplicate=lambda e1, e2: True,
             export_element=constraint.export_with_set,
-            duplication_alowed=True,
+            duplication_allowed=True,
         )
         assert_report_item_list_equal(
             report_processor.report_item_list,
