@@ -1,40 +1,65 @@
 from functools import partial
-from unittest import mock, TestCase
-from lxml import etree
-
-from pcs_test.tools.assertions import (
-    assert_raise_library_error,
-    assert_xml_equal,
+from unittest import (
+    TestCase,
+    mock,
 )
 
+from lxml import etree
+
+from pcs.common import const
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.constraint import ticket
 
+from pcs_test.tools import fixture
+from pcs_test.tools.assertions import (
+    assert_raise_library_error,
+    assert_xml_equal,
+)
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
+
+@mock.patch(
+    "pcs.lib.cib.constraint.ticket.tools.are_new_role_names_supported",
+    lambda _: True,
+)
 @mock.patch("pcs.lib.cib.constraint.ticket.tools.check_new_id_applicable")
 class PrepareOptionsPlainTest(TestCase):
     def setUp(self):
         self.cib = "cib"
-        self.prepare = partial(ticket.prepare_options_plain, self.cib)
+        self.report_processor = MockLibraryReportProcessor(debug=False)
+        self.prepare = partial(
+            ticket.prepare_options_plain, self.cib, self.report_processor
+        )
 
     @mock.patch("pcs.lib.cib.constraint.ticket._create_id")
     def test_prepare_correct_options(self, mock_create_id, _):
         mock_create_id.return_value = "generated_id"
+        role = str(const.PCMK_ROLE_PROMOTED_LEGACY).lower()
         self.assertEqual(
             {
                 "id": "generated_id",
                 "loss-policy": "fence",
                 "rsc": "resourceA",
-                "rsc-role": "Master",
-                "ticket": "ticket_key",
+                "rsc-role": const.PCMK_ROLE_PROMOTED_PRIMARY,
+                "ticket": "ticket-key",
             },
             self.prepare(
-                {"loss-policy": "fence", "rsc-role": "master"},
-                "ticket_key",
+                {"loss-policy": "fence", "rsc-role": role},
+                "ticket-key",
                 "resourceA",
             ),
         )
+        self.report_processor.assert_reports(
+            [
+                fixture.deprecation(
+                    report_codes.DEPRECATED_OPTION_VALUE,
+                    option_name="role",
+                    deprecated_value=role,
+                    replaced_by=const.PCMK_ROLE_PROMOTED,
+                )
+            ]
+        )
 
     @mock.patch("pcs.lib.cib.constraint.ticket._create_id")
     def test_does_not_include_role_if_not_presented(self, mock_create_id, _):
@@ -44,121 +69,156 @@ class PrepareOptionsPlainTest(TestCase):
                 "id": "generated_id",
                 "loss-policy": "fence",
                 "rsc": "resourceA",
-                "ticket": "ticket_key",
+                "ticket": "ticket-key",
             },
             self.prepare(
                 {"loss-policy": "fence", "rsc-role": ""},
-                "ticket_key",
+                "ticket-key",
                 "resourceA",
             ),
         )
+        self.report_processor.assert_reports([])
 
     def test_refuse_unknown_attributes(self, _):
         assert_raise_library_error(
             lambda: self.prepare(
-                {"unknown": "nonsense", "rsc-role": "master"},
-                "ticket_key",
+                {"unknown": "nonsense", "rsc-role": "promoted"},
+                "ticket-key",
                 "resourceA",
-            ),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTIONS,
-                {
-                    "option_names": ["unknown"],
-                    "option_type": None,
-                    "allowed": [
+            )
+        )
+        self.report_processor.assert_reports(
+            [
+                fixture.error(
+                    report_codes.INVALID_OPTIONS,
+                    option_names=["unknown"],
+                    option_type=None,
+                    allowed=[
                         "id",
                         "loss-policy",
-                        "rsc",
                         "rsc-role",
-                        "ticket",
                     ],
-                    "allowed_patterns": [],
-                },
-            ),
+                    allowed_patterns=[],
+                )
+            ]
         )
 
     def test_refuse_bad_role(self, _):
         assert_raise_library_error(
             lambda: self.prepare(
-                {"id": "id", "rsc-role": "bad_role"}, "ticket_key", "resourceA"
-            ),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTION_VALUE,
-                {
-                    "allowed_values": ("Master", "Slave", "Started", "Stopped"),
-                    "option_value": "bad_role",
-                    "option_name": "rsc-role",
-                    "cannot_be_empty": False,
-                    "forbidden_characters": None,
-                },
+                {"id": "id", "rsc-role": "bad_role"}, "ticket-key", "resourceA"
             ),
         )
+        self.report_processor.assert_reports(
+            [
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    allowed_values=const.PCMK_ROLES,
+                    option_value="bad_role",
+                    option_name="role",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ]
+        )
 
     def test_refuse_missing_ticket(self, _):
+        role = str(const.PCMK_ROLE_UNPROMOTED_LEGACY).lower()
         assert_raise_library_error(
             lambda: self.prepare(
-                {"id": "id", "rsc-role": "master"}, "", "resourceA"
+                {"id": "id", "rsc-role": role}, "", "resourceA"
             ),
-            (
-                severities.ERROR,
-                report_codes.REQUIRED_OPTIONS_ARE_MISSING,
+        )
+        self.report_processor.assert_reports(
+            [
+                fixture.error(
+                    report_codes.REQUIRED_OPTIONS_ARE_MISSING,
+                    option_names=["ticket"],
+                    option_type=None,
+                ),
+                fixture.deprecation(
+                    report_codes.DEPRECATED_OPTION_VALUE,
+                    option_name="role",
+                    deprecated_value=role,
+                    replaced_by=const.PCMK_ROLE_UNPROMOTED,
+                ),
+            ]
+        )
+
+    def test_refuse_bad_ticket(self, _):
+        assert_raise_library_error(
+            lambda: self.prepare(
                 {
-                    "option_names": ["ticket"],
-                    "option_type": None,
+                    "id": "id",
                 },
+                "bad_ticket",
+                "resourceA",
             ),
         )
+        self.report_processor.assert_reports(
+            [
+                fixture.error(
+                    report_codes.BOOTH_TICKET_NAME_INVALID,
+                    ticket_name="bad_ticket",
+                ),
+            ]
+        )
 
     def test_refuse_missing_resource_id(self, _):
         assert_raise_library_error(
             lambda: self.prepare(
-                {"id": "id", "rsc-role": "master"}, "ticket_key", ""
-            ),
-            (
-                severities.ERROR,
-                report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                {
-                    "option_names": ["rsc"],
-                    "option_type": None,
-                },
+                {"id": "id", "rsc-role": const.PCMK_ROLE_PROMOTED},
+                "ticket-key",
+                "",
             ),
         )
+        self.report_processor.assert_reports(
+            [
+                fixture.error(
+                    report_codes.REQUIRED_OPTIONS_ARE_MISSING,
+                    option_names=["rsc"],
+                    option_type=None,
+                ),
+            ]
+        )
 
     def test_refuse_unknown_lost_policy(self, mock_check_new_id_applicable):
         # pylint: disable=unused-argument
         assert_raise_library_error(
             lambda: self.prepare(
-                {"loss-policy": "unknown", "ticket": "T", "id": "id"},
-                "ticket_key",
+                {"loss-policy": "unknown", "id": "id"},
+                "ticket-key",
                 "resourceA",
             ),
-            (
-                severities.ERROR,
-                report_codes.INVALID_OPTION_VALUE,
-                {
-                    "allowed_values": ("fence", "stop", "freeze", "demote"),
-                    "option_value": "unknown",
-                    "option_name": "loss-policy",
-                    "cannot_be_empty": False,
-                    "forbidden_characters": None,
-                },
-            ),
+        )
+        self.report_processor.assert_reports(
+            [
+                fixture.error(
+                    report_codes.INVALID_OPTION_VALUE,
+                    allowed_values=("fence", "stop", "freeze", "demote"),
+                    option_value="unknown",
+                    option_name="loss-policy",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ]
         )
 
     @mock.patch("pcs.lib.cib.constraint.ticket._create_id")
     def test_complete_id(self, mock_create_id, _):
         mock_create_id.return_value = "generated_id"
-        options = {"loss-policy": "freeze", "ticket": "T", "rsc-role": "Master"}
-        ticket_key = "ticket_key"
+        options = {
+            "loss-policy": "freeze",
+            "rsc-role": const.PCMK_ROLE_PROMOTED,
+        }
+        ticket_key = "ticket-key"
         resource_id = "resourceA"
         expected_options = options.copy()
         expected_options.update(
             {
                 "id": "generated_id",
                 "rsc": resource_id,
-                "rsc-role": "Master",
+                "rsc-role": const.PCMK_ROLE_PROMOTED_PRIMARY,
                 "ticket": ticket_key,
             }
         )
@@ -174,7 +234,7 @@ class PrepareOptionsPlainTest(TestCase):
             self.cib,
             ticket_key,
             resource_id,
-            "Master",
+            const.PCMK_ROLE_PROMOTED_PRIMARY,
         )
 
 
@@ -267,6 +327,16 @@ class PrepareOptionsWithSetTest(TestCase):
             ),
         )
 
+    def test_refuse_bad_ticket(self, _):
+        assert_raise_library_error(
+            lambda: self.prepare({"id": "id", "ticket": "bad_ticket"}),
+            (
+                severities.ERROR,
+                report_codes.BOOTH_TICKET_NAME_INVALID,
+                {"ticket_name": "bad_ticket"},
+            ),
+        )
+
 
 class Element:
     # pylint: disable=too-few-public-methods
@@ -281,39 +351,67 @@ class Element:
 class AreDuplicatePlain(TestCase):
     def setUp(self):
         self.first = Element(
-            {"ticket": "ticket_key", "rsc": "resourceA", "rsc-role": "Master"}
+            {
+                "ticket": "ticket-key",
+                "rsc": "resourceA",
+                "rsc-role": const.PCMK_ROLE_PROMOTED_LEGACY,
+            }
         )
         self.second = Element(
-            {"ticket": "ticket_key", "rsc": "resourceA", "rsc-role": "Master"}
+            {
+                "ticket": "ticket-key",
+                "rsc": "resourceA",
+                "rsc-role": const.PCMK_ROLE_PROMOTED_LEGACY,
+            }
         )
 
     def test_returns_true_for_duplicate_elements(self):
-        self.assertTrue(ticket.are_duplicate_plain(self.first, self.second))
+        self.assertTrue(
+            ticket.get_duplicit_checker_callback(False)(self.first, self.second)
+        )
 
     def test_returns_false_for_different_ticket(self):
         self.assertFalse(
-            ticket.are_duplicate_plain(
+            ticket.get_duplicit_checker_callback(False)(
                 self.first, self.second.update({"ticket": "X"})
             )
         )
 
     def test_returns_false_for_different_resource(self):
         self.assertFalse(
-            ticket.are_duplicate_plain(
+            ticket.get_duplicit_checker_callback(False)(
                 self.first, self.second.update({"rsc": "Y"})
             )
         )
 
     def test_returns_false_for_different_role(self):
         self.assertFalse(
-            ticket.are_duplicate_plain(
+            ticket.get_duplicit_checker_callback(False)(
                 self.first, self.second.update({"rsc-role": "Z"})
             )
         )
 
     def test_returns_false_for_different_elements(self):
         self.second.update({"ticket": "X", "rsc": "Y", "rsc-role": "Z"})
-        self.assertFalse(ticket.are_duplicate_plain(self.first, self.second))
+        self.assertFalse(
+            ticket.get_duplicit_checker_callback(False)(self.first, self.second)
+        )
+
+    def test_returns_true_for_equivalent_new_role(self):
+        self.assertTrue(
+            ticket.get_duplicit_checker_callback(False)(
+                self.first,
+                self.second.update({"rsc-role": const.PCMK_ROLE_PROMOTED}),
+            )
+        )
+
+    def test_returns_true_for_equivalent_new_role_new_roles_supported(self):
+        self.assertTrue(
+            ticket.get_duplicit_checker_callback(True)(
+                self.first,
+                self.second.update({"rsc-role": const.PCMK_ROLE_PROMOTED}),
+            )
+        )
 
 
 @mock.patch(
@@ -326,8 +424,8 @@ class AreDuplicateWithResourceSet(TestCase):
         mock_have_duplicate_resource_sets.return_value = True
         self.assertTrue(
             ticket.are_duplicate_with_resource_set(
-                Element({"ticket": "ticket_key"}),
-                Element({"ticket": "ticket_key"}),
+                Element({"ticket": "ticket-key"}),
+                Element({"ticket": "ticket-key"}),
             )
         )
 
@@ -337,7 +435,7 @@ class AreDuplicateWithResourceSet(TestCase):
         mock_have_duplicate_resource_sets.return_value = True
         self.assertFalse(
             ticket.are_duplicate_with_resource_set(
-                Element({"ticket": "ticket_key"}),
+                Element({"ticket": "ticket-key"}),
                 Element({"ticket": "X"}),
             )
         )
