@@ -2,13 +2,6 @@ from unittest import TestCase
 
 from lxml import etree
 
-from pcs_test.tools import fixture
-from pcs_test.tools.assertions import (
-    assert_report_item_list_equal,
-    assert_xml_equal,
-)
-from pcs_test.tools.xml import etree_to_str
-
 from pcs.common import reports
 from pcs.common.pacemaker.nvset import (
     CibNvpairDto,
@@ -20,9 +13,8 @@ from pcs.common.pacemaker.rule import (
 )
 from pcs.common.tools import Version
 from pcs.common.types import (
-    CibNvsetType,
-    CibRuleInEffectStatus,
     CibRuleExpressionType,
+    CibRuleInEffectStatus,
 )
 from pcs.lib.cib import nvpair_multi
 from pcs.lib.cib.rule import RuleInEffectEval
@@ -39,10 +31,17 @@ from pcs.lib.cib.rule.expression_part import (
 )
 from pcs.lib.cib.tools import IdProvider
 
+from pcs_test.tools import fixture
+from pcs_test.tools.assertions import (
+    assert_report_item_list_equal,
+    assert_xml_equal,
+)
+from pcs_test.tools.xml import etree_to_str
+
 
 class RuleInEffectEvalMock(RuleInEffectEval):
     def __init__(self, mock_data=None):
-        self._mock_data = mock_data or dict()
+        self._mock_data = mock_data or {}
 
     def get_rule_status(self, rule_id):
         return self._mock_data.get(rule_id, CibRuleInEffectStatus.UNKNOWN)
@@ -66,25 +65,26 @@ class NvpairElementToDto(TestCase):
 
 
 class NvsetElementToDto(TestCase):
-    tag_type = (
-        ("meta_attributes", CibNvsetType.META),
-        ("instance_attributes", CibNvsetType.INSTANCE),
+    all_nvsets = (
+        nvpair_multi.NVSET_INSTANCE,
+        nvpair_multi.NVSET_META,
+        nvpair_multi.NVSET_UTILIZATION,
     )
 
     def test_minimal(self):
-        for tag, nvtype in self.tag_type:
-            with self.subTest(tag=tag, nvset_type=nvtype):
+        for tag in self.all_nvsets:
+            with self.subTest(tag=tag):
                 xml = etree.fromstring(f"""<{tag} id="my-id" />""")
                 self.assertEqual(
                     nvpair_multi.nvset_element_to_dto(
                         xml, get_in_effect_eval()
                     ),
-                    CibNvsetDto("my-id", nvtype, {}, None, []),
+                    CibNvsetDto("my-id", {}, None, []),
                 )
 
     def test_expired(self):
-        for tag, nvtype in self.tag_type:
-            with self.subTest(tag=tag, nvset_type=nvtype):
+        for tag in self.all_nvsets:
+            with self.subTest(tag=tag):
                 xml = etree.fromstring(
                     f"""
                     <{tag} id="my-id" score="150">
@@ -107,7 +107,6 @@ class NvsetElementToDto(TestCase):
                     ),
                     CibNvsetDto(
                         "my-id",
-                        nvtype,
                         {"score": "150"},
                         CibRuleExpressionDto(
                             "my-id-rule",
@@ -139,8 +138,8 @@ class NvsetElementToDto(TestCase):
                 )
 
     def test_full(self):
-        for tag, nvtype in self.tag_type:
-            with self.subTest(tag=tag, nvset_type=nvtype):
+        for tag in self.all_nvsets:
+            with self.subTest(tag=tag):
                 xml = etree.fromstring(
                     f"""
                     <{tag} id="my-id" score="150">
@@ -195,7 +194,6 @@ class NvsetElementToDto(TestCase):
                     ),
                     CibNvsetDto(
                         "my-id",
-                        nvtype,
                         {"score": "150"},
                         CibRuleExpressionDto(
                             "my-id-rule",
@@ -360,23 +358,45 @@ class NvsetElementToDto(TestCase):
 
 
 class FindNvsets(TestCase):
-    def test_empty(self):
-        xml = etree.fromstring("<parent />")
-        self.assertEqual([], nvpair_multi.find_nvsets(xml))
-
-    def test_full(self):
-        xml = etree.fromstring(
+    def setUp(self):
+        self.xml = etree.fromstring(
             """
             <parent>
                 <meta_attributes id="set1" />
                 <instance_attributes id="set2" />
                 <not_an_nvset id="set3" />
+                <instance_attributes id="set6" />
+                <meta_attributes id="set5" />
             </parent>
         """
         )
+
+    def test_empty(self):
+        xml = etree.fromstring("<parent />")
         self.assertEqual(
-            ["set1", "set2"],
-            [el.get("id") for el in nvpair_multi.find_nvsets(xml)],
+            [], nvpair_multi.find_nvsets(xml, nvpair_multi.NVSET_META)
+        )
+
+    def test_meta(self):
+        self.assertEqual(
+            ["set1", "set5"],
+            [
+                el.get("id")
+                for el in nvpair_multi.find_nvsets(
+                    self.xml, nvpair_multi.NVSET_META
+                )
+            ],
+        )
+
+    def test_instance(self):
+        self.assertEqual(
+            ["set2", "set6"],
+            [
+                el.get("id")
+                for el in nvpair_multi.find_nvsets(
+                    self.xml, nvpair_multi.NVSET_INSTANCE
+                )
+            ],
         )
 
 
@@ -533,7 +553,7 @@ class ValidateNvsetAppendNew(TestCase):
                 fixture.error(
                     reports.codes.RULE_EXPRESSION_PARSE_ERROR,
                     rule_string="bad rule",
-                    reason='Expected "eq"',
+                    reason="Expected 'eq'",
                     rule_line="bad rule",
                     line_number=1,
                     column_number=5,
