@@ -1,19 +1,17 @@
-# pylint: disable=too-many-lines
 from unittest import TestCase
+
 from lxml import etree
 
+from pcs.lib.cib.resource import common
+from pcs.lib.cib.tools import IdProvider
+
+from pcs_test.tools import fixture
 from pcs_test.tools.assertions import (
     assert_report_item_list_equal,
     assert_xml_equal,
 )
-from pcs_test.tools import fixture
 from pcs_test.tools.xml import etree_to_str
 
-from pcs.common.reports import codes as report_codes
-from pcs.lib.cib.resource import common
-from pcs.lib.cib.tools import IdProvider
-
-
 fixture_cib = etree.fromstring(
     """
     <cib>
@@ -132,7 +130,7 @@ class FindOneOrMoreResources(TestCase):
         self.assertEqual("R1", resource.attrib.get("id"))
         assert_report_item_list_equal(report_list, [])
 
-    def test_one_nonexistant(self):
+    def test_one_nonexistent(self):
         resource, report_list = common.find_one_resource(self.cib, "R-missing")
         self.assertIsNone(resource)
         assert_report_item_list_equal(
@@ -863,457 +861,6 @@ class Unmanage(TestCase):
         )
 
 
-class ValidateMoveBanClearMixin:
-    # pylint: disable=too-many-public-methods,line-too-long
-    @staticmethod
-    def _fixture_clone(promotable=False):
-        return etree.fromstring(
-            f"""
-            <clone id="R-clone">
-                <primitive id="R" />
-                <meta_attributes>
-                    <nvpair name="promotable" value="{'true' if promotable else 'false'}" />
-                </meta_attributes>
-            </clone>
-            """
-        )
-
-    @staticmethod
-    def _fixture_group_clone(promotable=False):
-        return etree.fromstring(
-            f"""
-            <clone id="G-clone">
-                <group id="G">
-                    <primitive id="R" />
-                </group>
-                <meta_attributes>
-                    <nvpair name="promotable" value="{'true' if promotable else 'false'}" />
-                </meta_attributes>
-            </clone>
-            """
-        )
-
-    @staticmethod
-    def _fixture_master():
-        return etree.fromstring(
-            """
-            <master id="R-master">
-                <primitive id="R" />
-            </master>
-            """
-        )
-
-    @staticmethod
-    def _fixture_group_master():
-        return etree.fromstring(
-            """
-            <master id="G-master">
-                <group id="G">
-                    <primitive id="R" />
-                </group>
-            </master>
-            """
-        )
-
-    def test_master_true_promotable_clone(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(self.validate(element, True), [])
-
-    def test_master_false_promotable_clone(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(self.validate(element, False), [])
-
-    def test_master_true_clone(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element, True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R-clone",
-                    promotable_id=None,
-                ),
-            ],
-        )
-
-    def test_master_false_clone(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(self.validate(element, False), [])
-
-    def test_master_true_master(self):
-        element = self._fixture_master()
-        assert_report_item_list_equal(self.validate(element, True), [])
-
-    def test_master_false_master(self):
-        element = self._fixture_master()
-        assert_report_item_list_equal(self.validate(element, False), [])
-
-    def test_master_true_promotable_clone_resource(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R",
-                    promotable_id="R-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_promotable_clone_resource(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False), []
-        )
-
-    def test_master_true_promotable_clone_group(self):
-        element = self._fixture_group_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="G",
-                    promotable_id="G-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_promotable_clone_group(self):
-        element = self._fixture_group_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), False), []
-        )
-
-    def test_master_true_promotable_clone_group_resource(self):
-        element = self._fixture_group_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R",
-                    promotable_id="G-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_promotable_clone_group_resource(self):
-        element = self._fixture_group_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), False), []
-        )
-
-    def test_master_true_clone_resource(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R",
-                    promotable_id=None,
-                ),
-            ],
-        )
-
-    def test_master_false_clone_resource(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False), []
-        )
-
-    def test_master_true_clone_group(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="G",
-                    promotable_id=None,
-                ),
-            ],
-        )
-
-    def test_master_false_clone_group(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), False), []
-        )
-
-    def test_master_true_clone_group_resource(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R",
-                    promotable_id=None,
-                ),
-            ],
-        )
-
-    def test_master_false_clone_group_resource(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), False), []
-        )
-
-    def test_master_true_master_resource(self):
-        element = self._fixture_master()
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R",
-                    promotable_id="R-master",
-                ),
-            ],
-        )
-
-    def test_master_true_master_group(self):
-        element = self._fixture_group_master()
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="G",
-                    promotable_id="G-master",
-                ),
-            ],
-        )
-
-    def test_master_true_master_group_resource(self):
-        element = self._fixture_group_master()
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), True),
-            [
-                fixture.error(
-                    self.report_code_bad_master,
-                    resource_id="R",
-                    promotable_id="G-master",
-                ),
-            ],
-        )
-
-
-class ValidateMove(ValidateMoveBanClearMixin, TestCase):
-    validate = staticmethod(common.validate_move)
-    report_code_bad_master = (
-        report_codes.CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
-    )
-
-    @staticmethod
-    def _fixture_bundle():
-        return etree.fromstring(
-            """
-            <bundle id="R-bundle">
-                <primitive id="R" />
-            </bundle>
-            """
-        )
-
-    def test_master_false_promotable_clone(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            [],
-        )
-
-    def test_master_true_promotable_clone(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element, True),
-            [],
-        )
-
-    def test_master_true_clone(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element, True),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_clone(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_master(self):
-        element = self._fixture_master()
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            [],
-        )
-
-    def test_master_true_master(self):
-        element = self._fixture_master()
-        assert_report_item_list_equal(
-            self.validate(element, True),
-            [],
-        )
-
-    def test_master_false_promotable_clone_resource(self):
-        element = self._fixture_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER,
-                    resource_id="R",
-                    promotable_id="R-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_promotable_clone_group(self):
-        element = self._fixture_group_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER,
-                    resource_id="G",
-                    promotable_id="G-clone",
-                ),
-            ],
-        )
-
-    def test_master_false_promotable_clone_group_resource(self):
-        element = self._fixture_group_clone(True)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER,
-                    resource_id="R",
-                    promotable_id="G-clone",
-                ),
-            ],
-        )
-
-    def test_master_true_clone_resource(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), True),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R",
-                ),
-            ],
-        )
-
-    def test_master_false_clone_resource(self):
-        element = self._fixture_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R",
-                ),
-            ],
-        )
-
-    def test_master_true_clone_group(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), True),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="G",
-                ),
-            ],
-        )
-
-    def test_master_false_clone_group(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group"), False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="G",
-                ),
-            ],
-        )
-
-    def test_master_true_clone_group_resource(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), True),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R",
-                ),
-            ],
-        )
-
-    def test_master_false_clone_group_resource(self):
-        element = self._fixture_group_clone(False)
-        assert_report_item_list_equal(
-            self.validate(element.find("./group/primitive"), False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R",
-                ),
-            ],
-        )
-
-    def test_bundle(self):
-        element = self._fixture_bundle()
-        assert_report_item_list_equal(
-            self.validate(element, False),
-            [
-                fixture.error(
-                    report_codes.CANNOT_MOVE_RESOURCE_BUNDLE,
-                    resource_id="R-bundle",
-                ),
-            ],
-        )
-
-    def test_bundle_resource(self):
-        element = self._fixture_bundle()
-        assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False), []
-        )
-
-
-class ValidateBan(ValidateMoveBanClearMixin, TestCase):
-    validate = staticmethod(common.validate_ban)
-    report_code_bad_master = (
-        report_codes.CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
-    )
-
-
-class ValidateUnmoveUnban(ValidateMoveBanClearMixin, TestCase):
-    validate = staticmethod(common.validate_unmove_unban)
-    report_code_bad_master = (
-        report_codes.CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
-    )
-
-
 class FindResourcesToDelete(TestCase):
     # pylint: disable=too-many-public-methods
     def assert_element2element_list(self, element_id, element_id_list):
