@@ -1,20 +1,19 @@
 from textwrap import dedent
 from unittest import TestCase
 
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import cluster
 from pcs.lib.corosync.constants import (
     TOTEM_OPTIONS,
-    TRANSPORT_KNET_CRYPTO_OPTIONS,
     TRANSPORT_KNET_COMPRESSION_OPTIONS,
+    TRANSPORT_KNET_CRYPTO_OPTIONS,
     TRANSPORT_KNET_GENERIC_OPTIONS,
 )
 
-from .common import fixture_totem
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
 
+from .common import fixture_totem
 
 ALLOWED_COMPRESSION_OPTIONS = list(TRANSPORT_KNET_COMPRESSION_OPTIONS)
 ALLOWED_CRYPTO_OPTIONS = list(TRANSPORT_KNET_CRYPTO_OPTIONS)
@@ -28,7 +27,10 @@ TRANSPORT_OPTIONS = {
 }
 COMPRESSION_OPTIONS = {"level": "5", "model": "zlib", "threshold": "1234"}
 CRYPTO_OPTIONS = {"cipher": "aes256", "hash": "sha256", "model": "nss"}
-TOTEM_OPTIONS = {opt: str(num) for num, opt in enumerate(ALLOWED_TOTEM_OPTIONS)}
+TOTEM_OPTIONS = {
+    opt: ("yes" if opt == "block_unlisted_ips" else str(num))
+    for num, opt in enumerate(ALLOWED_TOTEM_OPTIONS)
+}
 
 
 class CheckLiveMixin:
@@ -131,7 +133,8 @@ class UpdateConfig(TestCase):
             "model": "openssl",
         }
         modified_totem_options = {
-            opt: val + "0" for opt, val in TOTEM_OPTIONS.items()
+            opt: ("no" if opt == "block_unlisted_ips" else val + "0")
+            for opt, val in TOTEM_OPTIONS.items()
         }
         self.config.env.push_corosync_conf(
             corosync_conf_text=fixture_totem(
@@ -410,6 +413,7 @@ class UpdateConfigLocal(TestCase):
 
     def test_add_modify_remove_options(self):
         before = fixture_totem(
+            cluster_uuid=None,
             transport_options={
                 "ip_version": "ipv4",
                 "knet_pmtud_interval": "10",
