@@ -1,25 +1,35 @@
-# pylint: disable=no-member
 from functools import partial
-from unittest import mock, TestCase
-
-from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
-    EnvConfigMixin,
-    REPORTS as FIXTURE_REPORTS,
-    EXTRA_REPORTS as FIXTURE_EXTRA_REPORTS,
-    FAIL_HTTP_KWARGS,
-    fixture_reports_not_live_cib,
-    fixture_reports_new_node_unreachable,
+from unittest import (
+    TestCase,
+    mock,
 )
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import get_test_resource as rc
 
 from pcs import settings
-from pcs.common import file_type_codes, reports
+from pcs.common import (
+    file_type_codes,
+    reports,
+)
 from pcs.common.file import RawFileError
 from pcs.common.host import Destination
 from pcs.lib.commands.remote_node import node_add_remote as node_add_remote_orig
 
+from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
+    EXTRA_REPORTS as FIXTURE_EXTRA_REPORTS,
+)
+from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
+    FAIL_HTTP_KWARGS,
+)
+from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
+    REPORTS as FIXTURE_REPORTS,
+)
+from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
+    EnvConfigMixin,
+    fixture_reports_new_node_unreachable,
+    fixture_reports_not_live_cib,
+)
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import get_test_resource as rc
 
 NODE_NAME = "node-name"
 NODE_ADDR_PCSD = "node-addr"
@@ -64,11 +74,9 @@ def node_add_remote(
 
 class LocalConfig(EnvConfigMixin):
     def load_cluster_configs(self, cluster_node_list):
-        (
-            self.config.runner.cib.load()
-            .corosync_conf.load(node_name_list=cluster_node_list)
-            .runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
-        )
+        self.config.runner.cib.load()
+        self.config.corosync_conf.load(node_name_list=cluster_node_list)
+        self.config.runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
 
 
 get_env_tools = partial(get_env_tools, local_extensions={"local": LocalConfig})
@@ -84,8 +92,6 @@ EXTRA_REPORTS = FIXTURE_EXTRA_REPORTS.adapt_multi(
     [
         "manage_services_connection_failed",
         "manage_services_connection_failed_warn",
-        "check_availability_connection_failed",
-        "check_availability_connection_failed_warn",
         "put_file_connection_failed",
         "put_file_connection_failed_warn",
         "pcmk_remote_enable_failed",
@@ -112,22 +118,22 @@ FIXTURE_RESOURCES_TEMPLATE = """
             </instance_attributes>
             <operations>
                 <op id="node-name-migrate_from-interval-0s"
-                    interval="0s" name="migrate_from" timeout="60"
+                    interval="0s" name="migrate_from" timeout="60s"
                 />
                 <op id="node-name-migrate_to-interval-0s"
-                    interval="0s" name="migrate_to" timeout="60"
+                    interval="0s" name="migrate_to" timeout="60s"
                 />
                 <op id="node-name-monitor-interval-60s"
-                    interval="60s" name="monitor" timeout="30" {onfail}
+                    interval="60s" name="monitor" timeout="30s" {onfail}
                 />
                 <op id="node-name-reload-interval-0s"
-                  interval="0s" name="reload" timeout="60"
+                  interval="0s" name="reload" timeout="60s"
                 />
                 <op id="node-name-start-interval-0s"
-                    interval="0s" name="start" timeout="60"
+                    interval="0s" name="start" timeout="60s"
                 />
                 <op id="node-name-stop-interval-0s"
-                    interval="0s" name="stop" timeout="60"
+                    interval="0s" name="stop" timeout="60s"
                 />
             </operations>
         </primitive>
@@ -144,6 +150,8 @@ class AddRemote(TestCase):
         self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
 
     def _config_success_base(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         (
             self.config.local.load_cluster_configs(
                 cluster_node_list=[NODE_1, NODE_2]
@@ -165,24 +173,27 @@ class AddRemote(TestCase):
         self.env_assist.assert_reports(REPORTS)
 
     def test_success_base_addr_same_as_name(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
+
         # validation and creation of resource is covered in resource create
         # tests
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
-            .local.push_existing_authkey_to_remote(NODE_NAME, NODE_DEST_LIST)
-            .local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
-            .env.push_cib(
-                resources=FIXTURE_RESOURCES_TEMPLATE.format(
-                    server=NODE_NAME, onfail=""
-                )
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
+        )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.local.push_existing_authkey_to_remote(
+            NODE_NAME, NODE_DEST_LIST
+        )
+        self.config.local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.push_cib(
+            resources=FIXTURE_RESOURCES_TEMPLATE.format(
+                server=NODE_NAME, onfail=""
             )
         )
         node_add_remote(self.env_assist.get_env(), node_addr=NODE_NAME)
@@ -211,7 +222,7 @@ class AddRemote(TestCase):
             operations=[
                 {
                     "name": "monitor",
-                    "timeout": "30",
+                    "timeout": "30s",
                     "interval": "60s",
                     "on-fail": "demote",
                 }
@@ -252,6 +263,8 @@ class AddRemote(TestCase):
 
     @mock.patch("pcs.lib.commands.remote_node.generate_binary_key")
     def test_success_generated_authkey(self, generate_binary_key):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         generate_binary_key.return_value = b"password"
         (
             self.config.local.load_cluster_configs(
@@ -295,6 +308,8 @@ class AddRemote(TestCase):
         )
 
     def test_new_offline(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         (
             self.config.local.load_cluster_configs(
                 cluster_node_list=[NODE_1, NODE_2]
@@ -324,6 +339,8 @@ class AddRemote(TestCase):
         )
 
     def test_can_skip_new_offline(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         pcmk_authkey_content = b"password"
         (
             self.config.local.load_cluster_configs(
@@ -349,6 +366,8 @@ class AddRemote(TestCase):
 
     @mock.patch("pcs.lib.commands.remote_node.generate_binary_key")
     def test_can_skip_all_offline(self, generate_binary_key):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         generate_binary_key.return_value = b"password"
         (
             self.config.local.load_cluster_configs(
@@ -399,6 +418,8 @@ class AddRemote(TestCase):
         )
 
     def test_fails_when_remote_node_is_not_prepared(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         (
             self.config.local.load_cluster_configs(
                 cluster_node_list=[NODE_1, NODE_2]
@@ -450,6 +471,8 @@ class AddRemote(TestCase):
         )
 
     def test_fails_when_remote_node_returns_invalid_output(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         (
             self.config.local.load_cluster_configs(
                 cluster_node_list=[NODE_1, NODE_2]
@@ -476,6 +499,8 @@ class AddRemote(TestCase):
         )
 
     def test_open_failed(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         (
             self.config.local.load_cluster_configs(
                 cluster_node_list=[NODE_1, NODE_2]
@@ -500,7 +525,7 @@ class AddRemote(TestCase):
                 fixture.error(
                     reports.codes.FILE_IO_ERROR,
                     file_type_code=file_type_codes.PACEMAKER_AUTHKEY,
-                    file_path=LocalConfig.PCMK_AUTHKEY_PATH,
+                    file_path=settings.pacemaker_authkey_file,
                     operation=RawFileError.ACTION_READ,
                     reason="open failed",
                 )
@@ -508,10 +533,10 @@ class AddRemote(TestCase):
         )
 
     def test_validate_addr_already_exists(self):
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
         # more validation tests in pcs/lib/cib/test/test_resource_remote_node.py
         self.env_assist.assert_raise_library_error(
@@ -526,16 +551,16 @@ class AddRemote(TestCase):
         )
 
     def test_unknown_host(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         self.config.env.set_known_hosts_dests(
             {
                 NODE_1: NODE_1_DEST_LIST,
                 NODE_2: NODE_2_DEST_LIST,
             }
         )
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env()), []
@@ -551,6 +576,8 @@ class AddRemote(TestCase):
         )
 
     def test_unknown_host_skip_offline(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         pcmk_authkey_content = b"password"
         self.config.env.set_known_hosts_dests(
             {
@@ -575,6 +602,8 @@ class AddRemote(TestCase):
     def test_unknown_host_skip_offline_authkey_distribution(
         self, generate_binary_key
     ):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         generate_binary_key.return_value = b"password"
         self.config.env.set_known_hosts_dests(
             {
@@ -659,29 +688,34 @@ class AddRemote(TestCase):
 
 
 class NotLive(TestCase):
+    # pylint: disable=no-member
     def setUp(self):
+        self.tmp_file = "/fake/tmp_file"
+        self.cmd_env = dict(CIB_file=self.tmp_file)
         self.env_assist, self.config = get_env_tools(self)
         self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
         with open(rc("cib-empty.xml")) as cib_file:
-            self.config.env.set_cib_data(cib_file.read())
+            self.config.env.set_cib_data(
+                cib_file.read(), cib_tempfile=self.tmp_file
+            )
 
     def test_addr_specified(self):
-        (
-            self.config.runner.cib.load()
-            .runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.runner.cib.load(env=self.cmd_env)
+        self.config.runner.pcmk.load_agent(
+            agent_name="ocf:pacemaker:remote", env=self.cmd_env
         )
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
         node_add_remote(self.env_assist.get_env())
         self.env_assist.assert_reports(fixture_reports_not_live_cib(NODE_NAME))
 
     def test_addr_not_specified(self):
-        (
-            self.config.runner.cib.load()
-            .runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
-            .env.push_cib(
-                resources=FIXTURE_RESOURCES_TEMPLATE.format(
-                    server=NODE_ADDR_PCSD, onfail=""
-                )
+        self.config.runner.cib.load(env=self.cmd_env)
+        self.config.runner.pcmk.load_agent(
+            agent_name="ocf:pacemaker:remote", env=self.cmd_env
+        )
+        self.config.env.push_cib(
+            resources=FIXTURE_RESOURCES_TEMPLATE.format(
+                server=NODE_ADDR_PCSD, onfail=""
             )
         )
         node_add_remote(self.env_assist.get_env(), no_node_addr=True)
@@ -700,15 +734,15 @@ class NotLive(TestCase):
         )
 
     def test_unknown_host_addr_not_specified(self):
-        self.config.env.set_known_hosts_dests(dict())
-        (
-            self.config.runner.cib.load()
-            .runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
-            .env.push_cib(
-                resources=FIXTURE_RESOURCES_TEMPLATE.format(
-                    server=NODE_NAME, onfail=""
-                )
-            )
+        self.config.env.set_known_hosts_dests({})
+        self.config.runner.cib.load(env=self.cmd_env)
+        self.config.runner.pcmk.load_agent(
+            agent_name="ocf:pacemaker:remote", env=self.cmd_env
+        )
+        self.config.env.push_cib(
+            resources=FIXTURE_RESOURCES_TEMPLATE.format(
+                server=NODE_NAME, onfail=""
+            ),
         )
         node_add_remote(self.env_assist.get_env(), no_node_addr=True)
         self.env_assist.assert_reports(
@@ -726,17 +760,18 @@ class NotLive(TestCase):
         )
 
     def test_unknown_host_addr_specified(self):
-        self.config.env.set_known_hosts_dests(dict())
-        (
-            self.config.runner.cib.load()
-            .runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
-            .env.push_cib(
-                resources=FIXTURE_RESOURCES_TEMPLATE.format(
-                    server="addr", onfail=""
-                )
+        self.config.env.set_known_hosts_dests({})
+        server_value = "addr"
+        self.config.runner.cib.load(env=self.cmd_env)
+        self.config.runner.pcmk.load_agent(
+            agent_name="ocf:pacemaker:remote", env=self.cmd_env
+        )
+        self.config.env.push_cib(
+            resources=FIXTURE_RESOURCES_TEMPLATE.format(
+                server=server_value, onfail=""
             )
         )
-        node_add_remote(self.env_assist.get_env(), node_addr="addr")
+        node_add_remote(self.env_assist.get_env(), node_addr=server_value)
         self.env_assist.assert_reports(fixture_reports_not_live_cib(NODE_NAME))
 
     def test_wait(self):
@@ -751,6 +786,9 @@ class NotLive(TestCase):
         )
 
 
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class WithWait(TestCase):
     def setUp(self):
         self.wait = 1
@@ -770,21 +808,17 @@ class WithWait(TestCase):
         )
 
     def test_success_when_resource_started(self):
-        (
-            self.config.runner.pcmk.load_state(
-                raw_resources=dict(
-                    resource_id=NODE_NAME,
-                    resource_agent="ocf::pacemaker:remote",
-                    node_name=NODE_1,
-                )
-            )
-            # self.config.fs is used to mock authkey file existence. Therefore,
-            # filesystem mocking is active and we need to cover it. We tell the
-            # file doesn't exist, because we aren't currently mocking the
-            # function which reads it:
-            #   if os.path.isfile(settings.crm_mon_schema):
-            #       etree.RelaxNG(file=settings.crm_mon_schema).assertValid(dom)
-            .fs.isfile(settings.crm_mon_schema, return_value=False)
+        self.config.runner.pcmk.load_state(
+            resources=f"""
+                <resources>
+                    <resource
+                        id="{NODE_NAME}"
+                        resource_agent="ocf::pacemaker:remote"
+                    >
+                        <node name="{NODE_1}" id="1" cached="false"/>
+                    </resource>
+                </resources>
+            """
         )
         node_add_remote(self.env_assist.get_env(), wait=self.wait)
         self.env_assist.assert_reports(
@@ -797,22 +831,18 @@ class WithWait(TestCase):
         )
 
     def test_fail_when_resource_not_started(self):
-        (
-            self.config.runner.pcmk.load_state(
-                raw_resources=dict(
-                    resource_id=NODE_NAME,
-                    resource_agent="ocf::pacemaker:remote",
-                    node_name=NODE_1,
-                    failed="true",
-                )
-            )
-            # self.config.fs is used to mock authkey file existence. Therefore,
-            # filesystem mocking is active and we need to cover it. We tell the
-            # file doesn't exist, because we aren't currently mocking the
-            # function which reads it:
-            #   if os.path.isfile(settings.crm_mon_schema):
-            #       etree.RelaxNG(file=settings.crm_mon_schema).assertValid(dom)
-            .fs.isfile(settings.crm_mon_schema, return_value=False)
+        self.config.runner.pcmk.load_state(
+            resources=f"""
+                <resources>
+                    <resource
+                        id="{NODE_NAME}"
+                        resource_agent="ocf::pacemaker:remote"
+                        failed="true"
+                    >
+                        <node name="{NODE_1}" id="1" cached="false"/>
+                    </resource>
+                </resources>
+            """
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env(), wait=self.wait)
@@ -844,10 +874,10 @@ class AddRemotePcmkRemoteService(TestCase):
         )
 
     def test_fails_when_offline(self):
-        (
-            self.config.local.run_pacemaker_remote(
-                NODE_NAME, NODE_DEST_LIST, **FAIL_HTTP_KWARGS
-            )
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
+        self.config.local.run_pacemaker_remote(
+            NODE_NAME, NODE_DEST_LIST, **FAIL_HTTP_KWARGS
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env())
@@ -859,15 +889,15 @@ class AddRemotePcmkRemoteService(TestCase):
         )
 
     def test_fail_when_remotely_fail(self):
-        (
-            self.config.local.run_pacemaker_remote(
-                NODE_NAME,
-                NODE_DEST_LIST,
-                result={
-                    "code": "fail",
-                    "message": "Action failed",
-                },
-            )
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
+        self.config.local.run_pacemaker_remote(
+            NODE_NAME,
+            NODE_DEST_LIST,
+            result={
+                "code": "fail",
+                "message": "Action failed",
+            },
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env())
@@ -881,16 +911,16 @@ class AddRemotePcmkRemoteService(TestCase):
         )
 
     def test_forceable_when_remotely_fail(self):
-        (
-            self.config.local.run_pacemaker_remote(
-                NODE_NAME,
-                NODE_DEST_LIST,
-                result={
-                    "code": "fail",
-                    "message": "Action failed",
-                },
-            ).env.push_cib(resources=FIXTURE_RESOURCES)
-        )
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
+        self.config.local.run_pacemaker_remote(
+            NODE_NAME,
+            NODE_DEST_LIST,
+            result={
+                "code": "fail",
+                "message": "Action failed",
+            },
+        ).env.push_cib(resources=FIXTURE_RESOURCES)
         node_add_remote(
             self.env_assist.get_env(), allow_pacemaker_remote_service_fail=True
         )
@@ -919,6 +949,8 @@ class AddRemoteAuthkeyDistribution(TestCase):
         )
 
     def test_fails_when_offline(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         pcmk_authkey_content = b"password"
         (
             self.config.local.authkey_exists(return_value=True)
@@ -943,15 +975,15 @@ class AddRemoteAuthkeyDistribution(TestCase):
         )
 
     def test_fail_when_remotely_fail(self):
-        (
-            self.config.local.push_existing_authkey_to_remote(
-                NODE_NAME,
-                NODE_DEST_LIST,
-                distribution_result={
-                    "code": "conflict",
-                    "message": "",
-                },
-            )
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
+        self.config.local.push_existing_authkey_to_remote(
+            NODE_NAME,
+            NODE_DEST_LIST,
+            distribution_result={
+                "code": "conflict",
+                "message": "",
+            },
         )
 
         self.env_assist.assert_raise_library_error(
@@ -964,6 +996,8 @@ class AddRemoteAuthkeyDistribution(TestCase):
         )
 
     def test_forceable_when_remotely_fail(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         (
             self.config.local.push_existing_authkey_to_remote(
                 NODE_NAME,
