@@ -1,22 +1,22 @@
 from unittest import TestCase
 
-from pcs_test.tier0.lib.commands.resource.bundle_common import (
-    FixturesMixin,
-    SetUpMixin,
-    ParametrizedContainerMixin,
-    NetworkMixin,
-    PortMapMixin,
-    StorageMapMixin,
-    MetaMixin,
-    AllOptionsMixin,
-    WaitMixin,
-)
-from pcs_test.tools import fixture
-
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands.resource import bundle_reset
 
+from pcs_test.tier0.lib.commands.resource.bundle_common import (
+    AllOptionsMixin,
+    FixturesMixin,
+    MetaMixin,
+    NetworkMixin,
+    ParametrizedContainerMixin,
+    PortMapMixin,
+    SetUpMixin,
+    StorageMapMixin,
+    WaitMixin,
+)
+from pcs_test.tools import fixture
+
 
 class BaseMixin(FixturesMixin):
     container_type = None
@@ -404,7 +404,7 @@ class ResetWithMetaMap(BaseMixin, MetaMixin, TestCase):
 
     def test_success(self):
         # When there is no meta attributes the new one are put on the first
-        # possition (since reset now uses update internally). This is the reason
+        # position (since reset now uses update internally). This is the reason
         # for reimplementation of this MetaMixin test.
         self.config.env.push_cib(
             resources="""
@@ -454,6 +454,7 @@ class ResetUnknownContainerType(BaseMixin, SetUpMixin, TestCase):
                     report_codes.RESOURCE_BUNDLE_UNSUPPORTED_CONTAINER_TYPE,
                     bundle_id="B1",
                     supported_container_types=["docker", "podman", "rkt"],
+                    updating_options=True,
                 ),
             ]
         )
