@@ -1,20 +1,20 @@
-from functools import partial
 import logging
-from unittest import mock, TestCase
-
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
+from functools import partial
+from unittest import (
+    TestCase,
+    mock,
+)
 
+import pcs.lib.commands.alert as cmd_alert
 from pcs.common.reports import ReportItemSeverity as Severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.env import LibraryEnvironment
 
-import pcs.lib.commands.alert as cmd_alert
-
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
 get_env_tools = partial(
     get_env_tools,
-    base_cib_filename="cib-empty-2.5.xml",
     exception_reports_in_processor_by_default=False,
 )
 
@@ -79,34 +79,6 @@ class CreateAlertTest(TestCase):
             "my description",
         )
 
-    def test_create_upgrade(self):
-        (
-            self.config.runner.cib.load(
-                filename="cib-empty-2.0.xml", name="load_cib_old_version"
-            )
-            .runner.cib.upgrade()
-            .runner.cib.load()
-            .env.push_cib(optional_in_conf=self.fixture_final_alerts)
-        )
-        cmd_alert.create_alert(
-            self.env_assist.get_env(),
-            "my-alert",
-            "/my/path",
-            {"instance": "value", "another": "val"},
-            {"meta1": "val1"},
-            "my description",
-        )
-        self.env_assist.assert_reports(
-            [
-                (
-                    Severities.INFO,
-                    report_codes.CIB_UPGRADE_SUCCESSFUL,
-                    {},
-                    None,
-                ),
-            ]
-        )
-
 
 class UpdateAlertTest(TestCase):
     fixture_initial_alerts = """
