@@ -1,25 +1,33 @@
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
+
 from lxml import etree
 
+from pcs.common import const
+from pcs.common.reports import ReportItemSeverity as severities
+from pcs.common.reports import codes as report_codes
+from pcs.lib.commands.constraint import common as constraint
+
+from pcs_test.tools import fixture
 from pcs_test.tools.assertions import (
     assert_raise_library_error,
     assert_xml_equal,
 )
 from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
-from pcs.common.reports import ReportItemSeverity as severities
-from pcs.common.reports import codes as report_codes
-from pcs.lib.commands.constraint import common as constraint
-
 
 def fixture_cib_and_constraints():
-    cib = etree.Element("cib")
-    resources_section = etree.SubElement(cib, "resources")
+    cib = etree.Element(
+        "cib",
+        {"validate-with": f"pacemaker-{const.PCMK_NEW_ROLES_CIB_VERSION}"},
+    )
+    config_section = etree.SubElement(cib, "configuration")
+    resources_section = etree.SubElement(config_section, "resources")
     for _id in ("A", "B", "E", "F"):
         etree.SubElement(resources_section, "primitive").attrib["id"] = _id
-    constraint_section = etree.SubElement(
-        etree.SubElement(cib, "configuration"), "constraints"
-    )
+    constraint_section = etree.SubElement(config_section, "constraints")
     return cib, constraint_section
 
 
@@ -36,19 +44,20 @@ class CreateWithSetTest(TestCase):
     def setUp(self):
         self.cib, self.constraint_section = fixture_cib_and_constraints()
         self.env = fixture_env(self.cib)
+        self.role = const.PCMK_ROLE_PROMOTED_LEGACY
         self.independent_cib = etree.XML(etree.tostring(self.cib))
 
-    def create(self, duplication_alowed=False):
+    def create(self, duplication_allowed=False):
         constraint.create_with_set(
             "rsc_some",
             lambda cib, options, resource_set_list: options,
             self.env,
             [
-                {"ids": ["A", "B"], "options": {"role": "Master"}},
+                {"ids": ["A", "B"], "options": {"role": self.role}},
                 {"ids": ["E", "F"], "options": {"action": "start"}},
             ],
             {"id": "some_id", "symmetrical": "true"},
-            duplication_alowed=duplication_alowed,
+            duplication_alowed=duplication_allowed,
         )
 
     def test_put_new_constraint_to_constraint_section(self):
@@ -56,9 +65,9 @@ class CreateWithSetTest(TestCase):
         self.env.push_cib.assert_called_once_with()
         self.independent_cib.find(".//constraints").append(
             etree.XML(
-                """
+                f"""
             <rsc_some id="some_id" symmetrical="true">
-                  <resource_set id="some_id_set" role="Master">
+                  <resource_set id="some_id_set" role="{const.PCMK_ROLE_PROMOTED_PRIMARY}">
                       <resource_ref id="A"></resource_ref>
                       <resource_ref id="B"></resource_ref>
                   </resource_set>
@@ -74,6 +83,16 @@ class CreateWithSetTest(TestCase):
             etree.tostring(self.independent_cib).decode(),
             etree.tostring(self.cib).decode(),
         )
+        self.env.report_processor.assert_reports(
+            [
+                fixture.deprecation(
+                    report_codes.DEPRECATED_OPTION_VALUE,
+                    option_name="role",
+                    deprecated_value=self.role,
+                    replaced_by=const.PCMK_ROLE_PROMOTED,
+                )
+            ]
+        )
 
     def test_refuse_duplicate(self):
         self.create()
@@ -87,7 +106,7 @@ class CreateWithSetTest(TestCase):
                     {
                         "constraint_ids": ["some_id"],
                     },
-                    report_codes.FORCE_CONSTRAINT_DUPLICATE,
+                    report_codes.FORCE,
                 ),
                 (
                     severities.INFO,
@@ -104,7 +123,7 @@ class CreateWithSetTest(TestCase):
                                     {
                                         "ids": ["A", "B"],
                                         "options": {
-                                            "role": "Master",
+                                            "role": const.PCMK_ROLE_PROMOTED_PRIMARY,
                                             "id": "some_id_set",
                                         },
                                     },
@@ -121,11 +140,20 @@ class CreateWithSetTest(TestCase):
                     },
                 ),
             ]
+            + [
+                fixture.deprecation(
+                    report_codes.DEPRECATED_OPTION_VALUE,
+                    option_name="role",
+                    deprecated_value=self.role,
+                    replaced_by=const.PCMK_ROLE_PROMOTED,
+                )
+                for _ in range(2)
+            ]
         )
 
     def test_put_duplicate_constraint_when_duplication_allowed(self):
         self.create()
-        self.create(duplication_alowed=True)
+        self.create(duplication_allowed=True)
         expected_calls = [
             mock.call(),
             mock.call(),
@@ -136,9 +164,9 @@ class CreateWithSetTest(TestCase):
         constraint_section = self.independent_cib.find(".//constraints")
         constraint_section.append(
             etree.XML(
-                """
+                f"""
             <rsc_some id="some_id" symmetrical="true">
-                <resource_set id="some_id_set" role="Master">
+                <resource_set id="some_id_set" role="{const.PCMK_ROLE_PROMOTED_PRIMARY}">
                     <resource_ref id="A"></resource_ref>
                     <resource_ref id="B"></resource_ref>
                 </resource_set>
@@ -152,9 +180,9 @@ class CreateWithSetTest(TestCase):
         )
         constraint_section.append(
             etree.XML(
-                """
+                f"""
             <rsc_some id="some_id" symmetrical="true">
-                <resource_set id="some_id_set-2" role="Master">
+                <resource_set id="some_id_set-2" role="{const.PCMK_ROLE_PROMOTED_PRIMARY}">
                     <resource_ref id="A"></resource_ref>
                     <resource_ref id="B"></resource_ref>
                 </resource_set>
@@ -172,7 +200,7 @@ class CreateWithSetTest(TestCase):
         )
 
 
-class ShowTest(TestCase):
+class ConfigTest(TestCase):
     def setUp(self):
         self.cib, self.constraint_section = fixture_cib_and_constraints()
         self.env = fixture_env(self.cib)
@@ -187,11 +215,17 @@ class ShowTest(TestCase):
         )
 
     def test_returns_export_of_found_elements(self):
+        def is_plain(element):
+            return element.attrib.has_key("is_plain")
+
         tag_name = "rsc_some"
         self.create(
             tag_name,
             [
-                {"ids": ["A", "B"], "options": {"role": "Master"}},
+                {
+                    "ids": ["A", "B"],
+                    "options": {"role": const.PCMK_ROLE_UNPROMOTED_LEGACY},
+                },
             ],
         )
         self.create(
@@ -204,10 +238,8 @@ class ShowTest(TestCase):
             {"id": "plain1", "is_plain": "true"}
         )
 
-        is_plain = lambda element: element.attrib.has_key("is_plain")
-
         self.assertEqual(
-            constraint.show(tag_name, is_plain, self.env),
+            constraint.config(tag_name, is_plain, self.env),
             {
                 "plain": [{"options": {"id": "plain1", "is_plain": "true"}}],
                 "with_resource_sets": [
@@ -216,7 +248,7 @@ class ShowTest(TestCase):
                             {
                                 "ids": ["A", "B"],
                                 "options": {
-                                    "role": "Master",
+                                    "role": const.PCMK_ROLE_UNPROMOTED_PRIMARY,
                                     "id": "some_id_set",
                                 },
                             }
