@@ -1,17 +1,69 @@
+import os
 from textwrap import dedent
-from unittest import TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs import settings
 from pcs.common import file_type_codes
 from pcs.common.reports import codes as report_codes
+from pcs.lib.booth import constants
 from pcs.lib.commands import status
-from pcs_test.tools import fixture
+from pcs.lib.errors import LibraryError
+
+from pcs_test.tools import (
+    fixture,
+    fixture_crm_mon,
+)
+from pcs_test.tools.assertions import assert_xml_equal
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.misc import read_test_resource as rc_read
 
 
-class FullClusterStatusPlaintext(TestCase):
-    # pylint: disable=too-many-public-methods
+def _booth_config_path_fixture(instance_name="booth"):
+    return os.path.join(settings.booth_config_dir, f"{instance_name}.conf")
+
+
+class PacemakerStatusXml(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(self)
+
+    def test_success(self):
+        self.config.runner.pcmk.load_state(filename="crm_mon.minimal.xml")
+        assert_xml_equal(
+            status.pacemaker_status_xml(self.env_assist.get_env()),
+            rc_read("crm_mon.minimal.xml"),
+        )
+
+    def test_not_xml(self):
+        # Loading pacemaker state succeeded, we expect to get an xml and we
+        # just return it. If it is not a valid xml, it is a bug in pacemaker.
+        self.config.runner.pcmk.load_state(stdout="not an xml")
+        self.assertEqual(
+            status.pacemaker_status_xml(self.env_assist.get_env()), "not an xml"
+        )
+
+    def test_error(self):
+        error_xml = fixture_crm_mon.error_xml(
+            1, "an error", ["This is an error message", "And one more"]
+        )
+        self.config.runner.pcmk.load_state(stdout=error_xml, returncode=1)
+        with self.assertRaises(LibraryError) as cm:
+            status.pacemaker_status_xml(self.env_assist.get_env())
+        assert_xml_equal(cm.exception.output, error_xml)
+
+    def test_error_not_xml(self):
+        # Loading pacemaker state failed, but we expect to get an xml anyway
+        # and we return it. If it is not a valid xml, it is a bug or a critical
+        # error in pacemaker we can do nothing about.
+        self.config.runner.pcmk.load_state(stdout="an error", returncode=1)
+        with self.assertRaises(LibraryError) as cm:
+            status.pacemaker_status_xml(self.env_assist.get_env())
+        self.assertEqual(cm.exception.output, "an error")
+
+
+class FullClusterStatusPlaintextBase(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.node_name_list = ["node1", "node2", "node3"]
@@ -137,6 +189,11 @@ class FullClusterStatusPlaintext(TestCase):
             )
         )
 
+
+@mock.patch("pcs.settings.booth_enable_authfile_set_enabled", False)
+@mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", False)
+class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
+    # pylint: disable=too-many-public-methods
     def test_life_cib_mocked_corosync(self):
         self.config.env.set_corosync_conf_data("corosync conf data")
         self.env_assist.assert_raise_library_error(
@@ -382,7 +439,7 @@ class FullClusterStatusPlaintext(TestCase):
             ),
         )
 
-    def test_succes_mocked(self):
+    def test_success_mocked(self):
         tmp_file = "/fake/tmp_file"
         env = dict(CIB_file=tmp_file)
         (
@@ -410,7 +467,7 @@ class FullClusterStatusPlaintext(TestCase):
             ),
         )
 
-    def test_succes_mocked_verbose(self):
+    def test_success_mocked_verbose(self):
         tmp_file = "/fake/tmp_file"
         env = dict(CIB_file=tmp_file)
         (
@@ -823,3 +880,216 @@ class FullClusterStatusPlaintext(TestCase):
                   pcsd: inactive/disabled"""
             ),
         )
+
+    def test_move_constrains_warnings(self):
+        self.config.runner.pcmk.load_state_plaintext(
+            stdout="crm_mon cluster status",
+        )
+        self.config.fs.exists(settings.corosync_conf_file, return_value=True)
+        self.config.corosync_conf.load()
+        self.config.runner.cib.load(
+            constraints="""
+            <constraints>
+                <rsc_location id="cli-ban-P1-on-node1" rsc="P1"
+                    role="Started" node="node1" score="-INFINITY"/>
+                <rsc_location id="cli-prefer-P1" rsc="P1" role="Started"
+                    node="node3" score="INFINITY"/>
+                <rsc_location id="cli-prefer-P2" rsc="P2" role="Started"
+                    node="node1" score="INFINITY"/>
+                <rsc_location id="cli-ban-P2-on-node1" rsc="P2"
+                    role="Started" node="node1" score="-INFINITY"/>
+                <rsc_location id="location-P3-node3--INFINITY" rsc="P3"
+                    node="node3" score="-INFINITY"/>
+            </constraints>
+        """,
+            resources="""
+            <resources>
+                <primitive class="ocf" id="P1" provider="pacemaker"
+                    type="Dummy"/>
+                <primitive class="ocf" id="P2" provider="pacemaker"
+                    type="Dummy"/>
+                <primitive class="ocf" id="P3" provider="pacemaker"
+                    type="Dummy"/>
+            </resources>
+        """,
+        )
+        self.config.services.is_running(
+            "sbd", return_value=True, name="services.is_running.sbd"
+        )
+        self._fixture_config_local_daemons(sbd_enabled=True, sbd_active=True)
+
+        self.assertEqual(
+            # pylint: disable=line-too-long
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
+                Cluster name: test99
+
+                WARNINGS:
+                Following resources have been moved and their move constraints are still in place: 'P1', 'P2'
+                Run 'pcs constraint location' or 'pcs resource clear <resource id>' to view or remove the constraints, respectively
+
+                crm_mon cluster status
+
+                Daemon Status:
+                  corosync: active/enabled
+                  pacemaker: active/enabled
+                  pcsd: active/enabled
+                  sbd: active/enabled"""
+            ),
+        )
+
+
+class FullClusterStatusPlaintextBoothWarning(FullClusterStatusPlaintextBase):
+    # pylint: disable=too-many-public-methods
+    def setUp(self):
+        super().setUp()
+        self._fixture_config_live_minimal()
+        self._fixture_config_local_daemons()
+
+    def _assert_status_output(self, warning=None):
+        warning_str = ""
+        if warning:
+            warning_str = f"\n\nWARNINGS:\n{warning}\n"
+        self.assertEqual(
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
+                Cluster name: test99{warning_str}
+                crm_mon cluster status
+
+                Daemon Status:
+                  corosync: active/enabled
+                  pacemaker: active/enabled
+                  pcsd: active/enabled"""
+            ).format(warning_str=warning_str),
+        )
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", True)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", False)
+    def test_booth_not_configured_set_enabled(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=False,
+        )
+        self._assert_status_output()
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", True)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", False)
+    def test_booth_authfile_not_configured_set_enabled(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=True,
+        )
+        self.config.raw_file.read(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            content=dedent(
+                """
+                site = 1.1.1.1
+                """
+            ).encode("utf-8"),
+        )
+        self._assert_status_output()
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", False)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", True)
+    def test_booth_not_configured_unset_enabled(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=False,
+        )
+        self._assert_status_output()
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", True)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", False)
+    def test_missing_option(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=True,
+        )
+        self.config.raw_file.read(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            content=dedent(
+                f"""
+                authfile = {_booth_config_path_fixture()}
+                site = 1.1.1.1
+                """
+            ).encode("utf-8"),
+        )
+        self._assert_status_output(
+            "Booth is configured to use an authfile, but authfile is not "
+            "enabled. Run 'pcs booth enable-authfile --name booth' to enable "
+            "usage of booth autfile."
+        )
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", True)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", False)
+    def test_properly_configured(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=True,
+        )
+        self.config.raw_file.read(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            content=dedent(
+                f"""
+                authfile = {_booth_config_path_fixture()}
+                {constants.AUTHFILE_FIX_OPTION} = yes
+                site = 1.1.1.1
+                """
+            ).encode("utf-8"),
+        )
+        self._assert_status_output()
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", False)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", True)
+    def test_unsupported_option(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=True,
+        )
+        self.config.raw_file.read(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            content=dedent(
+                f"""
+                authfile = {_booth_config_path_fixture()}
+                {constants.AUTHFILE_FIX_OPTION} = yes
+                site = 1.1.1.1
+                """
+            ).encode("utf-8"),
+        )
+        self._assert_status_output(
+            "Unsupported option 'enable-authfile' is set in booth "
+            "configuration. Run 'pcs booth enable-booth-clean --name booth' to "
+            "remove the option."
+        )
+
+    @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", False)
+    @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", True)
+    def test_unsupported_option_not_present(self):
+        self.config.raw_file.exists(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            exists=True,
+        )
+        self.config.raw_file.read(
+            file_type_codes.BOOTH_CONFIG,
+            _booth_config_path_fixture(),
+            content=dedent(
+                f"""
+                authfile = {_booth_config_path_fixture()}
+                site = 1.1.1.1
+                """
+            ).encode("utf-8"),
+        )
+        self._assert_status_output()
