@@ -1,14 +1,19 @@
 # pylint: disable=too-many-lines
 from unittest import TestCase
 
+from pcs.common.corosync_conf import CorosyncNodeAddressType
+from pcs.common.reports import codes as report_codes
+from pcs.lib.cib.node import PacemakerNode
+from pcs.lib.corosync import (
+    config_validators,
+    constants,
+    node,
+)
+
 from pcs_test.tools import fixture
 from pcs_test.tools.assertions import assert_report_item_list_equal
 from pcs_test.tools.custom_mock import patch_getaddrinfo
 
-from pcs.common.reports import codes as report_codes
-from pcs.lib.cib.node import PacemakerNode
-from pcs.lib.corosync import config_validators, constants, node
-
 forbidden_characters_kwargs = dict(
     allowed_values=None,
     cannot_be_empty=False,
@@ -374,7 +379,7 @@ class AddLink(TestCase):
             [
                 fixture.error(
                     report_codes.NODE_ADDRESSES_UNRESOLVABLE,
-                    force_code=report_codes.FORCE_NODE_ADDRESSES_UNRESOLVABLE,
+                    force_code=report_codes.FORCE,
                     address_list=list(self.new_addrs.values())[:2],
                 )
             ],
@@ -441,7 +446,7 @@ class AddLink(TestCase):
                 fixture.error(
                     report_codes.COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK,
                     address=self.new_addrs["node2"],
-                    expected_address_type=node.ADDR_IPV4,
+                    expected_address_type=CorosyncNodeAddressType.IPV4.value,
                     link_number=None,
                 ),
             ],
@@ -463,7 +468,7 @@ class AddLink(TestCase):
                 fixture.error(
                     report_codes.COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK,
                     address=self.new_addrs["node2"],
-                    expected_address_type=node.ADDR_IPV6,
+                    expected_address_type=CorosyncNodeAddressType.IPV6.value,
                     link_number=None,
                 ),
             ],
@@ -615,7 +620,7 @@ class AddLink(TestCase):
                 ),
                 fixture.error(
                     report_codes.NODE_ADDRESSES_UNRESOLVABLE,
-                    force_code=report_codes.FORCE_NODE_ADDRESSES_UNRESOLVABLE,
+                    force_code=report_codes.FORCE,
                     address_list=["addr1-new\n", "addr2{-}new"],
                 ),
                 fixture.error(
@@ -929,14 +934,14 @@ class UpdateLinkCommon(TestCase):
 class UpdateLinkAddressesMixin:
     def test_swap_addresses(self):
         new_addrs = {
-            self.coro_nodes[0]
-            .name: self.coro_nodes[1]
-            .addr_plain_for_link(self.linknumber),
-            self.coro_nodes[1]
-            .name: self.coro_nodes[0]
-            .addr_plain_for_link(self.linknumber),
+            self.coro_nodes[0].name: (
+                self.coro_nodes[1].addr_plain_for_link(self.linknumber)
+            ),
+            self.coro_nodes[1].name: (
+                self.coro_nodes[0].addr_plain_for_link(self.linknumber)
+            ),
         }
-        patch_getaddrinfo(self, new_addrs.values())
+        patch_getaddrinfo(self, list(new_addrs.values()) + self.existing_addrs)
 
         assert_report_item_list_equal(
             config_validators.update_link(
@@ -959,7 +964,7 @@ class UpdateLinkAddressesMixin:
             self.coro_nodes[1].name: "addr-new2",
             self.coro_nodes[2].name: "addr-new1",
         }
-        patch_getaddrinfo(self, new_addrs.values())
+        patch_getaddrinfo(self, list(new_addrs.values()) + self.existing_addrs)
 
         assert_report_item_list_equal(
             config_validators.update_link(
@@ -982,6 +987,7 @@ class UpdateLinkAddressesMixin:
         )
 
     def test_remove_address(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         assert_report_item_list_equal(
             config_validators.update_link(
                 self.linknumber,
@@ -1008,13 +1014,13 @@ class UpdateLinkAddressesMixin:
         report_4 = fixture.error(
             report_codes.COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK,
             address="10.0.0.1",
-            expected_address_type=node.ADDR_IPV6,
+            expected_address_type=CorosyncNodeAddressType.IPV6.value,
             link_number=self.linknumber,
         )
         report_6 = fixture.error(
             report_codes.COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK,
             address="::ffff:10:0:2:3",
-            expected_address_type=node.ADDR_IPV4,
+            expected_address_type=CorosyncNodeAddressType.IPV4.value,
             link_number=self.linknumber,
         )
         test_matrix = (
@@ -1031,7 +1037,7 @@ class UpdateLinkAddressesMixin:
             (constants.IP_VERSION_46, "new-addr", []),
             (constants.IP_VERSION_64, "new-addr", []),
         )
-        patch_getaddrinfo(self, ["new-addr"])
+        patch_getaddrinfo(self, self.existing_addrs + ["new-addr"])
         for ip_version, new_ip, reports in test_matrix:
             with self.subTest(ip_version=ip_version, new_ip=new_ip):
                 assert_report_item_list_equal(
@@ -1052,6 +1058,7 @@ class UpdateLinkAddressesMixin:
                 )
 
     def test_mixing_ip_families_new_vs_new(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         assert_report_item_list_equal(
             config_validators.update_link(
                 self.linknumber,
@@ -1076,6 +1083,7 @@ class UpdateLinkAddressesMixin:
         )
 
     def test_unresolvable(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         assert_report_item_list_equal(
             config_validators.update_link(
                 self.linknumber,
@@ -1093,13 +1101,14 @@ class UpdateLinkAddressesMixin:
             [
                 fixture.error(
                     report_codes.NODE_ADDRESSES_UNRESOLVABLE,
-                    force_code=report_codes.FORCE_NODE_ADDRESSES_UNRESOLVABLE,
+                    force_code=report_codes.FORCE,
                     address_list=["addr-new"],
                 ),
             ],
         )
 
     def test_unresolvable_forced(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         assert_report_item_list_equal(
             config_validators.update_link(
                 self.linknumber,
@@ -1124,6 +1133,7 @@ class UpdateLinkAddressesMixin:
         )
 
     def test_unknown_nodes(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         assert_report_item_list_equal(
             config_validators.update_link(
                 self.linknumber,
@@ -1153,7 +1163,7 @@ class UpdateLinkAddressesMixin:
             self.coro_nodes[1].name: "}addr-new2{",
             self.coro_nodes[2].name: "addr-new3",
         }
-        patch_getaddrinfo(self, new_addrs.values())
+        patch_getaddrinfo(self, list(new_addrs.values()) + self.existing_addrs)
 
         assert_report_item_list_equal(
             config_validators.update_link(
@@ -1195,6 +1205,9 @@ class UpdateLinkAddressesUdp(UpdateLinkAddressesMixin, TestCase):
             )
             for i in range(1, 5)
         ]
+        self.existing_addrs = []
+        for a_node in self.coro_nodes:
+            self.existing_addrs.extend(a_node.addrs_plain())
 
     def test_new_address_already_used(self):
         pcmk_nodes = [PacemakerNode("node-remote", "addr-remote")]
@@ -1205,7 +1218,7 @@ class UpdateLinkAddressesUdp(UpdateLinkAddressesMixin, TestCase):
             self.coro_nodes[2].name: pcmk_nodes[0].addr,
             self.coro_nodes[3].name: "new-addr",
         }
-        patch_getaddrinfo(self, new_addrs.values())
+        patch_getaddrinfo(self, list(new_addrs.values()) + self.existing_addrs)
 
         assert_report_item_list_equal(
             config_validators.update_link(
@@ -1228,6 +1241,7 @@ class UpdateLinkAddressesUdp(UpdateLinkAddressesMixin, TestCase):
         )
 
     def test_mixing_ip_families_new_vs_ipv6(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         coro_nodes = [
             node.CorosyncNode(
                 f"node{i}",
@@ -1259,6 +1273,7 @@ class UpdateLinkAddressesUdp(UpdateLinkAddressesMixin, TestCase):
         )
 
     def test_mixing_ip_families_new_vs_ipv4(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         coro_nodes = [
             node.CorosyncNode(
                 f"node{i}", [node.CorosyncNodeAddress(f"10.0.0.{i}", "0")], i
@@ -1304,6 +1319,9 @@ class UpdateLinkAddressesKnet(UpdateLinkAddressesMixin, TestCase):
             )
             for i in range(1, 5)
         ]
+        self.existing_addrs = []
+        for a_node in self.coro_nodes:
+            self.existing_addrs.extend(a_node.addrs_plain())
 
     def test_new_address_already_used(self):
         pcmk_nodes = [PacemakerNode("node-remote", "addr-remote")]
@@ -1316,7 +1334,7 @@ class UpdateLinkAddressesKnet(UpdateLinkAddressesMixin, TestCase):
             .addr_plain_for_link("0"),
             self.coro_nodes[2].name: pcmk_nodes[0].addr,
         }
-        patch_getaddrinfo(self, new_addrs.values())
+        patch_getaddrinfo(self, list(new_addrs.values()) + self.existing_addrs)
 
         assert_report_item_list_equal(
             config_validators.update_link(
@@ -1339,6 +1357,7 @@ class UpdateLinkAddressesKnet(UpdateLinkAddressesMixin, TestCase):
         )
 
     def test_mixing_ip_families_new_vs_ipv6(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         coro_nodes = [
             node.CorosyncNode(
                 f"node{i}",
@@ -1374,6 +1393,7 @@ class UpdateLinkAddressesKnet(UpdateLinkAddressesMixin, TestCase):
         )
 
     def test_mixing_ip_families_new_vs_ipv4(self):
+        patch_getaddrinfo(self, self.existing_addrs)
         coro_nodes = [
             node.CorosyncNode(
                 f"node{i}",
