@@ -1,16 +1,14 @@
 from unittest import TestCase
 
-from pcs_test.tools import fixture
-from pcs_test.tools.assertions import assert_report_item_list_equal
-from pcs_test.tools.custom_mock import patch_getaddrinfo
-
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.node import PacemakerNode as PNode
 from pcs.lib.corosync import config_validators
-from pcs.lib.corosync.node import (
-    CorosyncNode as CNode,
-    CorosyncNodeAddress as CAddr,
-)
+from pcs.lib.corosync.node import CorosyncNode as CNode
+from pcs.lib.corosync.node import CorosyncNodeAddress as CAddr
+
+from pcs_test.tools import fixture
+from pcs_test.tools.assertions import assert_report_item_list_equal
+from pcs_test.tools.custom_mock import patch_getaddrinfo
 
 # pylint: disable=no-self-use
 
@@ -667,7 +665,8 @@ class RemoveNodes(TestCase):
             config_validators.remove_nodes(
                 ["node3", "nodeX", "nodeY", "node4"],
                 self.fixture_nodes,
-                (None, None, None, None),
+                None,
+                ({}, {}, {}),
             ),
             [
                 fixture.error(
@@ -682,7 +681,8 @@ class RemoveNodes(TestCase):
             config_validators.remove_nodes(
                 ["node3", "node1", "node2", "node4"],
                 self.fixture_nodes,
-                (None, None, None, None),
+                None,
+                ({}, {}, {}),
             ),
             [fixture.error(report_codes.CANNOT_REMOVE_ALL_CLUSTER_NODES)],
         )
@@ -690,7 +690,7 @@ class RemoveNodes(TestCase):
     def test_qdevice_tie_breaker_none(self):
         assert_report_item_list_equal(
             config_validators.remove_nodes(
-                ["node4"], self.fixture_nodes, ("net", {}, None, None)
+                ["node4"], self.fixture_nodes, "net", ({}, {}, {})
             ),
             [],
         )
@@ -700,7 +700,8 @@ class RemoveNodes(TestCase):
             config_validators.remove_nodes(
                 ["node4"],
                 self.fixture_nodes,
-                ("net", {"tie_breaker": "highest"}, None, None),
+                "net",
+                ({"tie_breaker": "highest"}, {}, {}),
             ),
             [],
         )
@@ -710,7 +711,8 @@ class RemoveNodes(TestCase):
             config_validators.remove_nodes(
                 ["node4"],
                 self.fixture_nodes,
-                ("net", {"tie_breaker": "3"}, None, None),
+                "net",
+                ({"tie_breaker": "3"}, {}, {}),
             ),
             [],
         )
@@ -720,7 +722,8 @@ class RemoveNodes(TestCase):
             config_validators.remove_nodes(
                 ["node4"],
                 self.fixture_nodes,
-                ("net", {"tie_breaker": "4"}, None, None),
+                "net",
+                ({"tie_breaker": "4"}, {}, {}),
             ),
             [
                 fixture.error(
@@ -736,7 +739,8 @@ class RemoveNodes(TestCase):
             config_validators.remove_nodes(
                 ["node3", "node1", "node2", "node4", "nodeX"],
                 self.fixture_nodes,
-                ("net", {"tie_breaker": "4"}, None, None),
+                "net",
+                ({"tie_breaker": "4"}, {}, {}),
             ),
             [
                 fixture.error(
