@@ -1,14 +1,19 @@
 import re
 from unittest import TestCase
+
 from lxml import etree
 
+from pcs.common import reports
+from pcs.common.reports.const import (
+    ADD_REMOVE_CONTAINER_TYPE_STONITH_RESOURCE,
+    ADD_REMOVE_ITEM_TYPE_DEVICE,
+)
+from pcs.lib import validate
+from pcs.lib.cib.tools import IdProvider
+
 from pcs_test.tools import fixture
 from pcs_test.tools.assertions import assert_report_item_list_equal
 
-from pcs.common import reports
-from pcs.lib import validate
-from pcs.lib.cib.tools import IdProvider
-
 # pylint: disable=no-self-use
 # pylint: disable=too-many-lines
 
@@ -333,6 +338,52 @@ class DependsOnOption(TestCase):
         )
 
 
+class DeprecatedOption(TestCase):
+    def test_return_no_report_when_deprecated_not_present(self):
+        assert_report_item_list_equal(
+            validate.DeprecatedOption(
+                ["old1a", "old1b"], ["new1", "new2"]
+            ).validate({"new1": "value"}),
+            [],
+        )
+
+    def test_return_report_when_deprecated_present(self):
+        assert_report_item_list_equal(
+            validate.DeprecatedOption(
+                ["old1a", "old1b"], ["new1", "new2"]
+            ).validate({"old1b": "value"}),
+            [
+                fixture.deprecation(
+                    reports.codes.DEPRECATED_OPTION,
+                    option_name="old1b",
+                    replaced_by=["new1", "new2"],
+                    option_type=None,
+                ),
+            ],
+        )
+
+    def test_more_deprecated_present_and_custom_type(self):
+        assert_report_item_list_equal(
+            validate.DeprecatedOption(
+                ["old1a", "old1b"], ["new1", "new2"], "some type"
+            ).validate({"old1a": "valuea", "old1b": "valueb"}),
+            [
+                fixture.deprecation(
+                    reports.codes.DEPRECATED_OPTION,
+                    option_name="old1a",
+                    replaced_by=["new1", "new2"],
+                    option_type="some type",
+                ),
+                fixture.deprecation(
+                    reports.codes.DEPRECATED_OPTION,
+                    option_name="old1b",
+                    replaced_by=["new1", "new2"],
+                    option_type="some type",
+                ),
+            ],
+        )
+
+
 class IsRequiredAll(TestCase):
     def test_returns_no_report_when_required_is_present(self):
         assert_report_item_list_equal(
@@ -395,6 +446,22 @@ class IsRequiredSome(TestCase):
                 fixture.error(
                     reports.codes.REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING,
                     option_names=["first", "second"],
+                    deprecated_names=[],
+                    option_type="type",
+                ),
+            ],
+        )
+
+    def test_returns_report_when_missing_with_deprecated(self):
+        assert_report_item_list_equal(
+            validate.IsRequiredSome(
+                ["first", "second"], "type", ["second"]
+            ).validate({"third": "value"}),
+            [
+                fixture.error(
+                    reports.codes.REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING,
+                    option_names=["first", "second"],
+                    deprecated_names=["second"],
                     option_type="type",
                 ),
             ],
@@ -995,6 +1062,90 @@ class ValueId(TestCase):
         )
 
 
+class ValueDeprecated(TestCase):
+    def test_no_deprecated(self):
+        assert_report_item_list_equal(
+            validate.ValueDeprecated(
+                "opt",
+                dict(valB="valA"),
+            ).validate(dict(other_opt="1")),
+            [],
+        )
+
+    def test_empty_deprecation_map(self):
+        assert_report_item_list_equal(
+            validate.ValueDeprecated("opt", {}).validate(dict(opt="1")),
+            [],
+        )
+
+    def test_deprecated_no_replacement(self):
+        assert_report_item_list_equal(
+            validate.ValueDeprecated("opt", dict(valA=None)).validate(
+                dict(opt="valA")
+            ),
+            [
+                fixture.deprecation(
+                    reports.codes.DEPRECATED_OPTION_VALUE,
+                    option_name="opt",
+                    deprecated_value="valA",
+                    replaced_by=None,
+                )
+            ],
+        )
+
+    def test_deprecated_replaced(self):
+        assert_report_item_list_equal(
+            validate.ValueDeprecated(
+                "opt", dict(valA="valB"), reports.ReportItemSeverity.error()
+            ).validate(dict(opt="valA")),
+            [
+                fixture.error(
+                    reports.codes.DEPRECATED_OPTION_VALUE,
+                    option_name="opt",
+                    deprecated_value="valA",
+                    replaced_by="valB",
+                )
+            ],
+        )
+
+    def test_deprecated_replaced_normalized_value(self):
+        assert_report_item_list_equal(
+            validate.ValueDeprecated(
+                "opt", dict(valA="valB"), reports.ReportItemSeverity.error()
+            ).validate(
+                dict(
+                    opt=validate.ValuePair(original="val_a", normalized="valA")
+                )
+            ),
+            [
+                fixture.error(
+                    reports.codes.DEPRECATED_OPTION_VALUE,
+                    option_name="opt",
+                    deprecated_value="val_a",
+                    replaced_by="valB",
+                )
+            ],
+        )
+
+    def test_deprecated_replaced_custom_option_name_report(self):
+        assert_report_item_list_equal(
+            validate.ValueDeprecated(
+                "opt",
+                dict(valA="valB"),
+                reports.ReportItemSeverity.error(),
+                option_name_for_report="opt_for_report",
+            ).validate(dict(opt="valA")),
+            [
+                fixture.error(
+                    reports.codes.DEPRECATED_OPTION_VALUE,
+                    option_name="opt_for_report",
+                    deprecated_value="valA",
+                    replaced_by="valB",
+                )
+            ],
+        )
+
+
 class ValueIn(TestCase):
     def test_returns_empty_report_on_valid_option(self):
         assert_report_item_list_equal(
@@ -1240,6 +1391,52 @@ class ValueNotEmpty(TestCase):
         )
 
 
+class ValuePcmkBoolean(TestCase):
+    # The real code only calls ValuePredicateBase => only basic tests here.
+    def test_empty_report_on_valid_option(self):
+        for value in [
+            "True",
+            "oN",
+            "YES",
+            "Y",
+            "1",
+            "False",
+            "Off",
+            "NO",
+            "N",
+            "0",
+        ]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkBoolean("key", None, None).validate(
+                        {"key": value}
+                    ),
+                    [],
+                )
+
+    def test_report_invalid_value(self):
+        for value in ["", "T", "F", "-1", "2"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkBoolean("key", None, None).validate(
+                        {"key": value}
+                    ),
+                    [
+                        fixture.error(
+                            reports.codes.INVALID_OPTION_VALUE,
+                            option_name="key",
+                            option_value=value,
+                            allowed_values=(
+                                "a pacemaker boolean value: '0', '1', 'false', "
+                                "'n', 'no', 'off', 'on', 'true', 'y', 'yes'"
+                            ),
+                            cannot_be_empty=False,
+                            forbidden_characters=None,
+                        ),
+                    ],
+                )
+
+
 class ValuePcmkDatespecPart(TestCase):
     # The real code only calls ValuePredicateBase => only basic tests here.
     def test_empty_report_on_valid_option(self):
@@ -1285,6 +1482,115 @@ class ValuePcmkDatespecPart(TestCase):
         )
 
 
+class ValuePcmkPercentage(TestCase):
+    # The real code only calls ValuePredicateBase => only basic tests here.
+    def test_empty_report_on_valid_option(self):
+        for value in ["0%", "50%", "100%", "120%"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkPercentage("key", None, None).validate(
+                        {"key": value}
+                    ),
+                    [],
+                )
+
+    def test_report_invalid_value(self):
+        for value in ["", "0", "50", "-10%", "not-a-number%"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkPercentage("key", None, None).validate(
+                        {"key": value}
+                    ),
+                    [
+                        fixture.error(
+                            reports.codes.INVALID_OPTION_VALUE,
+                            option_name="key",
+                            option_value=value,
+                            allowed_values=(
+                                "a non-negative integer followed by '%' (e.g. "
+                                "0%, 50%, 200%, ...)"
+                            ),
+                            cannot_be_empty=False,
+                            forbidden_characters=None,
+                        ),
+                    ],
+                )
+
+
+class ValuePcmkInteger(TestCase):
+    # The real code only calls ValuePredicateBase => only basic tests here.
+    def test_empty_report_on_valid_option(self):
+        for value in [
+            "INFINITY",
+            "+INFINITY",
+            "-INFINITY",
+            "-1",
+            "0",
+            "+5",
+            "100",
+        ]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkInteger("key", None, None).validate(
+                        {"key": value}
+                    ),
+                    [],
+                )
+
+    def test_report_invalid_value(self):
+        for value in ["", "a", "-infinity", "-10%", "3.14"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkInteger("key", None, None).validate(
+                        {"key": value}
+                    ),
+                    [
+                        fixture.error(
+                            reports.codes.INVALID_OPTION_VALUE,
+                            option_name="key",
+                            option_value=value,
+                            allowed_values=(
+                                "an integer or INFINITY or -INFINITY"
+                            ),
+                            cannot_be_empty=False,
+                            forbidden_characters=None,
+                        ),
+                    ],
+                )
+
+
+class ValuePcmkPositiveInteger(TestCase):
+    # The real code only calls ValuePredicateBase => only basic tests here.
+    def test_empty_report_on_valid_option(self):
+        for value in ["INFINITY", "+INFINITY", "1", "+5"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkPositiveInteger(
+                        "key", None, None
+                    ).validate({"key": value}),
+                    [],
+                )
+
+    def test_report_invalid_value(self):
+        for value in ["", "-INFINITY", "0", "-10", "3.14"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValuePcmkPositiveInteger(
+                        "key", None, None
+                    ).validate({"key": value}),
+                    [
+                        fixture.error(
+                            reports.codes.INVALID_OPTION_VALUE,
+                            option_name="key",
+                            option_value=value,
+                            allowed_values="a positive integer or INFINITY",
+                            cannot_be_empty=False,
+                            forbidden_characters=None,
+                        ),
+                    ],
+                )
+
+
 class ValuePortNumber(TestCase):
     # The real code only calls ValuePredicateBase => only basic tests here.
     def test_empty_report_on_valid_option(self):
@@ -1666,3 +1972,346 @@ class IsEmptyString(TestCase):
         self.assertFalse(validate.is_empty_string("a"))
         self.assertFalse(validate.is_empty_string("0"))
         self.assertFalse(validate.is_empty_string(0))
+
+
+### complex
+
+
+class ValidateAddRemoveItems(TestCase):
+    CONTAINER_TYPE = ADD_REMOVE_CONTAINER_TYPE_STONITH_RESOURCE
+    ITEM_TYPE = ADD_REMOVE_ITEM_TYPE_DEVICE
+    CONTAINER_ID = "container_id"
+
+    def _validate(
+        self, add, remove, current=None, adjacent=None, can_be_empty=False
+    ):
+        # pylint: disable=protected-access
+        return validate.validate_add_remove_items(
+            add,
+            remove,
+            current,
+            self.CONTAINER_TYPE,
+            self.ITEM_TYPE,
+            self.CONTAINER_ID,
+            adjacent,
+            can_be_empty,
+        )
+
+    def test_success_add_and_remove(self):
+        assert_report_item_list_equal(
+            self._validate(["a1"], ["c3"], ["b2", "c3"]), []
+        )
+
+    def test_success_add_only(self):
+        assert_report_item_list_equal(self._validate(["b2"], [], ["a1"]), [])
+
+    def test_success_remove_only(self):
+        assert_report_item_list_equal(
+            self._validate([], ["b2"], ["a1", "b2"]), []
+        )
+
+    def test_add_remove_items_not_specified(self):
+        assert_report_item_list_equal(
+            self._validate([], [], ["a1", "b2", "c3"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_ITEMS_NOT_SPECIFIED,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                )
+            ],
+        )
+
+    def test_add_remove_items_duplications(self):
+        assert_report_item_list_equal(
+            self._validate(["b2", "b2"], ["a1", "a1"], ["a1", "c3"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_ITEMS_DUPLICATION,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    duplicate_items_list=["a1", "b2"],
+                )
+            ],
+        )
+
+    def test_add_items_already_in_container(self):
+        assert_report_item_list_equal(
+            self._validate(["a1", "b2"], [], ["a1", "b2", "c3"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_ADD_ITEMS_ALREADY_IN_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a1", "b2"],
+                ),
+            ],
+        )
+
+    def test_remove_items_not_in_container(self):
+        assert_report_item_list_equal(
+            self._validate([], ["a1", "b2"], ["c3"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a1", "b2"],
+                )
+            ],
+        )
+
+    def test_add_remove_items_at_the_same_time(self):
+        assert_report_item_list_equal(
+            self._validate(
+                ["a1", "a1", "b2", "b2"], ["b2", "b2", "a1", "a1"], ["c3"]
+            ),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_ITEMS_DUPLICATION,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    duplicate_items_list=["a1", "b2"],
+                ),
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a1", "b2"],
+                ),
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_ADD_AND_REMOVE_ITEMS_AT_THE_SAME_TIME,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a1", "b2"],
+                ),
+            ],
+        )
+
+    def test_remove_all_items(self):
+        assert_report_item_list_equal(
+            self._validate([], ["a1", "b2"], ["a1", "b2"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_REMOVE_ALL_ITEMS_FROM_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a1", "b2"],
+                ),
+            ],
+        )
+
+    def test_remove_all_items_can_be_empty(self):
+        assert_report_item_list_equal(
+            self._validate([], ["a1", "b2"], ["a1", "b2"], can_be_empty=True),
+            [],
+        )
+
+    def test_remove_all_items_and_add_new_one(self):
+        assert_report_item_list_equal(
+            self._validate(["c3"], ["a1", "b2"], ["a1", "b2"]),
+            [],
+        )
+
+    def test_missing_adjacent_item(self):
+        assert_report_item_list_equal(
+            self._validate(["a1", "b2"], [], ["c3"], adjacent="d4"),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_ADJACENT_ITEM_NOT_IN_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    adjacent_item_id="d4",
+                ),
+            ],
+        )
+
+    def test_adjacent_item_in_add_list(self):
+        assert_report_item_list_equal(
+            self._validate(["a1", "b2"], [], ["a1"], adjacent="a1"),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_PUT_ITEM_NEXT_TO_ITSELF,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    adjacent_item_id="a1",
+                ),
+            ],
+        )
+
+    def test_adjacent_item_without_add_list(self):
+        assert_report_item_list_equal(
+            self._validate([], ["b2"], ["a1", "b2"], adjacent="a1"),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_SPECIFY_ADJACENT_ITEM_WITHOUT_ITEMS_TO_ADD,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    adjacent_item_id="a1",
+                ),
+            ],
+        )
+
+
+class ValidateSetUnsetItems(TestCase):
+    CONTAINER_TYPE = ADD_REMOVE_CONTAINER_TYPE_STONITH_RESOURCE
+    ITEM_TYPE = ADD_REMOVE_ITEM_TYPE_DEVICE
+    CONTAINER_ID = "container_id"
+
+    def _validate(self, add, remove, current, severity=None):
+        return validate.validate_set_unset_items(
+            add,
+            remove,
+            current,
+            self.CONTAINER_TYPE,
+            self.ITEM_TYPE,
+            self.CONTAINER_ID,
+            severity,
+        )
+
+    def test_success(self):
+        assert_report_item_list_equal(
+            self._validate(["a"], ["b"], ["b", "c"]), []
+        )
+
+    def test_items_not_specified(self):
+        assert_report_item_list_equal(
+            self._validate([], [], []),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_ITEMS_NOT_SPECIFIED,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                )
+            ],
+        )
+
+    def test_items_not_specified_severity(self):
+        assert_report_item_list_equal(
+            self._validate(
+                [], [], [], severity=reports.ReportItemSeverity.warning()
+            ),
+            [
+                fixture.warn(
+                    reports.codes.ADD_REMOVE_ITEMS_NOT_SPECIFIED,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                )
+            ],
+        )
+
+    def test_duplicate_items(self):
+        assert_report_item_list_equal(
+            self._validate(["a", "a", "b", "b"], ["c", "c"], ["a", "b", "c"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_ITEMS_DUPLICATION,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    duplicate_items_list=["a", "b", "c"],
+                )
+            ],
+        )
+
+    def test_duplicate_items_severity(self):
+        assert_report_item_list_equal(
+            self._validate(
+                ["a", "a", "b", "b"],
+                ["c", "c"],
+                ["a", "b", "c"],
+                severity=reports.ReportItemSeverity.warning(),
+            ),
+            [
+                fixture.warn(
+                    reports.codes.ADD_REMOVE_ITEMS_DUPLICATION,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    duplicate_items_list=["a", "b", "c"],
+                )
+            ],
+        )
+
+    def test_remove_items_missing(self):
+        assert_report_item_list_equal(
+            self._validate([], ["a", "b"], ["c"]),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a", "b"],
+                )
+            ],
+        )
+
+    def test_remove_items_missing_severity(self):
+        assert_report_item_list_equal(
+            self._validate(
+                [],
+                ["a", "b"],
+                ["c"],
+                severity=reports.ReportItemSeverity.info(),
+            ),
+            [
+                fixture.info(
+                    reports.codes.ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a", "b"],
+                )
+            ],
+        )
+
+    def test_items_both_added_and_removed(self):
+        assert_report_item_list_equal(
+            self._validate(
+                ["a", "b"],
+                ["a", "b"],
+                ["a", "b"],
+            ),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_ADD_AND_REMOVE_ITEMS_AT_THE_SAME_TIME,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a", "b"],
+                )
+            ],
+        )
+
+    def test_items_both_added_and_removed_severity(self):
+        assert_report_item_list_equal(
+            self._validate(
+                ["a", "b"],
+                ["a", "b"],
+                ["a", "b"],
+                severity=reports.ReportItemSeverity.info(),
+            ),
+            [
+                fixture.error(
+                    reports.codes.ADD_REMOVE_CANNOT_ADD_AND_REMOVE_ITEMS_AT_THE_SAME_TIME,
+                    container_type=self.CONTAINER_TYPE,
+                    item_type=self.ITEM_TYPE,
+                    container_id=self.CONTAINER_ID,
+                    item_list=["a", "b"],
+                )
+            ],
+        )
