@@ -1,10 +1,13 @@
-from unittest import mock, TestCase
-
-from pcs_test.tools.misc import dict_to_modifiers
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs import host
 from pcs.cli.common.errors import CmdLineInputError
 
+from pcs_test.tools.misc import dict_to_modifiers
+
 
 class HostAuth(TestCase):
     host_names = {
