@@ -1,9 +1,10 @@
 from unittest import TestCase
+
 from lxml import etree
 
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_file,
     write_data_to_tmpfile,
     write_file_to_tmpfile,
