@@ -1,19 +1,18 @@
 import unittest
 
+from pcs_test.tools.assertions import AssertPcsMixin
+from pcs_test.tools.misc import ParametrizedTestMetaClass
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_file,
     outdent,
-    ParametrizedTestMetaClass,
     write_file_to_tmpfile,
 )
-from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.pcs_runner import PcsRunner
 
-
 empty_cib = rc("cib-empty.xml")
 
-ERRORS_HAVE_OCURRED = (
+ERRORS_HAVE_OCCURRED = (
     "Error: Errors have occurred, therefore pcs is unable to continue\n"
 )
 
@@ -172,13 +171,17 @@ class DeleteRemoveAlertTest(PcsAlertTest):
     def _test_usage(self):
         self.assert_pcs_fail(
             ["alert", self.command],
-            stdout_start=f"\nUsage: pcs alert <command>\n    {self.command} <",
+            stderr_start=outdent(
+                f"""
+                Usage: pcs alert <command>
+                    {self.command} <"""
+            ),
         )
 
     def _test_not_existing_alert(self):
         self.assert_pcs_fail(
             ["alert", self.command, "alert1"],
-            ("Error: alert 'alert1' does not exist\n" + ERRORS_HAVE_OCURRED),
+            ("Error: alert 'alert1' does not exist\n" + ERRORS_HAVE_OCCURRED),
         )
 
     def _test_one(self):
@@ -327,7 +330,7 @@ Alerts:
             "alert recipient add alert value=rec_value".split(),
             (
                 "Error: Recipient 'rec_value' in alert 'alert' already exists, "
-                "use --force to override\n" + ERRORS_HAVE_OCURRED
+                "use --force to override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
         self.assert_pcs_success(
@@ -341,7 +344,7 @@ Alerts:
         )
         self.assert_pcs_success(
             "alert recipient add alert value=rec_value --force".split(),
-            "Warning: Recipient 'rec_value' in alert 'alert' already exists\n",
+            stderr_full="Warning: Recipient 'rec_value' in alert 'alert' already exists\n",
         )
         self.assert_pcs_success(
             "alert config".split(),
@@ -437,12 +440,12 @@ Alerts:
             "alert recipient update alert-recipient value=value".split(),
             (
                 "Error: Recipient 'value' in alert 'alert' already exists, "
-                "use --force to override\n" + ERRORS_HAVE_OCURRED
+                "use --force to override\n" + ERRORS_HAVE_OCCURRED
             ),
         )
         self.assert_pcs_success(
             "alert recipient update alert-recipient value=value --force".split(),
-            "Warning: Recipient 'value' in alert 'alert' already exists\n",
+            stderr_full="Warning: Recipient 'value' in alert 'alert' already exists\n",
         )
         self.assert_pcs_success(
             "alert config".split(),
@@ -505,7 +508,7 @@ class DeleteRemoveRecipientTest(PcsAlertTest):
     def _test_usage(self):
         self.assert_pcs_fail(
             ["alert", "recipient", self.command],
-            stdout_start=outdent(
+            stderr_start=outdent(
                 f"""
                 Usage: pcs alert <command>
                     recipient {self.command} <"""
@@ -595,7 +598,8 @@ class DeleteRemoveRecipientTest(PcsAlertTest):
             ["alert", "recipient", self.command, "rec1", "rec2", "rec3"],
             (
                 "Error: recipient 'rec2' does not exist\n"
-                "Error: recipient 'rec3' does not exist\n" + ERRORS_HAVE_OCURRED
+                "Error: recipient 'rec3' does not exist\n"
+                + ERRORS_HAVE_OCCURRED
             ),
         )
         self.assert_pcs_success(
