@@ -1,26 +1,28 @@
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from lxml import etree
 
-from pcs_test.tools.assertions import (
-    ac,
-    AssertPcsMixin,
+from pcs import (
+    node,
+    utils,
 )
+
+from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_file,
     outdent,
     write_file_to_tmpfile,
 )
 from pcs_test.tools.pcs_runner import (
-    pcs,
     PcsRunner,
+    pcs,
 )
 
-from pcs import node
-from pcs import utils
-
 # pylint: disable=invalid-name, line-too-long
 
 empty_cib = rc("cib-empty-withnodes.xml")
@@ -82,99 +84,142 @@ class NodeUtilizationSet(
         """
 
     def test_node_utilization_set(self):
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-1 test1=10".split()
         )
-        ac("", output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(stdout, "")
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-2".split()
         )
-        expected_out = """\
-Node Utilization:
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-1".split()
         )
-        expected_out = """\
-Node Utilization:
- rh7-1: test1=10
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                 rh7-1: test1=10
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name,
             "node utilization rh7-1 test1=-10 test4=1234".split(),
         )
-        ac("", output)
-        self.assertEqual(0, returnVal)
-        output, returnVal = pcs(
+        self.assertEqual(stdout, "")
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
+
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-1".split()
         )
-        expected_out = """\
-Node Utilization:
- rh7-1: test1=-10 test4=1234
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                 rh7-1: test1=-10 test4=1234
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name,
             "node utilization rh7-2 test2=321 empty=".split(),
         )
-        ac("", output)
-        self.assertEqual(0, returnVal)
-        output, returnVal = pcs(
+        self.assertEqual(stdout, "")
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
+
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-2".split()
         )
-        expected_out = """\
-Node Utilization:
- rh7-2: test2=321
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                 rh7-2: test2=321
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(self.temp_cib.name, "node utilization".split())
-        expected_out = """\
-Node Utilization:
- rh7-1: test1=-10 test4=1234
- rh7-2: test2=321
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        stdout, stderr, retval = pcs(
+            self.temp_cib.name, "node utilization".split()
+        )
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                 rh7-1: test1=-10 test4=1234
+                 rh7-2: test2=321
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-2 test1=-20".split()
         )
-        ac("", output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(stdout, "")
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization --name test1".split()
         )
-        expected_out = """\
-Node Utilization:
- rh7-1: test1=-10
- rh7-2: test1=-20
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                 rh7-1: test1=-10
+                 rh7-2: test1=-20
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
-        output, returnVal = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name,
             "node utilization --name test1 rh7-2".split(),
         )
-        expected_out = """\
-Node Utilization:
- rh7-2: test1=-20
-"""
-        ac(expected_out, output)
-        self.assertEqual(0, returnVal)
+        self.assertEqual(
+            stdout,
+            outdent(
+                """\
+                Node Utilization:
+                 rh7-2: test1=-20
+                """
+            ),
+        )
+        self.assertEqual(stderr, "")
+        self.assertEqual(retval, 0)
 
     def test_refuse_non_option_attribute_parameter_among_options(self):
         self.assert_pcs_fail(
@@ -297,31 +342,31 @@ class NodeStandby(TestCase, AssertPcsMixin):
     def test_one_bad_node(self):
         self.assert_standby_none()
         self.assert_pcs_fail(
-            "node standby nonexistant-node".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n",
+            "node standby nonexistent-node".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n",
         )
         self.assert_standby_none()
 
         self.fixture_standby_all()
         self.assert_pcs_fail(
-            "node unstandby nonexistant-node".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n",
+            "node unstandby nonexistent-node".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n",
         )
         self.assert_standby_all()
 
     def test_bad_node_cancels_all_changes(self):
         self.assert_standby_none()
         self.assert_pcs_fail(
-            "node standby rh7-1 nonexistant-node and-another rh7-2".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n"
+            "node standby rh7-1 nonexistent-node and-another rh7-2".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n"
             "Error: Node 'and-another' does not appear to exist in configuration\n",
         )
         self.assert_standby_none()
 
         self.fixture_standby_all()
         self.assert_pcs_fail(
-            "node standby rh7-1 nonexistant-node and-another rh7-2".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n"
+            "node standby rh7-1 nonexistent-node and-another rh7-2".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n"
             "Error: Node 'and-another' does not appear to exist in configuration\n",
         )
         self.assert_standby_all()
@@ -391,11 +436,11 @@ class NodeStandby(TestCase, AssertPcsMixin):
     def test_all_and_nodelist(self):
         self.assert_pcs_fail(
             "node standby rh7-1 rh7-2 --all".split(),
-            stdout_full="Error: Cannot specify both --all and a list of nodes.\n",
+            "Error: Cannot specify both --all and a list of nodes.\n",
         )
         self.assert_pcs_fail(
             "node unstandby rh7-1 rh7-2 --all".split(),
-            stdout_full="Error: Cannot specify both --all and a list of nodes.\n",
+            "Error: Cannot specify both --all and a list of nodes.\n",
         )
 
 
@@ -446,31 +491,31 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
     def test_one_bad_node(self):
         self.assert_maintenance_none()
         self.assert_pcs_fail(
-            "node maintenance nonexistant-node".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n",
+            "node maintenance nonexistent-node".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n",
         )
         self.assert_maintenance_none()
 
         self.fixture_maintenance_all()
         self.assert_pcs_fail(
-            "node unmaintenance nonexistant-node".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n",
+            "node unmaintenance nonexistent-node".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n",
         )
         self.assert_maintenance_all()
 
     def test_bad_node_cancels_all_changes(self):
         self.assert_maintenance_none()
         self.assert_pcs_fail(
-            "node maintenance rh7-1 nonexistant-node and-another rh7-2".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n"
+            "node maintenance rh7-1 nonexistent-node and-another rh7-2".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n"
             "Error: Node 'and-another' does not appear to exist in configuration\n",
         )
         self.assert_maintenance_none()
 
         self.fixture_maintenance_all()
         self.assert_pcs_fail(
-            "node maintenance rh7-1 nonexistant-node and-another rh7-2".split(),
-            "Error: Node 'nonexistant-node' does not appear to exist in configuration\n"
+            "node maintenance rh7-1 nonexistent-node and-another rh7-2".split(),
+            "Error: Node 'nonexistent-node' does not appear to exist in configuration\n"
             "Error: Node 'and-another' does not appear to exist in configuration\n",
         )
         self.assert_maintenance_all()
@@ -540,11 +585,11 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
     def test_all_and_nodelist(self):
         self.assert_pcs_fail(
             "node maintenance rh7-1 rh7-2 --all".split(),
-            stdout_full="Error: Cannot specify both --all and a list of nodes.\n",
+            "Error: Cannot specify both --all and a list of nodes.\n",
         )
         self.assert_pcs_fail(
             "node unmaintenance rh7-1 rh7-2 --all".split(),
-            stdout_full="Error: Cannot specify both --all and a list of nodes.\n",
+            "Error: Cannot specify both --all and a list of nodes.\n",
         )
 
 
@@ -567,7 +612,7 @@ class NodeAttributeTest(
         self.temp_cib.close()
 
     def fixture_attrs(self, nodes, attrs=None):
-        attrs = dict() if attrs is None else attrs
+        attrs = {} if attrs is None else attrs
         xml_lines = ["<nodes>"]
         for node_id, node_name in enumerate(nodes, 1):
             xml_lines.extend(
@@ -577,7 +622,7 @@ class NodeAttributeTest(
                 ]
             )
             nv = '<nvpair id="nodes-{id}-{name}" name="{name}" value="{val}"/>'
-            for name, value in attrs.get(node_name, dict()).items():
+            for name, value in attrs.get(node_name, {}).items():
                 xml_lines.append(nv.format(id=node_id, name=name, val=value))
             xml_lines.extend(["</instance_attributes>", "</node>"])
         xml_lines.append("</nodes>")
@@ -864,7 +909,8 @@ Node Attributes:
         )
         self.assert_pcs_result(
             "node attribute rh7-1 missing=".split(),
-            "Error: attribute: 'missing' doesn't exist for node: 'rh7-1'\n",
+            stdout_full="",
+            stderr_full="Error: attribute: 'missing' doesn't exist for node: 'rh7-1'\n",
             returncode=2,
         )
 
@@ -899,10 +945,11 @@ Node Attributes:
         # this behaves differently than the rest of pcs - instead of doing
         # nothing it returns an error.
         # Should be changed to be consistent with the rest of pcs.
-        output, retval = pcs(
+        stdout, stderr, retval = pcs(
             self.temp_cib.name, "node attribute rh7-1 test=".split()
         )
+        self.assertEqual(stdout, "")
         self.assertEqual(
-            output, "Error: attribute: 'test' doesn't exist for node: 'rh7-1'\n"
+            stderr, "Error: attribute: 'test' doesn't exist for node: 'rh7-1'\n"
         )
         self.assertEqual(retval, 2)
