@@ -1,20 +1,23 @@
 import os
 from textwrap import dedent
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs.cli.booth import command as booth_cmd
+from pcs.lib.booth import constants
 
-from pcs_test.tools.assertions import AssertPcsMixin
+from pcs_test.tools.assertions import AssertPcsMixinOld as AssertPcsMixin
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_dir,
     get_tmp_file,
     outdent,
     skip_unless_booth_resource_agent_installed,
     write_file_to_tmpfile,
 )
-from pcs_test.tools.pcs_runner import PcsRunner
-
+from pcs_test.tools.pcs_runner import PcsRunnerOld as PcsRunner
 
 EMPTY_CIB = rc("cib-empty.xml")
 
@@ -35,7 +38,13 @@ class BoothMixin(AssertPcsMixin):
         self.booth_key_path = os.path.join(self.booth_dir.name, "booth.key")
         self.temp_cib = get_tmp_file("tier1_booth")
         write_file_to_tmpfile(EMPTY_CIB, self.temp_cib)
-        self.pcs_runner = PcsRunner(self.temp_cib.name)
+        self.pcs_runner = PcsRunner(
+            self.temp_cib.name,
+            mock_settings=dict(
+                booth_enable_authfile_set_enabled=str(False),
+                booth_enable_authfile_unset_enabled=str(False),
+            ),
+        )
 
     def tearDown(self):
         # pylint cannot possibly know this is being mixed into TestCase classes
@@ -101,6 +110,32 @@ class SetupTest(BoothMixin, TestCase):
         with open(self.booth_key_path, "rb") as key_file:
             self.assertEqual(64, len(key_file.read()))
 
+    def test_success_setup_booth_config_enable_autfile(self):
+        self.pcs_runner = PcsRunner(
+            None,
+            mock_settings=dict(
+                booth_enable_authfile_set_enabled=str(True),
+                booth_enable_authfile_unset_enabled=str(False),
+            ),
+        )
+        self.ensure_booth_config_not_exists()
+        self.assert_pcs_success(
+            "booth setup sites 1.1.1.1 2.2.2.2 arbitrators 3.3.3.3".split()
+        )
+        with open(self.booth_cfg_path, "r") as config_file:
+            self.assertEqual(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    {constants.AUTHFILE_FIX_OPTION} = yes
+                    site = 1.1.1.1
+                    site = 2.2.2.2
+                    arbitrator = 3.3.3.3
+                    """
+                ),
+                config_file.read(),
+            )
+
     def test_overwrite_existing_mocked_config(self):
         self.ensure_booth_config_exists()
         self.assert_pcs_success(
@@ -123,7 +158,7 @@ class SetupTest(BoothMixin, TestCase):
             ),
         )
 
-    def test_refuse_partialy_mocked_environment(self):
+    def test_refuse_partially_mocked_environment(self):
         self.assert_pcs_fail_original(
             # no --booth-key!
             (
@@ -207,8 +242,8 @@ class AddTicketTest(BoothTest):
         self.assert_pcs_fail(
             "booth ticket add @TicketA".split(),
             (
-                "Error: booth ticket name '@TicketA' is not valid, use "
-                "alphanumeric chars or dash\n"
+                "Error: booth ticket name '@TicketA' is not valid, use up to 63 "
+                "alphanumeric characters or dash\n"
                 "Error: Errors have occurred, therefore pcs is unable to "
                 "continue\n"
             ),
@@ -232,7 +267,7 @@ class AddTicketTest(BoothTest):
             (
                 "Error: invalid booth ticket option 'site', allowed options"
                 " are: 'acquire-after', 'attr-prereq', "
-                "'before-acquire-handler', 'expire', 'renewal-freq', "
+                "'before-acquire-handler', 'expire', 'mode', 'renewal-freq', "
                 "'retries', 'timeout', 'weights'\n"
                 "Error: timeout cannot be empty\n"
                 "Error: Errors have occurred, therefore pcs is unable to "
@@ -244,7 +279,7 @@ class AddTicketTest(BoothTest):
         msg = (
             "invalid booth ticket option 'unknown', allowed options"
             " are: 'acquire-after', 'attr-prereq', 'before-acquire-handler',"
-            " 'expire', 'renewal-freq', 'retries', 'timeout', 'weights'"
+            " 'expire', 'mode', 'renewal-freq', 'retries', 'timeout', 'weights'"
         )
         self.assert_pcs_fail(
             "booth ticket add TicketA unknown=a".split(),
@@ -564,3 +599,116 @@ class Status(BoothMixinNoFiles, TestCase):
                     status"""
             ),
         )
+
+
+class EnableAuthfile(BoothMixin, TestCase):
+    def setUp(self):
+        super().setUp()
+        self.pcs_runner.cib_file = None
+        self.pcs_runner.mock_settings[
+            "booth_enable_authfile_set_enabled"
+        ] = str(True)
+        self.ensure_booth_config_not_exists()
+
+    def test_not_enabled(self):
+        with open(self.booth_cfg_path, "w") as config_file:
+            config_file.write(f"authfile = {self.booth_key_path}\n")
+        self.assert_pcs_success("booth enable-authfile".split())
+        with open(self.booth_cfg_path, "r") as config_file:
+            self.assertEqual(
+                dedent(
+                    f"""\
+                    {constants.AUTHFILE_FIX_OPTION} = yes
+                    authfile = {self.booth_key_path}
+                    """
+                ),
+                config_file.read(),
+            )
+
+    def test_already_enabled(self):
+        with open(self.booth_cfg_path, "w") as config_file:
+            config_file.write(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    {constants.AUTHFILE_FIX_OPTION} = on
+                    """
+                )
+            )
+        self.assert_pcs_success("booth enable-authfile".split())
+        with open(self.booth_cfg_path, "r") as config_file:
+            self.assertEqual(
+                dedent(
+                    f"""\
+                    {constants.AUTHFILE_FIX_OPTION} = yes
+                    authfile = {self.booth_key_path}
+                    """
+                ),
+                config_file.read(),
+            )
+
+
+class CleanEnableAuthfile(BoothMixin, TestCase):
+    def setUp(self):
+        super().setUp()
+        self.pcs_runner.cib_file = None
+        self.ensure_booth_config_not_exists()
+        self.pcs_runner.mock_settings[
+            "booth_enable_authfile_unset_enabled"
+        ] = str(True)
+
+    def test_not_set(self):
+        with open(self.booth_cfg_path, "w") as config_file:
+            config_file.write(f"authfile = {self.booth_key_path}\n")
+        self.assert_pcs_success("booth clean-enable-authfile".split())
+        with open(self.booth_cfg_path, "r") as config_file:
+            self.assertEqual(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    """
+                ),
+                config_file.read(),
+            )
+
+    def test_enabled(self):
+        with open(self.booth_cfg_path, "w") as config_file:
+            config_file.write(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    {constants.AUTHFILE_FIX_OPTION} = 1
+                    """
+                )
+            )
+        self.assert_pcs_success("booth clean-enable-authfile".split())
+        with open(self.booth_cfg_path, "r") as config_file:
+            self.assertEqual(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    """
+                ),
+                config_file.read(),
+            )
+
+    def test_disabled(self):
+        with open(self.booth_cfg_path, "w") as config_file:
+            config_file.write(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    {constants.AUTHFILE_FIX_OPTION} = off
+                    """
+                )
+            )
+        self.assert_pcs_success("booth clean-enable-authfile".split())
+        with open(self.booth_cfg_path, "r") as config_file:
+            self.assertEqual(
+                dedent(
+                    f"""\
+                    authfile = {self.booth_key_path}
+                    """
+                ),
+                config_file.read(),
+            )
