@@ -7,6 +7,7 @@ from pcs_test.tools.command_env.config_fs import FsConfig
 from pcs_test.tools.command_env.config_http import HttpConfig
 from pcs_test.tools.command_env.config_raw_file import RawFileConfig
 from pcs_test.tools.command_env.config_runner import RunnerConfig
+from pcs_test.tools.command_env.config_services import ServiceManagerConfig
 
 
 class Spy:
@@ -29,16 +30,14 @@ class Config:
         self.corosync_conf = self.__wrap_helper(CorosyncConf(self.__calls))
         self.fs = self.__wrap_helper(FsConfig(self.__calls))
         self.raw_file = self.__wrap_helper(RawFileConfig(self.__calls))
+        self.services = self.__wrap_helper(ServiceManagerConfig(self.__calls))
 
         self.spy = None
 
     def add_extension(self, name, Extension):
         if hasattr(self, name):
             raise AssertionError(
-                (
-                    "Config (integration tests) has the extension '{0}' "
-                    "already."
-                ).format(name)
+                f"Config (integration tests) has the extension '{name}' already."
             )
         setattr(
             self,
@@ -58,11 +57,18 @@ class Config:
 
     def remove(self, name):
         """
-        Remove call with specified name from list.
+        Remove a call with the specified name from the list
         """
         self.__calls.remove(name)
         return self
 
+    def trim_before(self, name):
+        """
+        Remove a call with the specified name and all calls after it from the list
+        """
+        self.__calls.trim_before(name)
+        return self
+
     def __wrap_method(self, helper, name, method):
         """
         Wrap method in helper to return self of this object
