@@ -3,108 +3,38 @@ import json
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 
-
 ALL_RESOURCE_XML_TAGS = ["bundle", "clone", "group", "master", "primitive"]
 
 
-def state_node(
-    id,
-    name,
-    type="member",
-    online=True,
-    standby=False,
-    standby_onfail=False,
-    maintenance=False,
-    pending=False,
-    unclean=False,
-    shutdown=False,
-    expected_up=True,
-    is_dc=False,
-    resources_running=0,
-):
-    # pylint: disable=invalid-name, too-many-arguments, redefined-builtin, unused-argument
-    return locals()
+def debug(code, context=None, **kwargs):
+    return severities.DEBUG, code, kwargs, None, context
 
 
-def complete_state_resources(resource_status):
-    for resource in resource_status.xpath(".//resource"):
-        _default_element_attributes(
-            resource,
-            {
-                "active": "true",
-                "managed": "true",
-                "failed": "false",
-                "failure_ignored": "false",
-                "nodes_running_on": "1",
-                "orphaned": "false",
-                "resource_agent": "ocf::heartbeat:Dummy",
-                "role": "Started",
-            },
-        )
-    for group in resource_status.xpath(".//group"):
-        _default_element_attributes(
-            group,
-            {
-                "disabled": "false",
-                "managed": "true",
-            },
-        )
-    for clone in resource_status.xpath(".//clone"):
-        _default_element_attributes(
-            clone,
-            {
-                "disabled": "false",
-                "failed": "false",
-                "failure_ignored": "false",
-            },
-        )
-    for bundle in resource_status.xpath(".//bundle"):
-        _default_element_attributes(
-            bundle,
-            {
-                "type": "docker",
-                "image": "image:name",
-                "unique": "false",
-                "failed": "false",
-            },
-        )
-    return resource_status
+def warn(code, context=None, **kwargs):
+    return severities.WARNING, code, kwargs, None, context
 
 
-def _default_element_attributes(element, default_attributes):
-    for name, value in default_attributes.items():
-        if name not in element.attrib:
-            element.attrib[name] = value
+def deprecation(code, context=None, **kwargs):
+    return severities.DEPRECATION, code, kwargs, None, context
 
 
-def report_variation(report, **_info):
-    updated_info = report[2].copy()
-    updated_info.update(_info)
-    return report[0], report[1], updated_info, report[3]
+def error(code, force_code=None, context=None, **kwargs):
+    return severities.ERROR, code, kwargs, force_code, context
 
 
-def debug(code, **kwargs):
-    return severities.DEBUG, code, kwargs, None
-
-
-def warn(code, **kwargs):
-    return severities.WARNING, code, kwargs, None
-
-
-def error(code, force_code=None, **kwargs):
-    return severities.ERROR, code, kwargs, force_code
-
-
-def info(code, **kwargs):
-    return severities.INFO, code, kwargs, None
+def info(code, context=None, **kwargs):
+    return severities.INFO, code, kwargs, None, context
 
 
 class ReportStore:
     def __init__(self, names=None, reports=None):
-        if not names:
-            names = []
+        self.__names = names or []
+        self.__reports = reports or []
 
-        duplicate_names = {n for n in names if names.count(n) > 1}
+        if len(self.__names) != len(self.__reports):
+            raise AssertionError("Reports count doesn't match names count")
+
+        duplicate_names = {n for n in self.__names if self.__names.count(n) > 1}
         if duplicate_names:
             raise AssertionError(
                 "Duplicate names are not allowed in ReportStore. "
@@ -113,31 +43,34 @@ class ReportStore:
                 )
             )
 
-        self.__names = names
-        self.__reports = reports or []
-        if len(self.__names) != len(self.__reports):
-            raise AssertionError("Same count reports as names required")
+    @staticmethod
+    def _report_variation(report, payload):
+        updated_payload = report[2].copy()
+        updated_payload.update(payload)
+        return report[0], report[1], updated_payload, report[3]
 
     @property
     def reports(self):
         return list(self.__reports)
 
-    def adapt(self, name, **_info):
+    def adapt(self, name, **payload):
         index = self.__names.index(name)
         return ReportStore(
             self.__names,
             [
-                report if i != index else report_variation(report, **_info)
+                report
+                if i != index
+                else self._report_variation(report, payload)
                 for i, report in enumerate(self.__reports)
             ],
         )
 
-    def adapt_multi(self, name_list, **_info):
+    def adapt_multi(self, name_list, **payload):
         names, reports = zip(
             *[
                 (
                     name,
-                    report_variation(self[name], **_info)
+                    self._report_variation(self[name], payload)
                     if name in name_list
                     else self[name],
                 )
@@ -152,6 +85,9 @@ class ReportStore:
     def warn(self, name, code, **kwargs):
         return self.__append(name, warn(code, **kwargs))
 
+    def deprecation(self, name, code, **kwargs):
+        return self.__append(name, deprecation(code, **kwargs))
+
     def error(self, name, code, force_code=None, **kwargs):
         return self.__append(name, error(code, force_code=force_code, **kwargs))
 
@@ -159,8 +95,10 @@ class ReportStore:
         report = self[name]
         return self.__append(as_name, warn(report[1], **report[2]))
 
-    def copy(self, name, as_name, **_info):
-        return self.__append(as_name, report_variation(self[name], **_info))
+    def copy(self, name, as_name, **payload):
+        return self.__append(
+            as_name, self._report_variation(self[name], payload)
+        )
 
     def remove(self, *name_list):
         names, reports = zip(
@@ -176,8 +114,10 @@ class ReportStore:
         names, reports = zip(*[(name, self[name]) for name in name_list])
         return ReportStore(list(names), list(reports))
 
-    def only(self, name, **_info):
-        return ReportStore([name], [report_variation(self[name], **_info)])
+    def only(self, name, **payload):
+        return ReportStore(
+            [name], [self._report_variation(self[name], payload)]
+        )
 
     def __getitem__(self, spec):
         if not isinstance(spec, slice):
