@@ -236,8 +236,8 @@ PRIMITIVE_R7 = CibResourcePrimitiveDto(
             start_delay=None,
             interval_origin=None,
             timeout="20s",
-            enabled=None,
-            record_pending=None,
+            enabled=False,
+            record_pending=False,
             role=None,
             on_fail=None,
             meta_attributes=[],
